@@ -25,13 +25,13 @@
 #include <ctime>
 #include <cstdlib>
 
+#include <ardour/svn_revision.h>
 #include <ardour/ardour.h>
 #include <ardour/version.h>
 
 #include "utils.h"
 #include "version.h"
 
-#include "svn_revision.h"
 #include "about.h"
 #include "rgb_macros.h"
 //#include "ardour_ui.h"
@@ -117,51 +117,54 @@ static const gchar * paypal_xpm[] = {
 #endif
 
 static const char* authors[] = {
-	N_("Paul Davis"),
-	N_("Jesse Chappell"),
-	N_("Taybin Rutkin"),
-	N_("Marcus Andersson"),
-	N_("Jeremy Hall"),
-	N_("Steve Harris"),
-	N_("Tim Mayberry"),
-	N_("Mark Stewart"),
-	N_("Sam Chessman"),
-	N_("Jack O'Quin"),
-	N_("Matt Krai"),
-	N_("Ben Bell"),
-	N_("Gerard van Dongen"),
-	N_("Thomas Charbonnel"),
-	N_("Nick Mainsbridge"),
-	N_("Colin Law"),
-	N_("Sampo Savolainen"),
-	N_("Joshua Leach"),
-	N_("Rob Holland"),
-	N_("Per Sigmond"),
-	N_("Doug Mclain"),
-	N_("Petter Sundlöf"),
-	N_("Thorsten Wilms"),
-	N_("Ben Loftis"),
-	N_("Stefan Kersten"),
-	N_("Christopher George"),
-	N_("Robert Jordens"),
-	N_("Dave Robillard"),
-	N_("Hans Fugal"),
 	N_("Brian Ahr"),
-	N_("Nimal Ratnayake"),
-	N_("Mike Täht"),
 	N_("John Anderson"),
+	N_("Marcus Andersson"),
 	N_("Nedko Arnaudov"),
-	N_("Carl Hetherington"),
+	N_("Ben Bell"),
+	N_("Chris Cannam"),
+	N_("Jesse Chappell"),
+	N_("Thomas Charbonnel"),
+	N_("Sam Chessman"),
+	N_("Paul Davis"),
+	N_("Gerard van Dongen"),
 	N_("Colin Fletcher"),
-	N_("Roland Stigge"),
+	N_("Hans Fugal"),
+	N_("Christopher George"),
+	N_("Jeremy Hall"),
 	N_("Audun Halland"),
+	N_("Steve Harris"),
+	N_("Carl Hetherington"),
+	N_("Rob Holland"),
+	N_("Robert Jordens"),
+	N_("Stefan Kersten"),
 	N_("Armand Klenk"),
+	N_("Matt Krai"),
+	N_("Colin Law"),
+	N_("Joshua Leach"),
+	N_("Ben Loftis"),
+	N_("Nick Mainsbridge"),
+	N_("Tim Mayberry"),
+	N_("Doug Mclain"),
+	N_("Jack O'Quin"),
+	N_("Nimal Ratnayake"),
+	N_("Dave Robillard"),
+	N_("Taybin Rutkin"),
+	N_("Sampo Savolainen"),
+	N_("Per Sigmond"),
+	N_("Mark Stewart"),
+	N_("Roland Stigge"),
+	N_("Petter Sundlöf"),
+	N_("Mike Täht"),
+	N_("Thorsten Wilms"),
 	0
 };
 
 static const char* translators[] = {
 	N_("French:\n\tAlain Fréhel <alain.frehel@free.fr>\n\tChristophe Combelles <ccomb@free.fr>\n"),
-	N_("German:\n\tKarsten Petersen <kapet@kapet.de>\n\tSebastian Arnold <mail@sebastian-arnold.net>\n"),
+	N_("German:\n\tKarsten Petersen <kapet@kapet.de>\
+\n\tSebastian Arnold <mail@sebastian-arnold.net>\
+\n\tRobert Schwede<schwede@ironshark.com>\n"),
 	N_("Italian:\n\tFilippo Pappalardo <filippo@email.it>\n"),
 	N_("Portuguese:\n\tRui Nuno Capela <rncbc@rncbc.org>\n"),
 	N_("Brazilian Portuguese:\n\tAlexander da Franca Fernandes <alexander@nautae.eti.br>\
@@ -207,7 +210,7 @@ About::About ()
 	set_website_label (_("visit http://www.ardour.org/"));
 	set_version ((string_compose(_("%1\n(built from revision %2)"),
 				     VERSIONSTRING, 
-				     ardour_svn_revision)));
+				     svn_revision)));
 	
 
 #ifdef WITH_PAYMENT_OPTIONS
