@@ -98,6 +98,7 @@ class AutomationLine;
 class UIExportSpecification;
 class ExportDialog;
 class Selection;
+class TempoLines;
 class TimeSelection;
 class TrackSelection;
 class AutomationSelection;
@@ -251,7 +252,6 @@ class Editor : public PublicEditor
 
 	void set_show_measures (bool yn);
 	bool show_measures () const { return _show_measures; }
-	bool initial_ruler_update_required;
 
 #ifdef FFT_ANALYSIS
 	/* analysis window */
@@ -290,6 +290,7 @@ class Editor : public PublicEditor
 	Width editor_mixer_strip_width;
 	void maybe_add_mixer_strip_width (XMLNode&);
 	void show_editor_mixer (bool yn);
+	void create_editor_mixer ();
 	void set_selected_mixer_strip (TimeAxisView&);
 	void hide_track_in_display (TimeAxisView& tv, bool temporary = false);
 	void show_track_in_display (TimeAxisView& tv);
@@ -316,6 +317,10 @@ class Editor : public PublicEditor
 	void toggle_measure_visibility ();
 	void toggle_logo_visibility ();
 
+	double get_physical_screen_width () const { return physical_screen_width; };
+	double physical_screen_width;
+	double physical_screen_height;
+
 	/* SMPTE timecode & video sync */
 
 	void smpte_fps_chosen (ARDOUR::SmpteFormat format);
@@ -325,7 +330,13 @@ class Editor : public PublicEditor
 	void update_smpte_mode();
 	void update_video_pullup();
 	void update_subframes_per_frame ();
-	/* xfades */
+
+	/* fades & xfades */
+
+	void toggle_region_fades ();
+	void toggle_region_fades_visible ();
+	void toggle_selected_region_fades (int dir);
+	void update_region_fade_visibility ();
 
 	void toggle_auto_xfade ();
 	void toggle_xfades_active ();
@@ -354,6 +365,8 @@ class Editor : public PublicEditor
 	void scroll_tracks_down_line ();
 	void scroll_tracks_up_line ();
 
+	void move_selected_tracks (bool up);
+
 	bool new_regionviews_display_gain () { return _new_regionviews_show_envelope; }
 	void prepare_for_cleanup ();
 	void finish_cleanup ();
@@ -512,8 +525,8 @@ class Editor : public PublicEditor
 	/* functions to be passed to mapover_audio_tracks(), possibly with sigc::bind()-supplied arguments */
 
 	void mapped_get_equivalent_regions (RouteTimeAxisView&, uint32_t, RegionView*, vector<RegionView*>*);
-	void mapped_use_new_playlist (AudioTimeAxisView&, uint32_t);
-	void mapped_use_copy_playlist (AudioTimeAxisView&, uint32_t);
+	void mapped_use_new_playlist (AudioTimeAxisView&, uint32_t, vector<boost::shared_ptr<ARDOUR::Playlist> > const &);
+	void mapped_use_copy_playlist (AudioTimeAxisView&, uint32_t, vector<boost::shared_ptr<ARDOUR::Playlist> > const &);
 	void mapped_clear_playlist (AudioTimeAxisView&, uint32_t);
 
 	/* end */
@@ -525,7 +538,7 @@ class Editor : public PublicEditor
 
 	void set_selected_track (TimeAxisView&, Selection::Operation op = Selection::Set, bool no_remove=false);
 	void select_all_tracks ();
-
+	
 	bool set_selected_control_point_from_click (Selection::Operation op = Selection::Set, bool no_remove=false);
 	void set_selected_track_from_click (bool press, Selection::Operation op = Selection::Set, bool no_remove=false);
 	void set_selected_track_as_side_effect (bool force = false);
@@ -575,7 +588,6 @@ class Editor : public PublicEditor
 	Gdk::Cursor* which_grabber_cursor ();
 
 	ArdourCanvas::Canvas* track_canvas;
-	ArdourCanvas::Canvas* time_canvas;
 
 	ArdourCanvas::Text* first_action_message;
 	ArdourCanvas::Text* verbose_canvas_cursor;
@@ -595,7 +607,7 @@ class Editor : public PublicEditor
 	Gtk::EventBox      time_canvas_event_box;
 	Gtk::EventBox      track_canvas_event_box;
 	Gtk::EventBox      time_button_event_box;
-	Gtk::Frame         time_button_frame;
+	Gtk::EventBox      ruler_label_event_box;
 
 	ArdourCanvas::Pixbuf*     logo_item;
 	ArdourCanvas::Group*      minsec_group;
@@ -608,6 +620,35 @@ class Editor : public PublicEditor
 	ArdourCanvas::Group*      range_marker_group;
 	ArdourCanvas::Group*      transport_marker_group;
 	ArdourCanvas::Group*      cd_marker_group;
+
+	ArdourCanvas::Group*      timebar_group;
+
+	/* These bars never need to be scrolled */
+	ArdourCanvas::Group*      meter_bar_group;
+	ArdourCanvas::Group*      tempo_bar_group;
+	ArdourCanvas::Group*      marker_bar_group;
+	ArdourCanvas::Group*      range_marker_bar_group;
+	ArdourCanvas::Group*      transport_marker_bar_group;
+	ArdourCanvas::Group*      cd_marker_bar_group;
+
+	ArdourCanvas::Group* _background_group;
+	/* 
+	   The _master_group is the group containing all items
+	   that require horizontal scrolling..
+	   It is primarily used to separate canvas items 
+	   that require horizontal scrolling from those that do not. 
+	*/
+	ArdourCanvas::Group* _master_group;
+	/* 
+	   The _trackview_group is the group containing all trackviews.
+	   It is only scrolled vertically.
+	*/
+	ArdourCanvas::Group* _trackview_group;
+	/* 
+	   This canvas group is used for region motion.
+	   It sits on top of the _trackview_group 
+	*/
+	ArdourCanvas::Group* _region_motion_group;
 	
 	enum RulerType {
 		ruler_metric_smpte = 0,
@@ -680,6 +721,8 @@ class Editor : public PublicEditor
 
 	static const double timebar_height;
 	guint32 visible_timebars;
+	gdouble canvas_timebars_vsize;
+	gdouble get_canvas_timebars_vsize () const { return canvas_timebars_vsize; }
 	Gtk::Menu          *editor_ruler_menu;
 	
 	ArdourCanvas::SimpleRect* tempo_bar;
@@ -775,6 +818,7 @@ class Editor : public PublicEditor
 	Gtk::Layout         controls_layout;
 	bool control_layout_scroll (GdkEventScroll* ev);
 	void controls_layout_size_request (Gtk::Requisition*);
+	sigc::connection controls_layout_size_request_connection;
 
 	Gtk::HScrollbar     edit_hscrollbar;
 	bool                _dragging_hscrollbar;
@@ -788,15 +832,14 @@ class Editor : public PublicEditor
 	double canvas_width;
 	double canvas_height;
 	double full_canvas_height;
-	nframes64_t last_canvas_frame;
 
 	bool track_canvas_map_handler (GdkEventAny*);
-	bool time_canvas_map_handler (GdkEventAny*);
 
 	gint edit_controls_button_release (GdkEventButton*);
 	Gtk::Menu *edit_controls_left_menu;
 	Gtk::Menu *edit_controls_right_menu;
 
+	Gtk::VBox           ruler_label_vbox;
 	Gtk::VBox           track_canvas_vbox;
 	Gtk::VBox           time_canvas_vbox;
 	Gtk::VBox           edit_controls_vbox;
@@ -807,7 +850,14 @@ class Editor : public PublicEditor
 	bool deferred_control_scroll (nframes64_t);
 	sigc::connection control_scroll_connection;
 
+	gdouble get_trackview_group_vertical_offset () const { return vertical_adjustment.get_value () - canvas_timebars_vsize;}
+	
+	ArdourCanvas::Group* get_background_group () const { return _background_group; }
+	ArdourCanvas::Group* get_trackview_group () const { return _trackview_group; }
+	double last_trackview_group_vertical_offset;
 	void tie_vertical_scrolling ();
+	void scroll_canvas_horizontally ();
+	void scroll_canvas_vertically ();
 	void canvas_horizontally_scrolled ();
 	void canvas_scroll_to (nframes64_t);
 
@@ -1007,6 +1057,7 @@ class Editor : public PublicEditor
 	void toggle_region_mute ();
 	void toggle_region_lock ();
 	void toggle_region_opaque ();
+	void toggle_record_enable ();
 	void set_region_lock_style (ARDOUR::Region::PositionLockStyle);
 	void raise_region ();
 	void raise_region_to_top ();
@@ -1111,18 +1162,16 @@ class Editor : public PublicEditor
 	
 	void bring_in_external_audio (Editing::ImportMode mode,  nframes64_t& pos);
 
-	void _do_import (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode, ARDOUR::SrcQuality, nframes64_t&);
+	bool  idle_drop_paths  (std::vector<Glib::ustring> paths, nframes64_t frame, double ypos);
+	void  drop_paths_part_two  (const std::vector<Glib::ustring>& paths, nframes64_t frame, double ypos);
+	
 	void do_import (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode, ARDOUR::SrcQuality, nframes64_t&);
-	bool idle_do_import (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode, ARDOUR::SrcQuality, nframes64_t&);
-
-	void _do_embed (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode,  nframes64_t&);
 	void do_embed (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode,  nframes64_t&);
-	bool idle_do_embed (vector<Glib::ustring> paths, Editing::ImportDisposition, Editing::ImportMode mode,  nframes64_t&);
 
 	int  import_sndfiles (vector<Glib::ustring> paths, Editing::ImportMode mode,  ARDOUR::SrcQuality, nframes64_t& pos,
-			      int target_regions, int target_tracks, boost::shared_ptr<ARDOUR::AudioTrack>&, bool);
+			      int target_regions, int target_tracks, boost::shared_ptr<ARDOUR::AudioTrack>, bool, uint32_t total);
 	int  embed_sndfiles (vector<Glib::ustring> paths, bool multiple_files, bool& check_sample_rate, Editing::ImportMode mode, 
-			     nframes64_t& pos, int target_regions, int target_tracks, boost::shared_ptr<ARDOUR::AudioTrack>&);
+			     nframes64_t& pos, int target_regions, int target_tracks, boost::shared_ptr<ARDOUR::AudioTrack>);
 
 	int add_sources (vector<Glib::ustring> paths, ARDOUR::SourceList& sources, nframes64_t& pos, Editing::ImportMode,
 			 int target_regions, int target_tracks, boost::shared_ptr<ARDOUR::AudioTrack>&, bool add_channel_suffix);
@@ -1150,10 +1199,20 @@ class Editor : public PublicEditor
 
 	/* import specific info */
 
-	ARDOUR::Session::import_status import_status;
+	struct EditorImportStatus : public ARDOUR::Session::import_status {
+	    Editing::ImportMode mode;
+	    nframes64_t pos;
+	    int target_tracks;
+	    int target_regions;
+	    boost::shared_ptr<ARDOUR::AudioTrack> track;
+	    bool replace;
+	};
+
+	EditorImportStatus import_status;
 	gint import_progress_timeout (void *);
 	static void *_import_thread (void *);
 	void* import_thread ();
+	void finish_import ();
 
 	/* to support this ... */
 
@@ -1202,6 +1261,7 @@ class Editor : public PublicEditor
 
 	void add_location_mark (nframes64_t where);
 	void add_location_from_audio_region ();
+	void add_locations_from_audio_region ();
 	void add_location_from_selection ();
 	void set_loop_from_selection (bool play);
 	void set_punch_from_selection ();
@@ -1244,6 +1304,7 @@ class Editor : public PublicEditor
 	double snap_threshold;
 
 	void handle_gui_changes (const string &, void *);
+	bool ignore_gui_changes;
 
 	void    hide_all_tracks (bool with_select);
 
@@ -1259,6 +1320,8 @@ class Editor : public PublicEditor
 	Gtk::Menu fade_context_menu;
 	void popup_fade_context_menu (int, int, ArdourCanvas::Item*, ItemType);
 
+	void region_gain_motion_callback (ArdourCanvas::Item*, GdkEvent*);
+
 	void start_fade_in_grab (ArdourCanvas::Item*, GdkEvent*);
 	void start_fade_out_grab (ArdourCanvas::Item*, GdkEvent*);
 	void fade_in_drag_motion_callback (ArdourCanvas::Item*, GdkEvent*);
@@ -1288,6 +1351,7 @@ class Editor : public PublicEditor
 
 	void cursor_drag_motion_callback (ArdourCanvas::Item*, GdkEvent*);
 	void cursor_drag_finished_callback (ArdourCanvas::Item*, GdkEvent*);
+	void cursor_drag_finished_ensure_locate_callback (ArdourCanvas::Item*, GdkEvent*);
 	void marker_drag_motion_callback (ArdourCanvas::Item*, GdkEvent*);
 	void marker_drag_finished_callback (ArdourCanvas::Item*, GdkEvent*);
 	void control_point_drag_motion_callback (ArdourCanvas::Item*, GdkEvent*);
@@ -1307,6 +1371,7 @@ class Editor : public PublicEditor
 	void start_region_brush_grab (ArdourCanvas::Item*, GdkEvent*);
 	void start_selection_grab (ArdourCanvas::Item*, GdkEvent*);
 	void start_cursor_grab (ArdourCanvas::Item*, GdkEvent*);
+	void start_cursor_grab_no_stop (ArdourCanvas::Item*, GdkEvent*);
 	void start_marker_grab (ArdourCanvas::Item*, GdkEvent*);
 	void start_control_point_grab (ArdourCanvas::Item*, GdkEvent*);
 	void start_line_grab_from_regionview (ArdourCanvas::Item*, GdkEvent*);
@@ -1380,17 +1445,13 @@ public:
 
 	bool canvas_playhead_cursor_event (GdkEvent* event, ArdourCanvas::Item*);
 	bool track_canvas_scroll (GdkEventScroll* event);
-	bool time_canvas_scroll (GdkEventScroll* event);
 
 	bool track_canvas_scroll_event (GdkEventScroll* event);
 	bool track_canvas_button_press_event (GdkEventButton* event);
 	bool track_canvas_button_release_event (GdkEventButton* event);
 	bool track_canvas_motion_notify_event (GdkEventMotion* event);
 
-	bool time_canvas_scroll_event (GdkEventScroll* event);
-
 	Gtk::Allocation canvas_allocation;
-	bool canvas_idle_queued;
 	void track_canvas_allocate (Gtk::Allocation alloc);
 	bool track_canvas_size_allocated ();
 
@@ -1405,7 +1466,6 @@ public:
 
 	void handle_new_duration ();
 	void initialize_canvas ();
-	void reset_scrolling_region (Gtk::Allocation* alloc = 0);
 
 	/* display control */
 	
@@ -1416,15 +1476,13 @@ public:
 	
 	ARDOUR::TempoMap::BBTPointList *current_bbt_points;
 	
-	typedef vector<ArdourCanvas::SimpleLine*> TimeLineList;
-	TimeLineList free_measure_lines;
-	TimeLineList used_measure_lines;
-
+	TempoLines* tempo_lines;
+	
 	ArdourCanvas::Group* time_line_group;
 	ArdourCanvas::SimpleLine* get_time_line ();
 	void hide_measures ();
 	void draw_measures ();
-	bool lazy_hide_and_draw_measures ();
+	bool redraw_measures ();
 
 	void new_tempo_section ();
 
@@ -1461,7 +1519,7 @@ public:
 	void new_transport_marker_menu_set_punch ();
 	void update_loop_range_view (bool visibility=false);
 	void update_punch_range_view (bool visibility=false);
-        gint new_transport_marker_menu_popdown (GdkEventAny*);
+        void new_transport_marker_menu_popdown ();
 	void marker_context_menu (GdkEventButton*, ArdourCanvas::Item*);
 	void tm_marker_context_menu (GdkEventButton*, ArdourCanvas::Item*);
 	void transport_marker_context_menu (GdkEventButton*, ArdourCanvas::Item*);
@@ -1486,6 +1544,7 @@ public:
 	void remove_metric_marks ();
 	void draw_metric_marks (const ARDOUR::Metrics& metrics);
 
+	void compute_current_bbt_points (nframes_t left, nframes_t right);
 	void tempo_map_changed (ARDOUR::Change);
 	void redisplay_tempo (bool immediate_redraw);
 	
@@ -1494,8 +1553,6 @@ public:
 	uint32_t bbt_beat_subdivision;
 
 	/* toolbar */
-	
-	Gtk::ToggleButton        editor_mixer_button;
 
 	void editor_mixer_button_toggled ();
 
@@ -1623,7 +1680,9 @@ public:
 	ArdourCanvas::SimpleRect*  range_marker_drag_rect;
 
 	void update_marker_drag_item (ARDOUR::Location *);
-	
+#ifdef GTKOSX
+	ArdourCanvas::SimpleRect     *bogus_background_rect;
+#endif
 	ArdourCanvas::SimpleRect     *transport_bar_range_rect;
 	ArdourCanvas::SimpleRect     *transport_bar_preroll_rect;
 	ArdourCanvas::SimpleRect     *transport_bar_postroll_rect;
@@ -1685,8 +1744,9 @@ public:
 
 	void update_route_visibility ();
 
-	void sync_order_keys ();
-	bool ignore_route_order_sync;
+	void sync_order_keys (const char*);
+	bool route_redisplay_does_not_sync_order_keys;
+	bool route_redisplay_does_not_reset_order_keys;
 
 	bool route_list_display_button_press (GdkEventButton*);
 	void route_list_display_drag_data_received  (const Glib::RefPtr<Gdk::DragContext>& context,
@@ -1771,12 +1831,13 @@ public:
 	uint32_t autoscroll_cnt;
 	nframes64_t autoscroll_x_distance;
 	double autoscroll_y_distance;
-     
+
 	static gint _autoscroll_canvas (void *);
 	bool autoscroll_canvas ();
 	void start_canvas_autoscroll (int x, int y);
 	void stop_canvas_autoscroll ();
 	void maybe_autoscroll (GdkEventMotion*);
+	void maybe_autoscroll_horizontally (GdkEventMotion*);
 	bool allow_vertical_scroll;
 
 	/* trimming */
@@ -1832,7 +1893,6 @@ public:
 						       guint               info,
 						       guint               time);
 
-
 	void  drop_paths  (const Glib::RefPtr<Gdk::DragContext>& context,
 			   gint                x,
 			   gint                y,
@@ -1944,6 +2004,7 @@ public:
 	    Gtk::ComboBoxText     stretch_opts_selector;
 	    Gtk::Label            stretch_opts_label;
 	    Gtk::ToggleButton     precise_button;
+	    Gtk::ToggleButton     preserve_formants_button;
 	    Gtk::HBox             opts_box;
 
 	    Gtk::Button*          cancel_button;
@@ -1985,7 +2046,9 @@ public:
 
 	void detach_tearoff (Gtk::Box* b, Gtk::Window* w);
 	void reattach_tearoff (Gtk::Box* b, Gtk::Window* w, int32_t n);
-
+#ifdef GTKOSX
+	void ensure_all_elements_drawn ();
+#endif
 	/* nudging tracks */
 
 	void nudge_track (bool use_edit_point, bool forwards);
@@ -2084,6 +2147,7 @@ public:
 	bool entered_track_canvas (GdkEventCrossing*);
 	void set_entered_track (TimeAxisView*);
 	void set_entered_regionview (RegionView*);
+	void ensure_track_visible (TimeAxisView*);
 	gint left_automation_track ();
 
 	bool _new_regionviews_show_envelope;
