@@ -89,10 +89,8 @@ Editor::initialize_canvas ()
 {
 	if (getenv ("ARDOUR_NON_AA_CANVAS")) {
 		track_canvas = new ArdourCanvas::Canvas ();
-		time_canvas = new ArdourCanvas::Canvas ();
 	} else {
 		track_canvas = new ArdourCanvas::CanvasAA ();
-		time_canvas = new ArdourCanvas::CanvasAA ();
 	}
 	
 	ArdourCanvas::init ();
@@ -101,37 +99,15 @@ Editor::initialize_canvas ()
 	/* don't try to center the canvas */
 
 	track_canvas->set_center_scroll_region (false);
-	track_canvas->set_dither  	(Gdk::RGB_DITHER_NONE);
+	track_canvas->set_dither (Gdk::RGB_DITHER_NONE);
 
-	/* need to handle 4 specific types of events as catch-alls */
+	Glib::RefPtr<Gdk::Screen> screen = get_screen();
 
-	track_canvas->signal_scroll_event().connect (mem_fun (*this, &Editor::track_canvas_scroll_event));
-	track_canvas->signal_motion_notify_event().connect (mem_fun (*this, &Editor::track_canvas_motion_notify_event));
-	track_canvas->signal_button_press_event().connect (mem_fun (*this, &Editor::track_canvas_button_press_event));
-	track_canvas->signal_button_release_event().connect (mem_fun (*this, &Editor::track_canvas_button_release_event));
-
-	/* just scroll stuff for the timecanvas */
-	time_canvas->signal_scroll_event().connect (mem_fun (*this, &Editor::time_canvas_scroll_event));
-
-	track_canvas->set_name ("EditorMainCanvas");
-	track_canvas->add_events (Gdk::POINTER_MOTION_HINT_MASK|Gdk::SCROLL_MASK);
-	track_canvas->signal_leave_notify_event().connect (mem_fun(*this, &Editor::left_track_canvas));
-	track_canvas->signal_enter_notify_event().connect (mem_fun(*this, &Editor::entered_track_canvas));
-	track_canvas->set_flags (CAN_FOCUS);
-
-	/* set up drag-n-drop */
-
-	vector<TargetEntry> target_table;
-	
-	// Drag-N-Drop from the region list can generate this target
-	target_table.push_back (TargetEntry ("regions"));
-
-	target_table.push_back (TargetEntry ("text/plain"));
-	target_table.push_back (TargetEntry ("text/uri-list"));
-	target_table.push_back (TargetEntry ("application/x-rootwin-drop"));
-
-	track_canvas->drag_dest_set (target_table);
-	track_canvas->signal_drag_data_received().connect (mem_fun(*this, &Editor::track_canvas_drag_data_received));
+	if (!screen) {
+		screen = Gdk::Screen::get_default();
+	}
+	physical_screen_width = screen->get_width ();
+	physical_screen_height = screen->get_height ();
 
 	/* stuff for the verbose canvas cursor */
 
@@ -156,105 +132,146 @@ Editor::initialize_canvas ()
 		// logo_item->property_width_set() = true;
 		logo_item->show ();
 	}
+
+	/* a group to hold time (measure) lines */	
+	time_line_group = new ArdourCanvas::Group (*track_canvas->root());
+
+#ifdef GTKOSX
+	/*XXX please don't laugh. this actually improves canvas performance on osx */
+	bogus_background_rect =  new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, max_canvas_coordinate/3, physical_screen_height);
+	bogus_background_rect->property_outline_pixels() = 0;
+#endif
+	transport_loop_range_rect = new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, 0.0, physical_screen_height);
+	transport_loop_range_rect->property_outline_pixels() = 1;
+	transport_loop_range_rect->hide();
+
+	transport_punch_range_rect = new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, 0.0, physical_screen_height);
+	transport_punch_range_rect->property_outline_pixels() = 0;
+	transport_punch_range_rect->hide();
+
+	_background_group = new ArdourCanvas::Group (*track_canvas->root());
+	_master_group = new ArdourCanvas::Group (*track_canvas->root());
+
+	range_marker_drag_rect = new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, 0.0, physical_screen_height);
+	range_marker_drag_rect->hide ();
+
+	_trackview_group = new ArdourCanvas::Group (*_master_group);
+	_region_motion_group = new ArdourCanvas::Group (*_trackview_group);
+
+	meter_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		meter_bar = new ArdourCanvas::SimpleRect (*meter_bar_group, 0.0, 0.0, physical_screen_width, timebar_height - 1);
+		meter_bar->property_outline_pixels() = 1;
+	} else {
+		meter_bar = new ArdourCanvas::SimpleRect (*meter_bar_group, 0.0, 0.0, physical_screen_width, timebar_height);
+		meter_bar->property_outline_pixels() = 0;
+	}
+	meter_bar->property_outline_what() = (0x1 | 0x8);
+
+	tempo_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		tempo_bar = new ArdourCanvas::SimpleRect (*tempo_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height - 1));
+		tempo_bar->property_outline_pixels() = 1;
+	} else {
+		tempo_bar = new ArdourCanvas::SimpleRect (*tempo_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height));
+		tempo_bar->property_outline_pixels() = 0;
+	}
+	tempo_bar->property_outline_what() = (0x1 | 0x8);
+
+	range_marker_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		range_marker_bar = new ArdourCanvas::SimpleRect (*range_marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height - 1));
+		range_marker_bar->property_outline_pixels() = 1;
+	} else {
+		range_marker_bar = new ArdourCanvas::SimpleRect (*range_marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height));
+		range_marker_bar->property_outline_pixels() = 0;
+	}
+	range_marker_bar->property_outline_what() = (0x1 | 0x8);
 	
-	/* a group to hold time (measure) lines */
+	transport_marker_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		transport_marker_bar = new ArdourCanvas::SimpleRect (*transport_marker_bar_group, 0.0, 0.0,  physical_screen_width, (timebar_height - 1));
+		transport_marker_bar->property_outline_pixels() = 1;
+	} else {
+		transport_marker_bar = new ArdourCanvas::SimpleRect (*transport_marker_bar_group, 0.0, 0.0,  physical_screen_width, (timebar_height));
+		transport_marker_bar->property_outline_pixels() = 0;
+	}
+	transport_marker_bar->property_outline_what() = (0x1 | 0x8);
+
+	marker_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		marker_bar = new ArdourCanvas::SimpleRect (*marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height - 1));
+		marker_bar->property_outline_pixels() = 1;
+	} else {
+		marker_bar = new ArdourCanvas::SimpleRect (*marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height));
+		marker_bar->property_outline_pixels() = 0;
+	}
+	marker_bar->property_outline_what() = (0x1 | 0x8);
 	
-	time_line_group = new ArdourCanvas::Group (*track_canvas->root(), 0.0, 0.0);
+	cd_marker_bar_group = new ArdourCanvas::Group (*track_canvas->root ());
+	if (Profile->get_sae()) {
+		cd_marker_bar = new ArdourCanvas::SimpleRect (*cd_marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height - 1));
+		cd_marker_bar->property_outline_pixels() = 1;
+	} else {
+		cd_marker_bar = new ArdourCanvas::SimpleRect (*cd_marker_bar_group, 0.0, 0.0, physical_screen_width, (timebar_height));
+		cd_marker_bar->property_outline_pixels() = 0;
+	}
+ 	cd_marker_bar->property_outline_what() = (0x1 | 0x8);
+
+	timebar_group =  new ArdourCanvas::Group (*track_canvas->root(), 0.0, 0.0);
 	cursor_group = new ArdourCanvas::Group (*track_canvas->root(), 0.0, 0.0);
 
-	time_canvas->set_name ("EditorTimeCanvas");
-	time_canvas->add_events (Gdk::POINTER_MOTION_HINT_MASK);
-	time_canvas->set_flags (CAN_FOCUS);
-	time_canvas->set_center_scroll_region (false);
-	time_canvas->set_dither  	(Gdk::RGB_DITHER_NONE);
-	
-	meter_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, 0.0);
-	tempo_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, timebar_height);
-	range_marker_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, timebar_height * 2.0);
-	transport_marker_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, timebar_height * 3.0);
-	marker_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, timebar_height * 4.0);
-	cd_marker_group = new ArdourCanvas::Group (*time_canvas->root(), 0.0, timebar_height * 5.0);
-	
-	tempo_bar = new ArdourCanvas::SimpleRect (*tempo_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	tempo_bar->property_outline_what() = (0x1 | 0x8);
-	tempo_bar->property_outline_pixels() = 0;
-	
-	meter_bar = new ArdourCanvas::SimpleRect (*meter_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	meter_bar->property_outline_what() = (0x1 | 0x8);
-	meter_bar->property_outline_pixels() = 0;
-	
-	marker_bar = new ArdourCanvas::SimpleRect (*marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	marker_bar->property_outline_what() = (0x1 | 0x8);
-	marker_bar->property_outline_pixels() = 0;
+	meter_group = new ArdourCanvas::Group (*timebar_group, 0.0, timebar_height * 5.0);
+	tempo_group = new ArdourCanvas::Group (*timebar_group, 0.0, timebar_height * 4.0);
+	range_marker_group = new ArdourCanvas::Group (*timebar_group, 0.0, timebar_height * 3.0);
+	transport_marker_group = new ArdourCanvas::Group (*timebar_group, 0.0, timebar_height * 2.0);
+	marker_group = new ArdourCanvas::Group (*timebar_group, 0.0, timebar_height);
+	cd_marker_group = new ArdourCanvas::Group (*timebar_group, 0.0, 0.0);
 
-	cd_marker_bar = new ArdourCanvas::SimpleRect (*cd_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
- 	cd_marker_bar->property_outline_what() = (0x1 | 0x8);
- 	cd_marker_bar->property_outline_pixels() = 0;
-	
-	range_marker_bar = new ArdourCanvas::SimpleRect (*range_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	range_marker_bar->property_outline_what() = (0x1 | 0x8);
-	range_marker_bar->property_outline_pixels() = 0;
-	
-	transport_marker_bar = new ArdourCanvas::SimpleRect (*transport_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	transport_marker_bar->property_outline_what() = (0x1 | 0x8);
-	transport_marker_bar->property_outline_pixels() = 0;
-	
-	cd_marker_bar_drag_rect = new ArdourCanvas::SimpleRect (*cd_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	cd_marker_bar_drag_rect->property_outline_pixels() = 0;
-	cd_marker_bar_drag_rect->hide ();
-
-	range_bar_drag_rect = new ArdourCanvas::SimpleRect (*range_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	range_bar_drag_rect->property_outline_pixels() = 0;
-	range_bar_drag_rect->hide ();
-
-	transport_bar_drag_rect = new ArdourCanvas::SimpleRect (*transport_marker_group, 0.0, 0.0, max_canvas_coordinate, timebar_height-1.0);
-	transport_bar_drag_rect->property_outline_pixels() = 0;
-	transport_bar_drag_rect->hide ();
-	
-	marker_drag_line_points.push_back(Gnome::Art::Point(0.0, 0.0));
 	marker_drag_line_points.push_back(Gnome::Art::Point(0.0, 0.0));
+	marker_drag_line_points.push_back(Gnome::Art::Point(0.0, physical_screen_height));
 
-	marker_drag_line = new ArdourCanvas::Line (*track_canvas->root());
+	marker_drag_line = new ArdourCanvas::Line (*timebar_group);
 	marker_drag_line->property_width_pixels() = 1;
 	marker_drag_line->property_points() = marker_drag_line_points;
 	marker_drag_line->hide();
 
-	range_marker_drag_rect = new ArdourCanvas::SimpleRect (*track_canvas->root(), 0.0, 0.0, 0.0, 0.0);
-	range_marker_drag_rect->hide ();
-	
-	transport_loop_range_rect = new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, 0.0, 0.0);
-	transport_loop_range_rect->property_outline_pixels() = 1;
-	transport_loop_range_rect->hide();
+	cd_marker_bar_drag_rect = new ArdourCanvas::SimpleRect (*cd_marker_group, 0.0, 0.0, 100, timebar_height);
+	cd_marker_bar_drag_rect->property_outline_pixels() = 0;
+	cd_marker_bar_drag_rect->hide ();
 
-	transport_punch_range_rect = new ArdourCanvas::SimpleRect (*time_line_group, 0.0, 0.0, 0.0, 0.0);
-	transport_punch_range_rect->property_outline_pixels() = 0;
-	transport_punch_range_rect->hide();
-	
-	transport_loop_range_rect->lower_to_bottom (); // loop on the bottom
+	range_bar_drag_rect = new ArdourCanvas::SimpleRect (*range_marker_group, 0.0, 0.0, 100, timebar_height);
+	range_bar_drag_rect->property_outline_pixels() = 0;
+	range_bar_drag_rect->hide ();
 
-	transport_punchin_line = new ArdourCanvas::SimpleLine (*time_line_group);
+	transport_bar_drag_rect = new ArdourCanvas::SimpleRect (*transport_marker_group, 0.0, 0.0, 100, timebar_height);
+	transport_bar_drag_rect->property_outline_pixels() = 0;
+	transport_bar_drag_rect->hide ();
+
+	transport_punchin_line = new ArdourCanvas::SimpleLine (*_master_group);
 	transport_punchin_line->property_x1() = 0.0;
 	transport_punchin_line->property_y1() = 0.0;
 	transport_punchin_line->property_x2() = 0.0;
-	transport_punchin_line->property_y2() = 0.0;
+	transport_punchin_line->property_y2() = physical_screen_height;
 	transport_punchin_line->hide ();
 	
-	transport_punchout_line  = new ArdourCanvas::SimpleLine (*time_line_group);
+	transport_punchout_line  = new ArdourCanvas::SimpleLine (*_master_group);
 	transport_punchout_line->property_x1() = 0.0;
 	transport_punchout_line->property_y1() = 0.0;
 	transport_punchout_line->property_x2() = 0.0;
-	transport_punchout_line->property_y2() = 0.0;
+	transport_punchout_line->property_y2() = physical_screen_height;
 	transport_punchout_line->hide();
 	
 	// used to show zoom mode active zooming
-	zoom_rect = new ArdourCanvas::SimpleRect (*track_canvas->root(), 0.0, 0.0, 0.0, 0.0);
+	zoom_rect = new ArdourCanvas::SimpleRect (*_master_group, 0.0, 0.0, 0.0, 0.0);
 	zoom_rect->property_outline_pixels() = 1;
 	zoom_rect->hide();
 	
 	zoom_rect->signal_event().connect (bind (mem_fun (*this, &Editor::canvas_zoom_rect_event), (ArdourCanvas::Item*) 0));
 	
 	// used as rubberband rect
-	rubberband_rect = new ArdourCanvas::SimpleRect (*track_canvas->root(), 0.0, 0.0, 0.0, 0.0);
+	rubberband_rect = new ArdourCanvas::SimpleRect (*_trackview_group, 0.0, 0.0, 0.0, 0.0);
+
 	rubberband_rect->property_outline_pixels() = 1;
 	rubberband_rect->hide();
 	
@@ -264,22 +281,40 @@ Editor::initialize_canvas ()
 	cd_marker_bar->signal_event().connect (bind (mem_fun (*this, &Editor::canvas_cd_marker_bar_event), cd_marker_bar));
 	range_marker_bar->signal_event().connect (bind (mem_fun (*this, &Editor::canvas_range_marker_bar_event), range_marker_bar));
 	transport_marker_bar->signal_event().connect (bind (mem_fun (*this, &Editor::canvas_transport_marker_bar_event), transport_marker_bar));
-	
-	ZoomChanged.connect (bind (mem_fun(*this, &Editor::update_loop_range_view), false));
-	ZoomChanged.connect (bind (mem_fun(*this, &Editor::update_punch_range_view), false));
-	
-	double time_height = timebar_height * 5;
-	double time_width = FLT_MAX/frames_per_unit;
-	time_canvas->set_scroll_region(0.0, 0.0, time_width, time_height);
 
 	playhead_cursor = new Cursor (*this, &Editor::canvas_playhead_cursor_event);
 
-	initial_ruler_update_required = true;
-	track_canvas->signal_size_allocate().connect (mem_fun(*this, &Editor::track_canvas_allocate));
-
 	if (logo_item) {
 		logo_item->lower_to_bottom ();
 	}
+	/* need to handle 4 specific types of events as catch-alls */
+
+	track_canvas->signal_scroll_event().connect (mem_fun (*this, &Editor::track_canvas_scroll_event));
+	track_canvas->signal_motion_notify_event().connect (mem_fun (*this, &Editor::track_canvas_motion_notify_event));
+	track_canvas->signal_button_press_event().connect (mem_fun (*this, &Editor::track_canvas_button_press_event));
+	track_canvas->signal_button_release_event().connect (mem_fun (*this, &Editor::track_canvas_button_release_event));
+
+	track_canvas->set_name ("EditorMainCanvas");
+	track_canvas->add_events (Gdk::POINTER_MOTION_HINT_MASK|Gdk::SCROLL_MASK);
+	track_canvas->signal_leave_notify_event().connect (mem_fun(*this, &Editor::left_track_canvas));
+	track_canvas->signal_enter_notify_event().connect (mem_fun(*this, &Editor::entered_track_canvas));
+	track_canvas->set_flags (CAN_FOCUS);
+
+	/* set up drag-n-drop */
+
+	vector<TargetEntry> target_table;
+	
+	// Drag-N-Drop from the region list can generate this target
+	target_table.push_back (TargetEntry ("regions"));
+
+	target_table.push_back (TargetEntry ("text/plain"));
+	target_table.push_back (TargetEntry ("text/uri-list"));
+	target_table.push_back (TargetEntry ("application/x-rootwin-drop"));
+
+	track_canvas->drag_dest_set (target_table);
+	track_canvas->signal_drag_data_received().connect (mem_fun(*this, &Editor::track_canvas_drag_data_received));
+
+	track_canvas->signal_size_allocate().connect (mem_fun(*this, &Editor::track_canvas_allocate));
 
 	ColorsChanged.connect (mem_fun (*this, &Editor::color_handler));
 	color_handler();
@@ -290,32 +325,17 @@ void
 Editor::track_canvas_allocate (Gtk::Allocation alloc)
 {
 	canvas_allocation = alloc;
-
-	if (!initial_ruler_update_required) {
-		if (!canvas_idle_queued) {
-			/* call this first so that we do stuff before any pending redraw */
-			Glib::signal_idle().connect (mem_fun (*this, &Editor::track_canvas_size_allocated), false);
-			canvas_idle_queued = true;
-		}
-		return;
-	} 
-
-	initial_ruler_update_required = false;
 	track_canvas_size_allocated ();
 }
 
 bool
 Editor::track_canvas_size_allocated ()
 {
-	if (canvas_idle_queued) {
-		canvas_idle_queued = false;
-	}
+	bool height_changed = canvas_height != canvas_allocation.get_height();
 
 	canvas_width = canvas_allocation.get_width();
 	canvas_height = canvas_allocation.get_height();
 
-	full_canvas_height = canvas_height;
-
 	if (session) {
 		TrackViewList::iterator i;
 		double height = 0;
@@ -324,113 +344,93 @@ Editor::track_canvas_size_allocated ()
 			if ((*i)->control_parent) {
 				height += (*i)->effective_height;
 			}
+			(*i)->clip_to_viewport ();
 		}
 		
-		full_canvas_height = height;
+		full_canvas_height = height + canvas_timebars_vsize;
 	}
 
-	zoom_range_clock.set ((nframes64_t) floor ((canvas_width * frames_per_unit)));
-	playhead_cursor->set_position (playhead_cursor->current_frame);
-
-	reset_hscrollbar_stepping ();
-	reset_scrolling_region ();
-
-	if (playhead_cursor) playhead_cursor->set_length (canvas_height);
-
-	double y1 = vertical_adjustment.get_value ();
+	if (height_changed) {
+		if (playhead_cursor) {
+			playhead_cursor->set_length (canvas_height);
+		}
  	
-	for (MarkerSelection::iterator x = selection->markers.begin(); x != selection->markers.end(); ++x) {
-		(*x)->set_line_vpos (y1, canvas_height);
+		for (MarkerSelection::iterator x = selection->markers.begin(); x != selection->markers.end(); ++x) {
+			(*x)->set_line_vpos (0, canvas_height);
+		}
+
+		vertical_adjustment.set_page_size (canvas_height);
+		last_trackview_group_vertical_offset = get_trackview_group_vertical_offset ();
+		if ((vertical_adjustment.get_value() + canvas_height) >= vertical_adjustment.get_upper()) {
+			/* 
+			   We're increasing the size of the canvas while the bottom is visible.
+			   We scroll down to keep in step with the controls layout.
+			*/
+			vertical_adjustment.set_value (full_canvas_height - canvas_height);
+		}
 	}
 
- 	range_marker_drag_rect->property_y1() = y1;
- 	range_marker_drag_rect->property_y2() = full_canvas_height;
- 	transport_loop_range_rect->property_y1() = y1;
- 	transport_loop_range_rect->property_y2() = full_canvas_height;
- 	transport_punch_range_rect->property_y1() = y1;
- 	transport_punch_range_rect->property_y2() = full_canvas_height;
- 	transport_punchin_line->property_y1() = y1;
- 	transport_punchin_line->property_y2() = full_canvas_height;
- 	transport_punchout_line->property_y1() = y1;
- 	transport_punchout_line->property_y2() = full_canvas_height;
-	
+	handle_new_duration ();
+	reset_hscrollbar_stepping ();
 	update_fixed_rulers();
-	redisplay_tempo (true);
+	redisplay_tempo (false);
 
 	Resized (); /* EMIT_SIGNAL */
 
 	return false;
 }
 
-void
-Editor::reset_scrolling_region (Gtk::Allocation* alloc)
-{
-	TreeModel::Children rows = route_display_model->children();
-	TreeModel::Children::iterator i;
-	double pos;
-
-        for (pos = 0, i = rows.begin(); i != rows.end(); ++i) {
-	        TimeAxisView *tv = (*i)[route_display_columns.tv];
-		if (tv != 0 && !tv->hidden()) {
-			pos += tv->effective_height;
-		}
-	}
-
-	double last_canvas_unit =  max ((last_canvas_frame / frames_per_unit), canvas_width);
-	//cerr << "Editor::reset_scrolling_region () lcf:fpu:cw:lcu " << last_canvas_frame << ":" << frames_per_unit << ":" << canvas_width << ":" << last_canvas_unit << endl;//DEBUG
-	track_canvas->set_scroll_region (0.0, 0.0, last_canvas_unit, pos);
-
-	// XXX what is the correct height value for the time canvas ? this overstates it
-	time_canvas->set_scroll_region ( 0.0, 0.0, last_canvas_unit, canvas_height);
-
-	range_marker_drag_rect->property_y2() = canvas_height;
-	transport_loop_range_rect->property_y2() = canvas_height;
-	transport_punch_range_rect->property_y2() = canvas_height;
-	transport_punchin_line->property_y2() = canvas_height;
-	transport_punchout_line->property_y2() = canvas_height;
-
-	update_punch_range_view (true);
-
-	controls_layout.queue_resize();
-}
-
 void
 Editor::controls_layout_size_request (Requisition* req)
 {
 	TreeModel::Children rows = route_display_model->children();
 	TreeModel::Children::iterator i;
 	double pos;
+	bool changed = false;
 
 	for (pos = 0, i = rows.begin(); i != rows.end(); ++i) {
 		TimeAxisView *tv = (*i)[route_display_columns.tv];
 		if (tv != 0) {
 			pos += tv->effective_height;
+			tv->clip_to_viewport ();
 		}
 	}
 
-	RefPtr<Gdk::Screen> screen = get_screen();
-
-	if (!screen) {
-		screen = Gdk::Screen::get_default();
-	}
-
-	edit_controls_vbox.check_resize();
-	req->width = max (edit_controls_vbox.get_width(),  controls_layout.get_width());
+	gint height = min ((gint) pos, (gint) (physical_screen_height - 600));
+	gint width = max (edit_controls_vbox.get_width(),  controls_layout.get_width());
 
 	/* don't get too big. the fudge factors here are just guesses */
-	
-	req->width = min (req->width, screen->get_width() - 300);
-	req->height = min ((gint) pos, (screen->get_height() - 400));
 
-	/* this one is important: it determines how big the layout thinks it really is, as 
-	   opposed to what it displays on the screen
-	*/
-	
-	controls_layout.set_size (edit_controls_vbox.get_width(), (gint) pos);
-	controls_layout.set_size_request(edit_controls_vbox.get_width(), -1);
-	zoom_box.set_size_request(edit_controls_vbox.get_width(), -1);
-	time_button_frame.set_size_request(edit_controls_vbox.get_width() + edit_vscrollbar.get_width(), -1);
+	width =  min (width, (gint) (physical_screen_width - 300));
 
+	if ((req->width != width) || (req->height != height)) {
+		changed = true;
+		controls_layout_size_request_connection.disconnect ();
+	}
+
+	if (req->width != width) {
+		gint vbox_width = edit_controls_vbox.get_width();
+		req->width = width;
+
+		/* this one is important: it determines how big the layout thinks it really is, as 
+		   opposed to what it displays on the screen
+		*/
+		controls_layout.property_width () = vbox_width;
+		controls_layout.property_width_request () = vbox_width;
+
+		time_button_event_box.property_width_request () = vbox_width;
+		zoom_box.property_width_request () = vbox_width;
+	}
+
+	if (req->height != height) {
+		req->height = height;
+		controls_layout.property_height () = (guint) floor (pos);
+		controls_layout.property_height_request () = height;
+	}
+
+	if (changed) {
+		controls_layout_size_request_connection = controls_layout.signal_size_request().connect (mem_fun (*this, &Editor::controls_layout_size_request));
+	}
 	//cerr << "sizes = " << req->width << " " << edit_controls_vbox.get_width() << " " << controls_layout.get_width() << " " << zoom_box.get_width() << " " << time_button_frame.get_width() << endl;//DEBUG	
 }
 
@@ -441,21 +441,12 @@ Editor::track_canvas_map_handler (GdkEventAny* ev)
 	return false;
 }
 
-bool
-Editor::time_canvas_map_handler (GdkEventAny* ev)
-{
-	time_canvas->get_window()->set_cursor (*timebar_cursor);
-	return false;
-}
-
 void  
 Editor::track_canvas_drag_data_received (const RefPtr<Gdk::DragContext>& context,
 					 int x, int y, 
 					 const SelectionData& data,
 					 guint info, guint time)
 {
-	cerr << "drop on canvas, target = " << data.get_target() << endl;
-
 	if (data.get_target() == "regions") {
 		drop_regions (context, x, y, data, info, time);
 	} else {
@@ -463,43 +454,20 @@ Editor::track_canvas_drag_data_received (const RefPtr<Gdk::DragContext>& context
 	}
 }
 
+bool
+Editor::idle_drop_paths (vector<ustring> paths, nframes64_t frame, double ypos)
+{
+	drop_paths_part_two (paths, frame, ypos);
+	return false;
+}
+
 void
-Editor::drop_paths (const RefPtr<Gdk::DragContext>& context,
-		    int x, int y, 
-		    const SelectionData& data,
-		    guint info, guint time)
+Editor::drop_paths_part_two (const vector<ustring>& paths, nframes64_t frame, double ypos)
 {
 	TimeAxisView* tvp;
 	AudioTimeAxisView* tv;
-	double cy;
-	vector<ustring> paths;
-	string spath;
-	GdkEvent ev;
-	nframes64_t frame;
 
-	if (convert_drop_to_paths (paths, context, x, y, data, info, time)) {
-		goto out;
-	}
-
-	/* D-n-D coordinates are window-relative, so convert to "world" coordinates
-	 */
-
-	double wx;
-	double wy;
-
-	track_canvas->window_to_world (x, y, wx, wy);
-	wx += horizontal_adjustment.get_value();
-	wy += vertical_adjustment.get_value();
-	
-	ev.type = GDK_BUTTON_RELEASE;
-	ev.button.x = wx;
-	ev.button.y = wy;
-
-	frame = event_frame (&ev, 0, &cy);
-
-	snap_to (frame);
-
-	if ((tvp = trackview_by_y_position (cy)) == 0) {
+	if ((tvp = trackview_by_y_position (ypos)) == 0) {
 
 		/* drop onto canvas background: create new tracks */
 
@@ -516,18 +484,57 @@ Editor::drop_paths (const RefPtr<Gdk::DragContext>& context,
 		/* check that its an audio track, not a bus */
 		
 		if (tv->get_diskstream()) {
-			/* select the track, then embed */
+			/* select the track, then embed/import */
 			selection->set (tv);
 
 			if (Profile->get_sae() || Config->get_only_copy_imported_files()) {
-				do_import (paths, Editing::ImportDistinctFiles, Editing::ImportToTrack, SrcBest, frame); 
+				do_import (paths, Editing::ImportSerializeFiles, Editing::ImportToTrack, SrcBest, frame); 
 			} else {
-				do_embed (paths, Editing::ImportDistinctFiles, ImportToTrack, frame);
+				do_embed (paths, Editing::ImportSerializeFiles, ImportToTrack, frame);
 			}
 		}
 	}
+}
+
+void
+Editor::drop_paths (const RefPtr<Gdk::DragContext>& context,
+		    int x, int y, 
+		    const SelectionData& data,
+		    guint info, guint time)
+{
+	vector<ustring> paths;
+	GdkEvent ev;
+	nframes64_t frame;
+	double wx;
+	double wy;
+	double cy;
+
+	if (convert_drop_to_paths (paths, context, x, y, data, info, time) == 0) {
+		
+		/* D-n-D coordinates are window-relative, so convert to "world" coordinates
+		 */
+
+		track_canvas->window_to_world (x, y, wx, wy);
+		
+		ev.type = GDK_BUTTON_RELEASE;
+		ev.button.x = wx;
+		ev.button.y = wy;
+		
+		frame = event_frame (&ev, 0, &cy);
+		
+		snap_to (frame);
+		
+#ifdef GTKOSX
+		/* We are not allowed to call recursive main event loops from within
+		   the main event loop with GTK/Quartz. Since import/embed wants
+		   to push up a progress dialog, defer all this till we go idle.
+		*/
+		Glib::signal_idle().connect (bind (mem_fun (*this, &Editor::idle_drop_paths), paths, frame, cy));
+#else
+		drop_paths_part_two (paths, frame, cy);
+#endif
+	}
 
-  out:
 	context->drag_finish (true, false, time);
 }
 
@@ -537,15 +544,14 @@ Editor::drop_regions (const RefPtr<Gdk::DragContext>& context,
 		      const SelectionData& data,
 		      guint info, guint time)
 {
-	const SerializedObjectPointers<boost::shared_ptr<Region> >* sr = 
-		reinterpret_cast<const SerializedObjectPointers<boost::shared_ptr<Region> > *> (data.get_data());
+	std::list<boost::shared_ptr<Region> > regions;
+	region_list_display.get_object_drag_data (regions);
 
-	for (uint32_t i = 0; i < sr->cnt; ++i) {
+	for (list<boost::shared_ptr<Region> >::iterator r = regions.begin(); r != regions.end(); ++r) {
 
-		boost::shared_ptr<Region> r = sr->data[i];
 		boost::shared_ptr<AudioRegion> ar;
 
-		if ((ar = boost::dynamic_pointer_cast<AudioRegion>(r)) != 0) {
+		if ((ar = boost::dynamic_pointer_cast<AudioRegion>(*r)) != 0) {
 			insert_region_list_drag (ar, x, y);
 		}
 	}
@@ -556,20 +562,17 @@ Editor::drop_regions (const RefPtr<Gdk::DragContext>& context,
 void
 Editor::maybe_autoscroll (GdkEventMotion* event)
 {
+
 	nframes64_t rightmost_frame = leftmost_frame + current_page_frames();
 	nframes64_t frame = drag_info.current_pointer_frame;
 	bool startit = false;
-	double vertical_pos = vertical_adjustment.get_value();
 
 	autoscroll_y = 0;
 	autoscroll_x = 0;
-
-	if (event->y < vertical_pos) {
+	if (event->y < canvas_timebars_vsize) {
 		autoscroll_y = -1;
 		startit = true;
-	}
-
-	if (event->y > vertical_pos + canvas_height) {
+	} else if (event->y > canvas_height) {
 		autoscroll_y = 1;
 		startit = true;
 	}
@@ -582,7 +585,6 @@ Editor::maybe_autoscroll (GdkEventMotion* event)
 		}
 
 	} else if (frame < leftmost_frame) {
-		
 		if (leftmost_frame > 0) {
 			autoscroll_x = -1;
 			startit = true;
@@ -606,6 +608,43 @@ Editor::maybe_autoscroll (GdkEventMotion* event)
 	last_autoscroll_y = autoscroll_y;
 }
 
+void
+Editor::maybe_autoscroll_horizontally (GdkEventMotion* event)
+{
+	nframes64_t rightmost_frame = leftmost_frame + current_page_frames();
+	nframes64_t frame = drag_info.current_pointer_frame;
+	bool startit = false;
+
+	autoscroll_y = 0;
+	autoscroll_x = 0;
+
+	if (frame > rightmost_frame) {
+
+		if (rightmost_frame < max_frames) {
+			autoscroll_x = 1;
+			startit = true;
+		}
+
+	} else if (frame < leftmost_frame) {
+		if (leftmost_frame > 0) {
+			autoscroll_x = -1;
+			startit = true;
+		}
+
+	}
+
+	if ((autoscroll_x != last_autoscroll_x) || (autoscroll_y != last_autoscroll_y) || (autoscroll_x == 0 && autoscroll_y == 0)) {
+		stop_canvas_autoscroll ();
+	}
+	
+	if (startit && autoscroll_timeout_tag < 0) {
+		start_canvas_autoscroll (autoscroll_x, autoscroll_y);
+	}
+
+	last_autoscroll_x = autoscroll_x;
+	last_autoscroll_y = autoscroll_y;
+}
+
 gint
 Editor::_autoscroll_canvas (void *arg)
 {
@@ -618,26 +657,40 @@ Editor::autoscroll_canvas ()
 	nframes64_t new_frame;
 	nframes64_t limit = max_frames - current_page_frames();
 	GdkEventMotion ev;
-	nframes64_t target_frame;
 	double new_pixel;
 	double target_pixel;
 
+	if (autoscroll_x_distance != 0) {
+		if (autoscroll_x > 0) {
+			autoscroll_x_distance = (unit_to_frame (drag_info.current_pointer_x) - (leftmost_frame + current_page_frames())) / 3;
+		} else if (autoscroll_x < 0) {
+			autoscroll_x_distance = (leftmost_frame - unit_to_frame (drag_info.current_pointer_x)) / 3;
+
+		}
+	}
+
+	if (autoscroll_y_distance != 0) {
+		if (autoscroll_y > 0) {
+			autoscroll_y_distance = (drag_info.current_pointer_y - (get_trackview_group_vertical_offset() + canvas_height)) / 3;
+		} else if (autoscroll_y < 0) {
+
+			autoscroll_y_distance = (vertical_adjustment.get_value () - drag_info.current_pointer_y) / 3;
+		}
+	}
+
 	if (autoscroll_x < 0) {
 		if (leftmost_frame < autoscroll_x_distance) {
 			new_frame = 0;
 		} else {
 			new_frame = leftmost_frame - autoscroll_x_distance;
 		}
-		target_frame = drag_info.current_pointer_frame - autoscroll_x_distance;
  	} else if (autoscroll_x > 0) {
 		if (leftmost_frame > limit - autoscroll_x_distance) {
 			new_frame = limit;
 		} else {
 			new_frame = leftmost_frame + autoscroll_x_distance;
 		}
-		target_frame = drag_info.current_pointer_frame + autoscroll_x_distance;
 	} else {
-		target_frame = drag_info.current_pointer_frame;
 		new_frame = leftmost_frame;
 	}
 
@@ -675,23 +728,34 @@ Editor::autoscroll_canvas ()
 		target_pixel = min (target_pixel, full_canvas_height - 10);
 		
 	} else {
-		target_pixel = drag_info.current_pointer_y;
+	  	target_pixel = drag_info.current_pointer_y;
 		new_pixel = vertical_pos;
 	}
 
-	/* now fake a motion event to get the object that is being dragged to move too */
-
-	ev.type = GDK_MOTION_NOTIFY;
-	ev.state &= Gdk::BUTTON1_MASK;
-	ev.x = frame_to_unit (target_frame);
-	ev.y = target_pixel;
-	motion_handler (drag_info.item, (GdkEvent*) &ev, drag_info.item_type, true);
-
 	if ((new_frame == 0 || new_frame == limit) && (new_pixel == 0 || new_pixel == DBL_MAX)) {
 		/* we are done */
 		return false;
 	}
 
+	if (new_frame != leftmost_frame) {
+		reset_x_origin (new_frame);
+	}
+
+	vertical_adjustment.set_value (new_pixel);
+
+	/* fake an event. */
+
+	Glib::RefPtr<Gdk::Window> canvas_window = const_cast<Editor*>(this)->track_canvas->get_window();
+	gint x, y;
+	Gdk::ModifierType mask;
+	canvas_window->get_pointer (x, y, mask);
+	ev.type = GDK_MOTION_NOTIFY;
+	ev.state &= Gdk::BUTTON1_MASK;
+	ev.x = x;
+	ev.y = y;
+
+	motion_handler (drag_info.item, (GdkEvent*) &ev, drag_info.item_type, true);
+
 	autoscroll_cnt++;
 
 	if (autoscroll_cnt == 1) {
@@ -703,53 +767,6 @@ Editor::autoscroll_canvas ()
 
 	} 
 
-	if (new_frame != leftmost_frame) {
-		reset_x_origin (new_frame);
-	}
-
-	vertical_adjustment.set_value (new_pixel);
-
-	if (autoscroll_x_distance != 0) {
-
-		if (autoscroll_cnt == 50) { /* 0.5 seconds */
-			
-			/* after about a while, speed up a bit by changing the timeout interval */
-			
-			autoscroll_x_distance = (nframes64_t) floor (current_page_frames()/30.0f);
-			
-		} else if (autoscroll_cnt == 150) { /* 1.0 seconds */
-			
-			autoscroll_x_distance = (nframes64_t) floor (current_page_frames()/20.0f);
-			
-		} else if (autoscroll_cnt == 300) { /* 1.5 seconds */
-			
-			/* after about another while, speed up by increasing the shift per callback */
-			
-			autoscroll_x_distance =  (nframes64_t) floor (current_page_frames()/10.0f);
-			
-		} 
-	}
-
-	if (autoscroll_y_distance != 0) {
-
-		if (autoscroll_cnt == 50) { /* 0.5 seconds */
-			
-			/* after about a while, speed up a bit by changing the timeout interval */
-			
-			autoscroll_y_distance = 10;
-			
-		} else if (autoscroll_cnt == 150) { /* 1.0 seconds */
-			
-			autoscroll_y_distance = 20;
-			
-		} else if (autoscroll_cnt == 300) { /* 1.5 seconds */
-			
-			/* after about another while, speed up by increasing the shift per callback */
-			
-			autoscroll_y_distance =  40;
-		} 
-	}
-
 	return true;
 }
 
@@ -777,6 +794,7 @@ Editor::start_canvas_autoscroll (int dx, int dy)
 void
 Editor::stop_canvas_autoscroll ()
 {
+
 	if (autoscroll_timeout_tag >= 0) {
 		g_source_remove (autoscroll_timeout_tag);
 		autoscroll_timeout_tag = -1;
@@ -804,34 +822,64 @@ Editor::entered_track_canvas (GdkEventCrossing *ev)
 void
 Editor::tie_vertical_scrolling ()
 {
-	double y1 = vertical_adjustment.get_value();
-
-	playhead_cursor->set_y_axis (y1);
-
- 	range_marker_drag_rect->property_y1() = y1;
- 	range_marker_drag_rect->property_y2() = full_canvas_height;
- 	transport_loop_range_rect->property_y1() = y1;
- 	transport_loop_range_rect->property_y2() = full_canvas_height;
- 	transport_punch_range_rect->property_y1() = y1;
- 	transport_punch_range_rect->property_y2() = full_canvas_height;
- 	transport_punchin_line->property_y1() = y1;
- 	transport_punchin_line->property_y2() = full_canvas_height;
- 	transport_punchout_line->property_y1() = y1;
- 	transport_punchout_line->property_y2() = full_canvas_height;
-
-	if (!selection->markers.empty()) {
-		for (MarkerSelection::iterator x = selection->markers.begin(); x != selection->markers.end(); ++x) {		
-			(*x)->set_line_vpos (y1, canvas_height);
-		}
-	}
-
-	if (logo_item) {
-		logo_item->property_y() = y1;
-	}
+	scroll_canvas_vertically ();
 
 	/* this will do an immediate redraw */
 
-	controls_layout.get_vadjustment()->set_value (y1);
+	controls_layout.get_vadjustment()->set_value (vertical_adjustment.get_value());
+}
+
+void
+Editor::scroll_canvas_horizontally ()
+{
+	nframes64_t time_origin = (nframes64_t) floor (horizontal_adjustment.get_value() * frames_per_unit);
+
+	if (time_origin != leftmost_frame) {
+		canvas_scroll_to (time_origin);
+	}
+
+	/* horizontal scrolling only */
+	double x1, x2, y1, y2, x_delta;
+
+	_master_group->get_bounds(x1, y1, x2, y2);
+	x_delta = x1 + horizontal_adjustment.get_value();
+
+	_master_group->move (-x_delta, 0);
+	timebar_group->move (-x_delta, 0);
+	time_line_group->move (-x_delta, 0);
+	cursor_group->move (-x_delta, 0);
+
+	update_fixed_rulers ();
+	redisplay_tempo (true);
+
+#ifndef GTKOSX
+	if (!autoscroll_active) {
+		/* force rulers and canvas to move in lock step */
+		while (gtk_events_pending ()) {
+			gtk_main_iteration ();
+		}
+	}
+#endif
+
+}
+
+void
+Editor::scroll_canvas_vertically ()
+{
+	/* vertical scrolling only */
+
+	double y_delta;
+
+	y_delta = last_trackview_group_vertical_offset - get_trackview_group_vertical_offset ();
+	_trackview_group->move (0, y_delta);
+	_background_group->move (0, y_delta);
+
+	for (TrackViewList::iterator i = track_views.begin(); i != track_views.end(); ++i) {
+		(*i)->clip_to_viewport ();
+	}
+	last_trackview_group_vertical_offset = get_trackview_group_vertical_offset ();
+	/* required to keep the controls_layout in lock step with the canvas group */
+	track_canvas->update_now ();
 }
 
 void 
@@ -842,27 +890,13 @@ Editor::canvas_horizontally_scrolled ()
 	if (time_origin != leftmost_frame) {
 		canvas_scroll_to (time_origin);
 	}
+	redisplay_tempo (true);
 }
 
 void
 Editor::canvas_scroll_to (nframes64_t time_origin)
 {
 	leftmost_frame = time_origin;
-
-	nframes64_t rightmost_frame = leftmost_frame + current_page_frames ();
-
-	if (rightmost_frame > last_canvas_frame) {
-		last_canvas_frame = rightmost_frame;
-		reset_scrolling_region ();
-	}
-
-	if (logo_item) {
-		logo_item->property_x() = horizontal_adjustment.get_value ();
-	}
-
-	update_fixed_rulers ();
-
-	redisplay_tempo (!_dragging_hscrollbar);
 }
 
 void
@@ -925,10 +959,12 @@ Editor::color_handler()
 	location_punch_color = ARDOUR_UI::config()->canvasvar_LocationPunch.get();
 
 	refresh_location_display ();
+/*
 	redisplay_tempo (true);
 
 	if (session)
 		session->tempo_map().apply_with_metrics (*this, &Editor::draw_metric_marks); // redraw metric markers
+*/
 }
 
 void
