@@ -682,7 +682,7 @@ Editor::build_new_transport_marker_menu ()
 	items.push_back (MenuElem (_("Set Loop Range"), mem_fun(*this, &Editor::new_transport_marker_menu_set_loop)));
 	items.push_back (MenuElem (_("Set Punch Range"), mem_fun(*this, &Editor::new_transport_marker_menu_set_punch)));
 
-	new_transport_marker_menu->signal_unmap_event().connect ( mem_fun(*this, &Editor::new_transport_marker_menu_popdown)); 
+	new_transport_marker_menu->signal_unmap().connect ( mem_fun(*this, &Editor::new_transport_marker_menu_popdown)); 
 }
 
 void
@@ -1112,14 +1112,12 @@ Editor::marker_menu_rename ()
 	commit_reversible_command ();
 }
 
-gint
-Editor::new_transport_marker_menu_popdown (GdkEventAny *ev)
+void
+Editor::new_transport_marker_menu_popdown ()
 {
 	// hide rects
 	transport_bar_drag_rect->hide();
 	range_marker_drag_rect->hide();
-
-	return FALSE;
 }
 
 void
@@ -1170,51 +1168,22 @@ Editor::update_punch_range_view (bool visibility)
 	Location* tpl;
 
 	if ((Config->get_punch_in() || Config->get_punch_out()) && ((tpl = transport_punch_location()) != 0)) {
-
-		double x1 = frame_to_pixel (tpl->start());
-		double x2 = frame_to_pixel (tpl->end());
-		
 		guint track_canvas_width,track_canvas_height;
 		track_canvas->get_size(track_canvas_width,track_canvas_height);
-		
-		transport_punch_range_rect->property_x1() = x1;
-		transport_punch_range_rect->property_x2() = x2;
-		
-		transport_punch_range_rect->property_x1() = (Config->get_punch_in() ? x1 : 0);
-		transport_punch_range_rect->property_x2() = (Config->get_punch_out() ? x2 : track_canvas_width);
+		if (Config->get_punch_in()) {
+			transport_punch_range_rect->property_x1() = frame_to_pixel (tpl->start());
+			transport_punch_range_rect->property_x2() = (Config->get_punch_out() ? frame_to_pixel (tpl->end()) : frame_to_pixel (JACK_MAX_FRAMES));
+		} else {
+			transport_punch_range_rect->property_x1() = 0;
+			transport_punch_range_rect->property_x2() = (Config->get_punch_out() ? frame_to_pixel (tpl->end()) : track_canvas_width);
+		}
 		
 		if (visibility) {
 		        transport_punch_range_rect->show();
 		}
-	}
-	else if (visibility) {
+	} else if (visibility) {
 	        transport_punch_range_rect->hide();
 	}
-
-// 	if (session->get_punch_in()) {
-// 		double x = frame_to_pixel (transport_punch_location->start());
-// 		gnome_canvas_item_set (transport_punchin_line, "x1", x, "x2", x, NULL);
-		
-// 		if (visibility) {
-// 			gnome_canvas_item_show (transport_punchin_line);
-// 		}
-// 	}
-// 	else if (visibility) {
-// 		gnome_canvas_item_hide (transport_punchin_line);
-// 	}
-	
-// 	if (session->get_punch_out()) {
-// 		double x = frame_to_pixel (transport_punch_location->end());
-		
-// 		gnome_canvas_item_set (transport_punchout_line, "x1", x, "x2", x, NULL);
-		
-// 		if (visibility) {
-// 			gnome_canvas_item_show (transport_punchout_line);
-// 		}
-// 	}
-// 	else if (visibility) {
-// 		gnome_canvas_item_hide (transport_punchout_line);
-// 	}
 }
 
 void
@@ -1245,7 +1214,7 @@ Editor::marker_selection_changed ()
 	}
 
 	for (MarkerSelection::iterator x = selection->markers.begin(); x != selection->markers.end(); ++x) {
-		(*x)->add_line (cursor_group, vertical_adjustment.get_value(), canvas_height);
+		(*x)->add_line (cursor_group, 0, canvas_height);
 		(*x)->show_line ();
 	}
 
