@@ -56,117 +56,158 @@ Editor::cms_deleted ()
 void
 Editor::show_editor_mixer (bool yn)
 {
+	boost::shared_ptr<ARDOUR::Route> r;
+
 	show_editor_mixer_when_tracks_arrive = false;
 
+	if (!session) {
+		show_editor_mixer_when_tracks_arrive = yn;
+		return;
+	}
+
 	if (yn) {
 
-		if (current_mixer_strip == 0) {
+		if (selection->tracks.empty()) {
+			
+			if (track_views.empty()) {	
+				show_editor_mixer_when_tracks_arrive = true;
+				return;
+			} 
 
-			if (selection->tracks.empty()) {
+			for (TrackViewList::iterator i = track_views.begin(); i != track_views.end(); ++i) {
+				AudioTimeAxisView* atv;
 				
-				if (track_views.empty()) {	
-					show_editor_mixer_when_tracks_arrive = true;
-					return;
-				} 
-				
-				for (TrackViewList::iterator i = track_views.begin(); i != track_views.end(); ++i) {
-					AudioTimeAxisView* atv;
-
-					if ((atv = dynamic_cast<AudioTimeAxisView*> (*i)) != 0) {
-						
-						current_mixer_strip = new MixerStrip (*ARDOUR_UI::instance()->the_mixer(),
-										      *session,
-										      atv->route(), false);
-
-						current_mixer_strip->GoingAway.connect (mem_fun(*this, &Editor::cms_deleted));						
-						break;
-					}
+				if ((atv = dynamic_cast<AudioTimeAxisView*> (*i)) != 0) {
+					r = atv->route();
+					break;
 				}
-
-			} else {
-
-				sort_track_selection ();
-
-				for (TrackSelection::iterator i = selection->tracks.begin(); i != selection->tracks.end(); ++i) {
-					AudioTimeAxisView* atv;
-
-					if ((atv = dynamic_cast<AudioTimeAxisView*> (*i)) != 0) {
-
-						current_mixer_strip = new MixerStrip (*ARDOUR_UI::instance()->the_mixer(),
-										      *session,
-										      atv->route(), false);
-						current_mixer_strip->GoingAway.connect (mem_fun(*this, &Editor::cms_deleted));						
-						break;
-					}
-				}
-
 			}
 
+		} else {
+
+			sort_track_selection ();
+			
+			for (TrackSelection::iterator i = selection->tracks.begin(); i != selection->tracks.end(); ++i) {
+				AudioTimeAxisView* atv;
+				
+				if ((atv = dynamic_cast<AudioTimeAxisView*> (*i)) != 0) {
+					r = atv->route();
+					break;
+				}
+			}
+		}
+
+		if (r) {
+			bool created;
+
 			if (current_mixer_strip == 0) {
-				return;
-			}		
+				create_editor_mixer ();
+				created = true;
+			} else {
+				created = false;
+			}
+
+			current_mixer_strip->set_route (r);
+
+			if (created) {
+				current_mixer_strip->set_width (editor_mixer_strip_width, (void*) this);
+			}
 		}
 		
 		if (current_mixer_strip->get_parent() == 0) {
-			current_mixer_strip->set_embedded (true);
-			current_mixer_strip->Hiding.connect (mem_fun(*this, &Editor::current_mixer_strip_hidden));
-			current_mixer_strip->GoingAway.connect (mem_fun(*this, &Editor::current_mixer_strip_removed));
-			current_mixer_strip->set_width (editor_mixer_strip_width, (void*) this);
-
 			global_hpacker.pack_start (*current_mixer_strip, Gtk::PACK_SHRINK );
  			global_hpacker.reorder_child (*current_mixer_strip, 0);
-
 			current_mixer_strip->show_all ();
 		}
 
 	} else {
 
 		if (current_mixer_strip) {
-		        editor_mixer_strip_width = current_mixer_strip->get_width ();
 			if (current_mixer_strip->get_parent() != 0) {
 				global_hpacker.remove (*current_mixer_strip);
 			}
 		}
 	}
+
+#ifdef GTKOSX
+	/* XXX gtk problem here */
+	ensure_all_elements_drawn();
+#endif
 }
 
+#ifdef GTKOSX
+void
+Editor::ensure_all_elements_drawn ()
+{
+	controls_layout.queue_draw ();
+	ruler_label_event_box.queue_draw ();
+	time_button_event_box.queue_draw ();
+}
+#endif
+
+void
+Editor::create_editor_mixer ()
+{
+	current_mixer_strip = new MixerStrip (*ARDOUR_UI::instance()->the_mixer(),
+					      *session,
+					      false);
+	current_mixer_strip->Hiding.connect (mem_fun(*this, &Editor::current_mixer_strip_hidden));
+	current_mixer_strip->GoingAway.connect (mem_fun(*this, &Editor::current_mixer_strip_removed));
+#ifdef GTKOSX
+	current_mixer_strip->WidthChanged.connect (mem_fun(*this, &Editor::ensure_all_elements_drawn));
+#endif
+	current_mixer_strip->set_embedded (true);
+}	
+
 void
 Editor::set_selected_mixer_strip (TimeAxisView& view)
 {
 	AudioTimeAxisView* at;
 	bool show = false;
+	bool created;
 
 	if (!session || (at = dynamic_cast<AudioTimeAxisView*>(&view)) == 0) {
 		return;
 	}
-	
-	if (current_mixer_strip) {
 
-		/* might be nothing to do */
-
-		if (current_mixer_strip->route() == at->route()) {
+	Glib::RefPtr<Gtk::Action> act = ActionManager::get_action (X_("Editor"), X_("show-editor-mixer"));
+	if (act) {
+		Glib::RefPtr<Gtk::ToggleAction> tact = Glib::RefPtr<Gtk::ToggleAction>::cast_dynamic(act);
+		if (!tact || !tact->get_active()) {
+			/* not showing mixer strip presently */
 			return;
 		}
-
-		if (current_mixer_strip->get_parent()) {
-			show = true;
-		}
-		delete current_mixer_strip;
-		current_mixer_strip = 0;
 	}
 
-	current_mixer_strip = new MixerStrip (*ARDOUR_UI::instance()->the_mixer(),
-					      *session,
-					      at->route(), false);
-	current_mixer_strip->GoingAway.connect (mem_fun(*this, &Editor::cms_deleted));
+	if (current_mixer_strip == 0) {
+		create_editor_mixer ();
+		created = true;
+	} else {
+		created = false;
+	}
+
+	/* might be nothing to do */
 	
+	if (current_mixer_strip->route() == at->route()) {
+		return;
+	}
+	
+	if (current_mixer_strip->get_parent()) {
+		show = true;
+	}
+
+	current_mixer_strip->set_route (at->route());
+
+	if (created) {
+		current_mixer_strip->set_width (editor_mixer_strip_width, (void*) this);
+	}
+
 	if (show) {
 		show_editor_mixer (true);
 	}
 }
 
 double current = 0.0;
-bool currentInitialized = 0;
 
 void
 Editor::update_current_screen ()
@@ -185,7 +226,7 @@ Editor::update_current_screen ()
 
 		if (_follow_playhead && session->requested_return_frame() < 0) {
 
-			playhead_cursor->canvas_item.show();
+			//playhead_cursor->canvas_item.show();
 
 			if (frame != last_update_frame) {
 
@@ -241,7 +282,6 @@ Editor::update_current_screen ()
 
 	  almost_done:
 		last_update_frame = frame;
-
 		if (current_mixer_strip) {
 			current_mixer_strip->fast_update ();
 		}
@@ -253,7 +293,7 @@ void
 Editor::current_mixer_strip_removed ()
 {
 	if (current_mixer_strip) {
-		/* it is being deleted */
+		/* it is being deleted elsewhere */
 		current_mixer_strip = 0;
 	}
 }
@@ -301,7 +341,8 @@ Editor::session_going_away ()
 	entered_track = 0;
 	last_update_frame = 0;
 	drag_info.item = 0;
-	last_canvas_frame = 0;
+
+	playhead_cursor->canvas_item.hide ();
 
 	/* hide all tracks */
 
@@ -331,10 +372,6 @@ Editor::session_going_away ()
 	zoom_range_clock.set_session (0);
 	nudge_clock.set_session (0);
 
-	/* put editor/mixer toggle button in off position and disable until a new session is loaded */
-
-	editor_mixer_button.set_active(false);
-	editor_mixer_button.set_sensitive(false);
 	/* clear tempo/meter rulers */
 	remove_metric_marks ();
 	hide_measures ();
