@@ -375,7 +375,7 @@ EngineControl::build_command_line (vector<string>& cmd)
 	if (str != _("Ignore")) {
 		double secs;
 		uint32_t msecs;
-		atof (str);
+		secs = atof (str);
 		msecs = (uint32_t) floor (secs * 1000.0);
 		cmd.push_back ("-t");
 		cmd.push_back (to_string (msecs, std::dec));
@@ -1151,7 +1151,7 @@ EngineControl::set_state (const XMLNode& root)
 	XMLNodeList          clist;
 	XMLNodeConstIterator citer;
 	XMLNode* child;
-	XMLProperty* prop;
+	XMLProperty* prop = NULL;
 	bool using_dummy = false;
 	
 	int val;
