@@ -43,6 +43,7 @@
 #include "ardour_ui.h"
 #include "public_editor.h"
 #include "keyboard.h"
+#include "nag.h"
 
 #include "i18n.h"
 
@@ -807,9 +808,9 @@ ExportDialog::export_cue_file (Locations::LocationList& locations, const string&
 	out << "TITLE \"" << session->name() << "\"" << endl;
 
 	if ((header_format_combo.get_active_text() == N_("WAV"))) {
-		  out << "FILE " << path  << " WAVE" << endl;
+		  out << "FILE \"" << path  << "\" WAVE" << endl;
 	} else {
-		  out << "FILE " << path  << ' ' << (header_format_combo.get_active_text()) << endl;
+		  out << "FILE \"" << path  << "\" " << (header_format_combo.get_active_text()) << endl;
 	}
 
 	if (false && numtracks == 0) {
@@ -947,7 +948,38 @@ ExportDialog::do_export ()
 		msg.run ();
 		return;
 	}
+
+	if (!wants_dir()) {
+
+		/* maybe add suffix */
 		
+		int file_format = sndfile_header_format_from_string (header_format_combo.get_active_text ());
+		
+		if ((file_format & SF_FORMAT_TYPEMASK) == SF_FORMAT_WAV) {
+			if (filepath.find (".wav") != filepath.length() - 4) {
+				filepath += ".wav";
+			}
+		} else if ((file_format & SF_FORMAT_TYPEMASK) == SF_FORMAT_AIFF) {
+			if (filepath.find (".aiff") != filepath.length() - 5) {
+				filepath += ".aiff";
+			}
+		} else if ((file_format & SF_FORMAT_TYPEMASK) == SF_FORMAT_W64) {
+			if (filepath.find (".w64") != filepath.length() - 5) {
+				filepath += ".w64";
+			}
+		} else if ((file_format & SF_FORMAT_TYPEMASK) == SF_FORMAT_FLAC) {
+			if (filepath.find (".flac") != filepath.length() - 5) {
+				filepath += ".flac";
+			}
+		} else if ((file_format & SF_FORMAT_TYPEMASK) == SF_FORMAT_CAF) {
+			if (filepath.find (".caf") != filepath.length() - 4) {
+				filepath += ".caf";
+			}
+		}
+
+		/* others ? */
+	}
+
 	if(!is_filepath_valid(filepath)){
 		return;
 	}
@@ -980,6 +1012,18 @@ ExportDialog::do_export ()
 	
   	progress_connection.disconnect ();
 	end_dialog ();
+
+	/* if not stopped early and not SAE, ask for money, maybe */
+
+	if (!spec.stop && !Profile->get_sae()) {
+
+		NagScreen* ns = NagScreen::maybe_nag (_("export"));
+		
+		if (ns) {
+			ns->nag ();
+			delete ns;
+		}
+	}
 }
 	
 void
@@ -1245,7 +1289,7 @@ ExportDialog::initSpec(string &filepath)
 	spec.format |= sndfile_header_format_from_string (header_format_combo.get_active_text ());
 
 	if (!Profile->get_sae()) {
-		if ((spec.format & SF_FORMAT_WAV) == 0) {
+		if (((spec.format & SF_FORMAT_TYPEMASK) != SF_FORMAT_WAV)) {
 			/* RIFF/WAV specifies endianess */
 			spec.format |= sndfile_endian_format_from_string (endian_format_combo.get_active_text ());
 		}
