@@ -18,6 +18,7 @@
 */
 
 #include <cstdlib>
+#include <signal.h>
 
 #include <sigc++/bind.h>
 #include <gtkmm/settings.h>
@@ -30,6 +31,7 @@
 
 #include <jack/jack.h>
 
+#include <ardour/svn_revision.h>
 #include <ardour/version.h>
 #include <ardour/ardour.h>
 #include <ardour/audioengine.h>
@@ -38,7 +40,6 @@
 #include <gtkmm2ext/popup.h>
 #include <gtkmm2ext/utils.h>
 
-#include "svn_revision.h"
 #include "version.h"
 #include "ardour_ui.h"
 #include "opts.h"
@@ -82,7 +83,10 @@ fixup_bundle_environment ()
 	Glib::ustring path;
 	const char *cstr = getenv ("PATH");
 
-	/* ensure that we find any bundled executables (e.g. JACK) */
+	/* ensure that we find any bundled executables (e.g. JACK),
+	   and find them before any instances of the same name
+	   elsewhere in PATH
+	*/
 
 	path = dir_path;
 	if (cstr) {
@@ -113,12 +117,18 @@ fixup_bundle_environment ()
 	setenv ("ARDOUR_CONFIG_PATH", path.c_str(), 1);
 	setenv ("ARDOUR_DATA_PATH", path.c_str(), 1);
 
+	path = dir_path;
+	path += "/../Resources";
+	setenv ("ARDOUR_INSTANT_XML_PATH", path.c_str(), 1);
+
 	cstr = getenv ("LADSPA_PATH");
 	if (cstr) {
 		path = cstr;
 		path += ':';
+	} else {
+		path = "";
 	}
-	path = dir_path;
+	path += dir_path;
 	path += "/../Plugins";
 	
 	setenv ("LADSPA_PATH", path.c_str(), 1);
@@ -127,8 +137,10 @@ fixup_bundle_environment ()
 	if (cstr) {
 		path = cstr;
 		path += ':';
+	} else {
+		path = "";
 	}
-	path = dir_path;
+	path += dir_path;
 	path += "/../Frameworks";
 	
 	setenv ("VAMP_PATH", path.c_str(), 1);
@@ -137,8 +149,10 @@ fixup_bundle_environment ()
 	if (cstr) {
 		path = cstr;
 		path += ':';
+	} else {
+		path = "";
 	}
-	path = dir_path;
+	path += dir_path;
 	path += "/../Surfaces";
 	
 	setenv ("ARDOUR_CONTROL_SURFACE_PATH", path.c_str(), 1);
@@ -147,8 +161,10 @@ fixup_bundle_environment ()
 	if (cstr) {
 		path = cstr;
 		path += ':';
+	} else {
+		path = "";
 	}
-	path = dir_path;
+	path += dir_path;
 	path += "/../Plugins";
 	
 	setenv ("LV2_PATH", path.c_str(), 1);
@@ -183,8 +199,11 @@ fixup_bundle_environment ()
 			error << string_compose (_("cannot open pango.rc file %1") , path) << endmsg;
 		} else {
 			pangorc << "[Pango]\nModuleFiles=";
-			Glib::ustring mpath = dir_path;
+			Glib::ustring mpath;
+
+			mpath = dir_path;
 			mpath += "/../Resources/pango.modules";
+
 			pangorc << mpath << endl;
 			
 			pangorc.close ();
@@ -222,6 +241,12 @@ fixup_bundle_environment ()
 
 #endif
 
+static void
+sigpipe_handler (int sig)
+{
+	cerr << _("SIGPIPE received - JACK has probably died") << endl;
+}
+
 #ifdef VST_SUPPORT
 /* this is called from the entry point of a wine-compiled
    executable that is linked against gtk2_ardour built
@@ -270,7 +295,7 @@ int main (int argc, char* argv[])
 	cout << _("Ardour/GTK ") 
 	     << VERSIONSTRING
 	     << _("\n   (built using ")
-	     << ardour_svn_revision
+	     << svn_revision
 #ifdef __GNUC__
 	     << _(" and GCC version ") << __VERSION__ 
 #endif
@@ -296,6 +321,10 @@ int main (int argc, char* argv[])
 
 	PBD::ID::init ();
 
+	if (::signal (SIGPIPE, sigpipe_handler)) {
+		cerr << _("Cannot install SIGPIPE error handler") << endl;
+	}
+
         try { 
 		ui = new ARDOUR_UI (&argc, &argv);
 	} catch (failed_constructor& err) {
