@@ -83,15 +83,15 @@ speed_printer (char buf[32], Gtk::Adjustment& adj, void* arg)
 }
 #endif 
 
-MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt, bool in_mixer)
+MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, bool in_mixer)
 	: AxisView(sess),
-	  RouteUI (rt, sess, _("Mute"), _("Solo"), _("Record")),
+	  RouteUI (sess, _("Mute"), _("Solo"), _("Record")),
 	  _mixer(mx),
 	  _mixer_owned (in_mixer),
-	  pre_redirect_box (PreFader, sess, rt, mx.plugin_selector(), mx.selection(), in_mixer),
-	  post_redirect_box (PostFader, sess, rt, mx.plugin_selector(), mx.selection(), in_mixer),
-	  gpm (_route, sess),
-	  panners (_route, sess),
+	  pre_redirect_box (PreFader, sess, mx.plugin_selector(), mx.selection(), in_mixer),
+	  post_redirect_box (PostFader, sess, mx.plugin_selector(), mx.selection(), in_mixer),
+	  gpm (sess),
+	  panners (sess),
 	  button_table (3, 2),
 	  middle_button_table (1, 2),
 	  bottom_button_table (1, 2),
@@ -101,10 +101,34 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	  speed_spinner (&speed_adjustment, "MixerStripSpeedBase", true)
 
 {
-	if (set_color_from_route()) {
-		set_color (unique_random_color());
-	}
+	init ();
+}
 
+MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt, bool in_mixer)
+	: AxisView(sess),
+	  RouteUI (sess, _("Mute"), _("Solo"), _("Record")),
+	  _mixer(mx),
+	  _mixer_owned (in_mixer),
+	  pre_redirect_box (PreFader, sess, mx.plugin_selector(), mx.selection(), in_mixer),
+	  post_redirect_box (PostFader, sess, mx.plugin_selector(), mx.selection(), in_mixer),
+	  gpm (sess),
+	  panners (sess),
+	  button_table (3, 2),
+	  middle_button_table (1, 2),
+	  bottom_button_table (1, 2),
+	  meter_point_label (_("pre")),
+	  comment_button (_("Comments")),
+	  speed_adjustment (1.0, 0.001, 4.0, 0.001, 0.1),
+	  speed_spinner (&speed_adjustment, "MixerStripSpeedBase", true)
+
+{
+	init ();
+	set_route (rt);
+}
+
+void
+MixerStrip::init ()
+{
 	input_selector = 0;
 	output_selector = 0;
 	group_menu = 0;
@@ -121,34 +145,22 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	hide_button.add (*(manage (new Gtk::Image (::get_icon("hide")))));
 
 	input_label.set_text (_("Input"));
+	ARDOUR_UI::instance()->set_tip (&input_button, _("Click to choose inputs"), "");
 	input_button.add (input_label);
 	input_button.set_name ("MixerIOButton");
 	input_label.set_name ("MixerIOButtonLabel");
 
 	output_label.set_text (_("Output"));
+	ARDOUR_UI::instance()->set_tip (&output_button, _("Click to choose outputs"), "");
 	output_button.add (output_label);
 	output_button.set_name ("MixerIOButton");
 	output_label.set_name ("MixerIOButtonLabel");
 
-	_route->meter_change.connect (mem_fun(*this, &MixerStrip::meter_changed));
+	ARDOUR_UI::instance()->set_tip (&meter_point_button, _("Select metering point"), "");
 	meter_point_button.add (meter_point_label);
 	meter_point_button.set_name ("MixerStripMeterPreButton");
 	meter_point_label.set_name ("MixerStripMeterPreButton");
 	
-	switch (_route->meter_point()) {
-	case MeterInput:
-		meter_point_label.set_text (_("input"));
-		break;
-		
-	case MeterPreFader:
-		meter_point_label.set_text (_("pre"));
-		break;
-		
-	case MeterPostFader:
-		meter_point_label.set_text (_("post"));
-		break;
-	}
-	
 	/* TRANSLATORS: this string should be longest of the strings
 	   used to describe meter points. In english, it's "input".
 	*/
@@ -180,55 +192,18 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	bottom_button_table.set_homogeneous (true);
 	bottom_button_table.attach (group_button, 0, 1, 0, 1);
 	
-	if (is_audio_track()) {
-		
-		rec_enable_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::rec_enable_press), false);
-		rec_enable_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::rec_enable_release));
-
-		rec_enable_button->set_name ("MixerRecordEnableButton");
-
-		boost::shared_ptr<AudioTrack> at = audio_track();
-
-		at->FreezeChange.connect (mem_fun(*this, &MixerStrip::map_frozen));
-
-#ifdef VARISPEED_IN_MIXER_STRIP
-		speed_adjustment.signal_value_changed().connect (mem_fun(*this, &MixerStrip::speed_adjustment_changed));
-		
-		speed_frame.set_name ("BaseFrame");
-		speed_frame.set_shadow_type (Gtk::SHADOW_IN);
-		speed_frame.add (speed_spinner);
-		
-		speed_spinner.set_print_func (speed_printer, 0);
-
-		ARDOUR_UI::instance()->tooltips().set_tip (speed_spinner, _("Varispeed"));
-
-		button_table.attach (speed_frame, 0, 2, 5, 6);
-#endif /* VARISPEED_IN_MIXER_STRIP */
-
-		button_table.attach (*rec_enable_button, 0, 2, 2, 3);
-	}
-
 	name_button.add (name_label);
 	name_button.set_name ("MixerNameButton");
 	Gtkmm2ext::set_size_request_to_display_given_text (name_button, "longest label", 2, 2);
 
 	name_label.set_name ("MixerNameButtonLabel");
-	if (_route->phase_invert()) {
-	        name_label.set_text (X_("Ø ") + name_label.get_text());
-	} else {
-	        name_label.set_text (_route->name());
-	}
-
+	ARDOUR_UI::instance()->set_tip (&group_button, _("Mix group"), "");
 	group_button.add (group_label);
 	group_button.set_name ("MixerGroupButton");
 	group_label.set_name ("MixerGroupButtonLabel");
 
 	comment_button.set_name ("MixerCommentButton");
 
-	ARDOUR_UI::instance()->tooltips().set_tip (comment_button, _route->comment()==""	?
-							_("Click to Add/Edit Comments"):
-							_route->comment());
-
 	comment_button.signal_clicked().connect (mem_fun(*this, &MixerStrip::comment_button_clicked));
 	
 	global_vpacker.set_border_width (0);
@@ -263,19 +238,6 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	global_vpacker.pack_start (output_button, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (comment_button, Gtk::PACK_SHRINK);
 
-	if (route()->master() || route()->control()) {
-		
-		if (scrollbar_height == 0) {
-			HScrollbar scrollbar;
-			Gtk::Requisition requisition(scrollbar.size_request ());
-			scrollbar_height = requisition.height;
-		}
-
-		EventBox* spacer = manage (new EventBox);
-		spacer->set_size_request (-1, scrollbar_height);
-		global_vpacker.pack_start (*spacer, false, false);
-	}
-
 	global_frame.add (global_vpacker);
 	global_frame.set_shadow_type (Gtk::SHADOW_IN);
 	global_frame.set_name ("BaseFrame");
@@ -292,22 +254,6 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 
 	_session.engine().Stopped.connect (mem_fun(*this, &MixerStrip::engine_stopped));
 	_session.engine().Running.connect (mem_fun(*this, &MixerStrip::engine_running));
-	_route->input_changed.connect (mem_fun(*this, &MixerStrip::input_changed));
-	_route->output_changed.connect (mem_fun(*this, &MixerStrip::output_changed));
-	_route->mute_changed.connect (mem_fun(*this, &RouteUI::mute_changed));
-	_route->solo_changed.connect (mem_fun(*this, &RouteUI::solo_changed));
-	_route->solo_safe_changed.connect (mem_fun(*this, &RouteUI::solo_changed));
-	_route->mix_group_changed.connect (mem_fun(*this, &MixerStrip::mix_group_changed));
-	_route->panner().Changed.connect (mem_fun(*this, &MixerStrip::connect_to_pan));
-
-	if (is_audio_track()) {
-		audio_track()->DiskstreamChanged.connect (mem_fun(*this, &MixerStrip::diskstream_changed));
-		get_diskstream()->SpeedChanged.connect (mem_fun(*this, &MixerStrip::speed_changed));
-	}
-
-	_route->name_changed.connect (mem_fun(*this, &RouteUI::name_changed));
-	_route->comment_changed.connect (mem_fun(*this, &MixerStrip::comment_changed));
-	_route->gui_changed.connect (mem_fun(*this, &MixerStrip::route_gui_changed));
 
 	input_button.signal_button_press_event().connect (mem_fun(*this, &MixerStrip::input_press), false);
 	output_button.signal_button_press_event().connect (mem_fun(*this, &MixerStrip::output_press), false);
@@ -317,11 +263,18 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	mute_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::mute_press), false);
 	mute_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::mute_release), false);
 
+	/* we don't need this if its not an audio track, but we don't know that yet and it doesn't
+	   hurt (much).
+	*/
+
+	rec_enable_button->set_name ("MixerRecordEnableButton");
+	rec_enable_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::rec_enable_press), false);
+	rec_enable_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::rec_enable_release));
+
 	name_button.signal_button_press_event().connect (mem_fun(*this, &MixerStrip::name_button_button_press), false);
 	group_button.signal_button_press_event().connect (mem_fun(*this, &MixerStrip::select_mix_group), false);
 
 	_width = (Width) -1;
-	set_stuff_from_route ();
 
 	/* start off as a passthru strip. we'll correct this, if necessary,
 	   in update_diskstream_display().
@@ -329,6 +282,140 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 
 	set_name ("AudioTrackStripBase");
 
+	add_events (Gdk::BUTTON_RELEASE_MASK);
+}
+
+MixerStrip::~MixerStrip ()
+{
+	GoingAway(); /* EMIT_SIGNAL */
+
+	if (input_selector) {
+		delete input_selector;
+	}
+
+	if (output_selector) {
+		delete output_selector;
+	}
+}
+
+void
+MixerStrip::set_route (boost::shared_ptr<Route> rt)
+{
+	if (rec_enable_button->get_parent()) {
+		button_table.remove (*rec_enable_button);
+	}
+
+#ifdef VARISPEED_IN_MIXER_STRIP
+	if (speed_frame->get_parent()) {
+		button_table.remove (*speed_frame);
+	}
+#endif
+
+	RouteUI::set_route (rt);
+
+	if (input_selector) {
+		delete input_selector;
+		input_selector = 0;
+	}
+
+	if (output_selector) {
+		delete output_selector;
+		output_selector = 0;
+	}
+
+	panners.set_io (rt);
+	gpm.set_io (rt);
+	pre_redirect_box.set_route (rt);
+	post_redirect_box.set_route (rt);
+
+	if (set_color_from_route()) {
+		set_color (unique_random_color());
+	}
+
+	if (_mixer_owned && (route()->master() || route()->control())) {
+		
+		if (scrollbar_height == 0) {
+			HScrollbar scrollbar;
+			Gtk::Requisition requisition(scrollbar.size_request ());
+			scrollbar_height = requisition.height;
+		}
+
+		EventBox* spacer = manage (new EventBox);
+		spacer->set_size_request (-1, scrollbar_height);
+		global_vpacker.pack_start (*spacer, false, false);
+	}
+
+	if (is_audio_track()) {
+
+		boost::shared_ptr<AudioTrack> at = audio_track();
+
+		connections.push_back (at->FreezeChange.connect (mem_fun(*this, &MixerStrip::map_frozen)));
+
+#ifdef VARISPEED_IN_MIXER_STRIP
+		speed_adjustment.signal_value_changed().connect (mem_fun(*this, &MixerStrip::speed_adjustment_changed));
+		
+		speed_frame.set_name ("BaseFrame");
+		speed_frame.set_shadow_type (Gtk::SHADOW_IN);
+		speed_frame.add (speed_spinner);
+		
+		speed_spinner.set_print_func (speed_printer, 0);
+
+		ARDOUR_UI::instance()->tooltips().set_tip (speed_spinner, _("Varispeed"));
+
+		button_table.attach (speed_frame, 0, 2, 5, 6);
+#endif /* VARISPEED_IN_MIXER_STRIP */
+
+		button_table.attach (*rec_enable_button, 0, 2, 2, 3);
+		rec_enable_button->show();
+	}
+
+	if (_route->phase_invert()) {
+	        name_label.set_text (X_("Ø ") + name_label.get_text());
+	} else {
+	        name_label.set_text (_route->name());
+	}
+
+	switch (_route->meter_point()) {
+	case MeterInput:
+		meter_point_label.set_text (_("input"));
+		break;
+		
+	case MeterPreFader:
+		meter_point_label.set_text (_("pre"));
+		break;
+		
+	case MeterPostFader:
+		meter_point_label.set_text (_("post"));
+		break;
+	}
+
+	delete route_ops_menu;
+	route_ops_menu = 0;
+	
+	ARDOUR_UI::instance()->tooltips().set_tip (comment_button, _route->comment().empty() ?
+						   _("Click to Add/Edit Comments"):
+						   _route->comment());
+
+	connections.push_back (_route->meter_change.connect (mem_fun(*this, &MixerStrip::meter_changed)));
+	connections.push_back (_route->input_changed.connect (mem_fun(*this, &MixerStrip::input_changed)));
+	connections.push_back (_route->output_changed.connect (mem_fun(*this, &MixerStrip::output_changed)));
+	connections.push_back (_route->mute_changed.connect (mem_fun(*this, &RouteUI::mute_changed)));
+	connections.push_back (_route->solo_changed.connect (mem_fun(*this, &RouteUI::solo_changed)));
+	connections.push_back (_route->solo_safe_changed.connect (mem_fun(*this, &RouteUI::solo_changed)));
+	connections.push_back (_route->mix_group_changed.connect (mem_fun(*this, &MixerStrip::mix_group_changed)));
+	connections.push_back (_route->panner().Changed.connect (mem_fun(*this, &MixerStrip::connect_to_pan)));
+
+	if (is_audio_track()) {
+		connections.push_back (audio_track()->DiskstreamChanged.connect (mem_fun(*this, &MixerStrip::diskstream_changed)));
+		connections.push_back (get_diskstream()->SpeedChanged.connect (mem_fun(*this, &MixerStrip::speed_changed)));
+	}
+
+	connections.push_back (_route->name_changed.connect (mem_fun(*this, &RouteUI::name_changed)));
+	connections.push_back (_route->comment_changed.connect (mem_fun(*this, &MixerStrip::comment_changed)));
+	connections.push_back (_route->gui_changed.connect (mem_fun(*this, &MixerStrip::route_gui_changed)));
+
+	set_stuff_from_route ();
+
 	/* now force an update of all the various elements */
 
 	pre_redirect_box.update();
@@ -350,21 +437,6 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt
 	update_diskstream_display ();
 	update_input_display ();
 	update_output_display ();
-
-	add_events (Gdk::BUTTON_RELEASE_MASK);
-}
-
-MixerStrip::~MixerStrip ()
-{
-	GoingAway(); /* EMIT_SIGNAL */
-
-	if (input_selector) {
-		delete input_selector;
-	}
-
-	if (output_selector) {
-		delete output_selector;
-	}
 }
 
 void
@@ -414,20 +486,19 @@ MixerStrip::set_width (Width w, void* owner)
 
 	switch (w) {
 	case Wide:
-		set_size_request (-1, -1);
-		
+
 		if (rec_enable_button)  {
-			((Gtk::Label*)rec_enable_button->get_child())->set_text (_("record"));
+			((Gtk::Label*)rec_enable_button->get_child())->set_text (_("Record"));
 		}
 		((Gtk::Label*)mute_button->get_child())->set_text  (_("Mute"));
 		((Gtk::Label*)solo_button->get_child())->set_text (_("Solo"));
 
 		if (_route->comment() == "") {
 		       comment_button.unset_bg (STATE_NORMAL);
-		       ((Gtk::Label*)comment_button.get_child())->set_text (_("comments"));
+		       ((Gtk::Label*)comment_button.get_child())->set_text (_("Comments"));
 		} else {
 		       comment_button.modify_bg (STATE_NORMAL, color());
-		       ((Gtk::Label*)comment_button.get_child())->set_text (_("*comments*"));
+		       ((Gtk::Label*)comment_button.get_child())->set_text (_("*Comments*"));
 		}
 
 		((Gtk::Label*)gpm.gain_automation_style_button.get_child())->set_text (gpm.astyle_string(_route->gain_automation_curve().automation_style()));
@@ -435,6 +506,7 @@ MixerStrip::set_width (Width w, void* owner)
 		((Gtk::Label*)panners.pan_automation_style_button.get_child())->set_text (panners.astyle_string(_route->panner().automation_style()));
 		((Gtk::Label*)panners.pan_automation_state_button.get_child())->set_text (panners.astate_string(_route->panner().automation_state()));
 		Gtkmm2ext::set_size_request_to_display_given_text (name_button, "long", 2, 2);
+		set_size_request (-1, -1);
 		break;
 
 	case Narrow:
@@ -460,12 +532,13 @@ MixerStrip::set_width (Width w, void* owner)
 		set_size_request (max (50, gpm.get_gm_width()), -1);
 		break;
 	}
-
 	update_input_display ();
 	update_output_display ();
 	mix_group_changed (0);
 	name_changed (0);
-
+#ifdef GTKOSX
+	WidthChanged();
+#endif
 }
 
 void
@@ -734,6 +807,7 @@ MixerStrip::update_output_display ()
 			break;
 		}
 	}
+
 	gpm.setup_meters ();
 	panners.setup_pan ();
 }
@@ -967,7 +1041,7 @@ void
 MixerStrip::build_route_ops_menu ()
 {
 	using namespace Menu_Helpers;
-	route_ops_menu = manage (new Menu);
+	route_ops_menu = new Menu;
 	route_ops_menu->set_name ("ArdourContextMenu");
 
 	MenuList& items = route_ops_menu->items();
@@ -985,11 +1059,10 @@ MixerStrip::build_route_ops_menu ()
 	denormal_menu_item = dynamic_cast<CheckMenuItem *> (&items.back());
 	denormal_menu_item->set_active (_route->denormal_protection());
 
-	build_remote_control_menu ();
-	
-	items.push_back (SeparatorElem());
 	if (!Profile->get_sae()) {
-              items.push_back (MenuElem (_("Remote Control ID"), *remote_control_menu));
+		build_remote_control_menu ();
+		items.push_back (SeparatorElem());
+		items.push_back (MenuElem (_("Remote Control ID"), *remote_control_menu));
         }
 
 	items.push_back (SeparatorElem());
@@ -999,7 +1072,7 @@ MixerStrip::build_route_ops_menu ()
 gint
 MixerStrip::name_button_button_press (GdkEventButton* ev)
 {
-	if (ev->button == 1) {
+	if (ev->button == 1 || ev->button == 3) {
 		list_route_operations ();
 
 		Menu_Helpers::MenuList& items = route_ops_menu->items();
@@ -1213,23 +1286,23 @@ MixerStrip::meter_changed (void *src)
 
 	ENSURE_GUI_THREAD (bind (mem_fun(*this, &MixerStrip::meter_changed), src));
 
-		switch (_route->meter_point()) {
-		case MeterInput:
-			meter_point_label.set_text (_("input"));
-			break;
-			
-		case MeterPreFader:
-			meter_point_label.set_text (_("pre"));
-			break;
-			
-		case MeterPostFader:
-			meter_point_label.set_text (_("post"));
-			break;
-		}
-
-		gpm.setup_meters ();
-		// reset peak when meter point changes
-		gpm.reset_peak_display();
-		set_width(_width, this);
+	switch (_route->meter_point()) {
+	case MeterInput:
+		meter_point_label.set_text (_("input"));
+		break;
+		
+	case MeterPreFader:
+		meter_point_label.set_text (_("pre"));
+		break;
+		
+	case MeterPostFader:
+		meter_point_label.set_text (_("post"));
+		break;
+	}
+	
+	gpm.setup_meters ();
+	// reset peak when meter point changes
+	gpm.reset_peak_display();
+	set_width (_width, this);
 }
 
