@@ -59,7 +59,6 @@ using namespace std;
 
 using PBD::atoi;
 
-
 Mixer_UI::Mixer_UI ()
 	: Window (Gtk::WINDOW_TOPLEVEL)
 {
@@ -70,8 +69,8 @@ Mixer_UI::Mixer_UI ()
 	no_track_list_redisplay = false;
 	in_group_row_change = false;
 	_visible = false;
-	ignore_route_reorder = false;
-	ignore_sync = false;
+	strip_redisplay_does_not_reset_order_keys = false;
+	strip_redisplay_does_not_sync_order_keys = false;
 
 	Route::SyncOrderKeys.connect (mem_fun (*this, &Mixer_UI::sync_order_keys));
 
@@ -192,8 +191,12 @@ Mixer_UI::Mixer_UI ()
 	list_vpacker.pack_start (rhs_pane1, true, true);
 
 	global_hpacker.pack_start (scroller, true, true);
+#ifdef GTKOSX
+	/* current gtk-quartz has dirty updates on borders like this one */
+	global_hpacker.pack_start (out_packer, false, false, 0);
+#else
 	global_hpacker.pack_start (out_packer, false, false, 12);
-
+#endif
 	list_hpane.add1(list_vpacker);
 	list_hpane.add2(global_hpacker);
 
@@ -241,18 +244,19 @@ void
 Mixer_UI::show_window ()
 {
 	show_all ();
+	if (!_visible) {
+		set_window_pos_and_size ();
 
-	set_window_pos_and_size ();
-
-	/* now reset each strips width so the right widgets are shown */
-	MixerStrip* ms;
-
-	TreeModel::Children rows = track_model->children();
-	TreeModel::Children::iterator ri;
-
-	for (ri = rows.begin(); ri != rows.end(); ++ri) {
-		ms = (*ri)[track_columns.strip];
-		ms->set_width (ms->get_width(), ms->width_owner());
+		/* now reset each strips width so the right widgets are shown */
+		MixerStrip* ms;
+		
+		TreeModel::Children rows = track_model->children();
+		TreeModel::Children::iterator ri;
+		
+		for (ri = rows.begin(); ri != rows.end(); ++ri) {
+			ms = (*ri)[track_columns.strip];
+			ms->set_width (ms->get_width(), ms->width_owner());
+		}
 	}
 	_visible = true;
 }
@@ -274,6 +278,9 @@ Mixer_UI::add_strip (Session::RouteList& routes)
 	
 	MixerStrip* strip;
 
+	no_track_list_redisplay = true;
+	strip_redisplay_does_not_sync_order_keys = true;
+
 	for (Session::RouteList::iterator x = routes.begin(); x != routes.end(); ++x) {
 		boost::shared_ptr<Route> route = (*x);
 
@@ -292,26 +299,30 @@ Mixer_UI::add_strip (Session::RouteList& routes)
 
 		show_strip (strip);
 		
-		no_track_list_redisplay = true;
-		
 		TreeModel::Row row = *(track_model->append());
 		row[track_columns.text] = route->name();
-		
 		row[track_columns.visible] = strip->marked_for_display();
 		row[track_columns.route] = route;
 		row[track_columns.strip] = strip;
-
-		strip->set_old_order_key (track_model->children().size() - 1);
-
-		no_track_list_redisplay = false;
-		redisplay_track_list ();
+		
+		if (route->order_key (N_("signal")) == -1) {
+			route->set_order_key (N_("signal"), track_model->children().size()-1);
+		}
 		
 		route->name_changed.connect (bind (mem_fun(*this, &Mixer_UI::strip_name_changed), strip));
 
 		strip->GoingAway.connect (bind (mem_fun(*this, &Mixer_UI::remove_strip), strip));
-		
+#ifdef GTKOSX
+		strip->WidthChanged.connect (mem_fun(*this, &Mixer_UI::queue_draw_all_strips));
+#endif	
 		strip->signal_button_release_event().connect (bind (mem_fun(*this, &Mixer_UI::strip_button_release_event), strip));
 	}
+
+	no_track_list_redisplay = false;
+
+	redisplay_track_list ();
+	
+	strip_redisplay_does_not_sync_order_keys = false;
 }
 
 void
@@ -327,13 +338,7 @@ Mixer_UI::remove_strip (MixerStrip* strip)
 		strips.erase (i);
 	}
 
-	/* Decrement old order keys for strips `above' the one that is being removed */
-	for (ri = rows.begin(); ri != rows.end(); ++ri) {
-		MixerStrip* s = (*ri)[track_columns.strip];
-		if (s->old_order_key() > strip->old_order_key()) {
-			s->set_old_order_key (s->old_order_key() - 1);
-		}
-	}
+	strip_redisplay_does_not_sync_order_keys = true;
 
 	for (ri = rows.begin(); ri != rows.end(); ++ri) {
 		if ((*ri)[track_columns.strip] == strip) {
@@ -341,27 +346,32 @@ Mixer_UI::remove_strip (MixerStrip* strip)
 			break;
 		}
 	}
+
+	strip_redisplay_does_not_sync_order_keys = false;
 }
 
 const char*
 Mixer_UI::get_order_key() 
 {
+	return X_("signal");
+#if 0
 	if (Config->get_sync_all_route_ordering()) {
 		return X_("editor");
 	} else {
 		return X_("signal");
 	}
+#endif
 }
 
 
 void
-Mixer_UI::sync_order_keys ()
+Mixer_UI::sync_order_keys (const char *src)
 {
 	vector<int> neworder;
 	TreeModel::Children rows = track_model->children();
 	TreeModel::Children::iterator ri;
 
-	if (ignore_sync || !session || (session->state_of_the_state() & Session::Loading) || rows.empty()) {
+	if ((strcmp (src, get_order_key()) == 0) || !session || (session->state_of_the_state() & Session::Loading) || rows.empty()) {
 		return;
 	}
 
@@ -369,15 +379,26 @@ Mixer_UI::sync_order_keys ()
 		neworder.push_back (0);
 	}
 
-	for (ri = rows.begin(); ri != rows.end(); ++ri) {
+	bool changed = false;
+	int order;
+
+	for (order = 0, ri = rows.begin(); ri != rows.end(); ++ri, ++order) {
 		boost::shared_ptr<Route> route = (*ri)[track_columns.route];
-		MixerStrip* strip = (*ri)[track_columns.strip];
-		neworder[route->order_key (get_order_key())] = strip->old_order_key ();
+		int old_key = order;
+		int new_key = route->order_key (get_order_key());
+
+		neworder[new_key] = old_key;
+
+		if (new_key != old_key) {
+			changed = true;
+		}
 	}
 
-	ignore_route_reorder = true;
-	track_model->reorder (neworder);
-	ignore_route_reorder = false;
+	if (changed) {
+		strip_redisplay_does_not_reset_order_keys = true;
+		track_model->reorder (neworder);
+		strip_redisplay_does_not_reset_order_keys = false;
+	}
 }
 
 
@@ -627,20 +648,26 @@ Mixer_UI::hide_all_audiotracks ()
 void
 Mixer_UI::track_list_reorder (const TreeModel::Path& path, const TreeModel::iterator& iter, int* new_order)
 {
+	strip_redisplay_does_not_sync_order_keys = true;
 	session->set_remote_control_ids();
 	redisplay_track_list ();
+	strip_redisplay_does_not_sync_order_keys = false;
 }
 
 void
 Mixer_UI::track_list_change (const Gtk::TreeModel::Path& path,const Gtk::TreeModel::iterator& iter)
 {
+	// never reset order keys because of a property change
+	strip_redisplay_does_not_reset_order_keys = true; 
 	session->set_remote_control_ids();
 	redisplay_track_list ();
+	strip_redisplay_does_not_reset_order_keys = false;
 }
 
 void
 Mixer_UI::track_list_delete (const Gtk::TreeModel::Path& path)
 {
+	/* this could require an order sync */
 	session->set_remote_control_ids();
 	redisplay_track_list ();
 }
@@ -671,12 +698,10 @@ Mixer_UI::redisplay_track_list ()
 		if (visible) {
 			strip->set_marked_for_display (true);
 
-			if (!ignore_route_reorder) {
+			if (!strip_redisplay_does_not_reset_order_keys) {
 				strip->route()->set_order_key (get_order_key(), order);
 			} 
 
-			strip->set_old_order_key (order);
-
 			if (strip->packed()) {
 
 				if (strip->route()->master() || strip->route()->control()) {
@@ -709,19 +734,41 @@ Mixer_UI::redisplay_track_list ()
 		}
 	}
 	
-	if (Config->get_sync_all_route_ordering() && !ignore_route_reorder) {
-		ignore_sync = true;
-		Route::SyncOrderKeys (); // EMIT SIGNAL
-		ignore_sync = false;
+	if (!strip_redisplay_does_not_reset_order_keys && !strip_redisplay_does_not_sync_order_keys) {
+		session->sync_order_keys (get_order_key());
 	}
 
 	// Rebind all of the midi controls automatically
 	
-	if (auto_rebinding)
+	if (auto_rebinding) {
 		auto_rebind_midi_controls ();
-
+	}
 }
 
+#ifdef GTKOSX
+void
+Mixer_UI::queue_draw_all_strips ()
+{
+	TreeModel::Children rows = track_model->children();
+	TreeModel::Children::iterator i;
+	long order;
+
+	for (order = 0, i = rows.begin(); i != rows.end(); ++i, ++order) {
+		MixerStrip* strip = (*i)[track_columns.strip];
+
+		if (strip == 0) {
+			continue;
+		}
+
+		bool visible = (*i)[track_columns.visible];
+		
+		if (visible) {
+			strip->queue_draw();
+		}
+	}
+}
+#endif
+
 void
 Mixer_UI::set_auto_rebinding( bool val )
 {
@@ -875,6 +922,9 @@ Mixer_UI::track_display_button_press (GdkEventButton* ev)
 					bool visible = (*iter)[track_columns.visible];
 					(*iter)[track_columns.visible] = !visible;
 				}
+#ifdef GTKOSX
+				track_display.queue_draw();
+#endif
 			}
 		}
 		return true;
@@ -970,6 +1020,9 @@ Mixer_UI::group_display_button_press (GdkEventButton* ev)
 			if ((iter = group_model->get_iter (path))) {
 				if ((group = (*iter)[group_columns.group]) != 0) {
 					// edit_mix_group (group);
+#ifdef GTKOSX
+					group_display.queue_draw();
+#endif
 					return true;
 				}
 			}
@@ -981,6 +1034,9 @@ Mixer_UI::group_display_button_press (GdkEventButton* ev)
 		if ((iter = group_model->get_iter (path))) {
 			bool active = (*iter)[group_columns.active];
 			(*iter)[group_columns.active] = !active;
+#ifdef GTKOSX
+			group_display.queue_draw();
+#endif
 			return true;
 		}
 		break;
@@ -989,6 +1045,9 @@ Mixer_UI::group_display_button_press (GdkEventButton* ev)
 		if ((iter = group_model->get_iter (path))) {
 			bool visible = (*iter)[group_columns.visible];
 			(*iter)[group_columns.visible] = !visible;
+#ifdef GTKOSX
+			group_display.queue_draw();
+#endif
 			return true;
 		}
 		break;
@@ -1237,19 +1296,41 @@ Mixer_UI::set_state (const XMLNode& node)
 	const XMLProperty* prop;
 	XMLNode* geometry;
 	
-	if ((geometry = find_named_node (node, "geometry")) == 0) {
+	m_width = default_width;
+	m_height = default_height;
+	m_root_x = 1;
+	m_root_y = 1;
+	
+	if ((geometry = find_named_node (node, "geometry")) != 0) {
 
-		m_width = default_width;
-		m_height = default_height;
-		m_root_x = 1;
-		m_root_y = 1;
+		XMLProperty* prop;
 
-	} else {
+		if ((prop = geometry->property("x_size")) == 0) {
+			prop = geometry->property ("x-size");
+		}
+		if (prop) {
+			m_width = atoi(prop->value());
+		}
+		if ((prop = geometry->property("y_size")) == 0) {
+			prop = geometry->property ("y-size");
+		}
+		if (prop) {
+			m_height = atoi(prop->value());
+		}
 
-		m_width = atoi(geometry->property("x_size")->value().c_str());
-		m_height = atoi(geometry->property("y_size")->value().c_str());
-		m_root_x = atoi(geometry->property("x_pos")->value().c_str());
-		m_root_y = atoi(geometry->property("y_pos")->value().c_str());
+		if ((prop = geometry->property ("x_pos")) == 0) {
+			prop = geometry->property ("x-pos");
+		}
+		if (prop) {
+			m_root_x = atoi (prop->value());
+			
+		}
+		if ((prop = geometry->property ("y_pos")) == 0) {
+			prop = geometry->property ("y-pos");
+		}
+		if (prop) {
+			m_root_y = atoi (prop->value());
+		}
 	}
 
 	set_window_pos_and_size ();
@@ -1325,12 +1406,24 @@ Mixer_UI::pane_allocation_handler (Allocation& alloc, Gtk::Paned* which)
 	int width, height;
 	static int32_t done[3] = { 0, 0, 0 };
 
-	if ((geometry = find_named_node (*node, "geometry")) == 0) {
-		width = default_width;
-		height = default_height;
-	} else {
-		width = atoi(geometry->property("x_size")->value());
-		height = atoi(geometry->property("y_size")->value());
+	width = default_width;
+	height = default_height;
+
+	if ((geometry = find_named_node (*node, "geometry")) != 0) {
+
+
+		if ((prop = geometry->property ("x_size")) == 0) {
+			prop = geometry->property ("x-size");
+		}
+		if (prop) {
+			width = atoi (prop->value());
+		}
+		if ((prop = geometry->property ("y_size")) == 0) {
+			prop = geometry->property ("y-size");
+		}
+		if (prop) {
+			height = atoi (prop->value());
+		}
 	}
 
 	if (which == static_cast<Gtk::Paned*> (&rhs_pane1)) {
