@@ -28,6 +28,7 @@
 #include <ardour/auditioner.h>
 #include <ardour/sndfilesource.h>
 #include <ardour/crossfade.h>
+#include <ardour/profile.h>
 #include <midi++/manager.h>
 #include <midi++/factory.h>
 #include <gtkmm2ext/stop_signal.h>
@@ -95,6 +96,8 @@ OptionEditor::OptionEditor (ARDOUR_UI& uip, PublicEditor& ed, Mixer_UI& mixui)
 	  mmc_send_device_id_adjustment (0.0, 0.0, (double) 0x7f, 1.0, 16.0),
 	  mmc_send_device_id_spinner (mmc_send_device_id_adjustment),
 	  add_midi_port_button (_("Add new MIDI port")),
+	  initial_program_change_adjustment (0.0, -1.0, (double) 0x7f, 1.0, 16.0),
+	  initial_program_change_spinner (initial_program_change_adjustment),
 
 	  /* Click */
 
@@ -146,9 +149,11 @@ OptionEditor::OptionEditor (ARDOUR_UI& uip, PublicEditor& ed, Mixer_UI& mixui)
 	setup_keyboard_options ();
 	setup_auditioner_editor ();
 
-	notebook.pages().push_back (TabElem (sync_packer, _("Sync")));
-	notebook.pages().push_back (TabElem (path_table, _("Paths/Files")));
-	notebook.pages().push_back (TabElem (keyboard_mouse_table, _("Kbd/Mouse")));
+	if (!Profile->get_sae()) {
+		notebook.pages().push_back (TabElem (sync_packer, _("Sync")));
+		notebook.pages().push_back (TabElem (path_table, _("Paths/Files")));
+		notebook.pages().push_back (TabElem (keyboard_mouse_table, _("Kbd/Mouse")));
+	}
 	notebook.pages().push_back (TabElem (click_packer, _("Click")));
 	notebook.pages().push_back (TabElem (audition_packer, _("Audition")));
 	notebook.pages().push_back (TabElem (misc_packer, _("Misc")));
@@ -527,9 +532,26 @@ OptionEditor::setup_midi_options ()
 
 	mmc_send_device_id_spinner.set_value(Config->get_mmc_send_device_id ());
 
+	hbox = manage (new HBox);
+	hbox->set_border_width (6);
+	hbox->set_spacing (6);
+	label = (manage (new Label (_("Startup program change")))); 
+	hbox->pack_start (initial_program_change_spinner, false, false);
+	hbox->pack_start (*label, false, false);
+	midi_packer.pack_start (*hbox, false, false);
+
+	initial_program_change_spinner.set_value (Config->get_initial_program_change());
+	initial_program_change_adjustment.signal_value_changed().connect (mem_fun (*this, &OptionEditor::initial_program_change_adjusted));
+
 	add_midi_port_button.signal_clicked().connect (mem_fun (*this, &OptionEditor::add_midi_port));
 }
 
+void
+OptionEditor::initial_program_change_adjusted ()
+{
+	Config->set_initial_program_change (((int32_t) floor (initial_program_change_adjustment.get_value())) & 0x7f);
+}
+
 void
 OptionEditor::redisplay_midi_ports ()
 {
@@ -1056,7 +1078,8 @@ OptionEditor::setup_click_editor ()
 	click_emphasis_path_entry.set_sensitive (true);
 
 	click_io_selector = new IOSelector (*session, session->click_io(), false);
-	click_gpm = new GainMeter (session->click_io(), *session);
+	click_gpm = new GainMeter (*session);
+	click_gpm->set_io (session->click_io());
 
 	click_hpacker.pack_start (*click_io_selector, false, false);
 	click_hpacker.pack_start (*click_gpm, false, false);
@@ -1098,7 +1121,8 @@ void
 OptionEditor::connect_audition_editor ()
 {
 	auditioner_io_selector = new IOSelector (*session, session->the_auditioner(), false);
-	auditioner_gpm = new GainMeter (session->the_auditioner(), *session);
+	auditioner_gpm = new GainMeter (*session);
+	auditioner_gpm->set_io (session->the_auditioner());
 
 	audition_hpacker.pack_start (*auditioner_io_selector, false, false);
 	audition_hpacker.pack_start (*auditioner_gpm, false, false);
