@@ -306,7 +306,7 @@ PluginSelector::ladspa_refiller (const std::string& filterstr)
 void
 PluginSelector::lv2_refiller (const std::string& filterstr)
 {
-#ifdef HAVE_SLV2
+#ifdef HAVE_LV2
 	refiller (manager->lv2_plugin_info(), filterstr, "LV2");
 #endif
 }
@@ -491,10 +491,12 @@ PluginSelector::plugin_menu()
 
 	if (!_menu) {
 		_menu = new Menu();
+		_menu->set_name("ArdourContextMenu");
 	} 
 
 	MenuList& items = _menu->items();
 	Menu* favs = new Menu();
+	favs->set_name("ArdourContextMenu");
 
 	items.clear ();
 	items.push_back (MenuElem (_("Favorites"), *favs));
@@ -510,7 +512,7 @@ PluginSelector::plugin_menu()
 #ifdef HAVE_AUDIOUNITS
 	all_plugs.insert (all_plugs.end(), manager->au_plugin_info().begin(), manager->au_plugin_info().end());
 #endif
-#ifdef HAVE_SLV2
+#ifdef HAVE_LV2
 	all_plugs.insert (all_plugs.end(), manager->lv2_plugin_info().begin(), manager->lv2_plugin_info().end());
 #endif
 
@@ -539,6 +541,7 @@ PluginSelector::plugin_menu()
 			submenu = new Gtk::Menu;
 			items.push_back (MenuElem (creator, *submenu));
 			submenu_map.insert (pair<Glib::ustring,Menu*> (creator, submenu));
+			submenu->set_name("ArdourContextMenu");
 		}
 		
 		submenu->items().push_back (MenuElem ((*i)->name, (bind (mem_fun (*this, &PluginSelector::plugin_chosen_from_menu), *i))));
