@@ -42,6 +42,10 @@
 #ifdef VST_SUPPORT
 #include <ardour/vst_plugin.h>
 #endif
+#ifdef HAVE_LV2
+#include <ardour/lv2_plugin.h>
+#include "lv2_plugin_ui.h"
+#endif
 
 #include <lrdf.h>
 
@@ -83,6 +87,10 @@ PluginUIWindow::PluginUIWindow (Gtk::Window* win, boost::shared_ptr<PluginInsert
 			error << _("Eh? LADSPA plugins don't have editors!") << endmsg;
 			break;
 
+		case ARDOUR::LV2:
+			have_gui = create_lv2_editor (insert);
+			break;
+
 		default:
 #ifndef VST_SUPPORT
 			error << _("unknown type of editor-supplying plugin (note: no VST support in this version of ardour)")
@@ -162,6 +170,22 @@ PluginUIWindow::on_leave_notify_event (GdkEventCrossing *ev)
 	return false;
 }
 
+bool
+PluginUIWindow::on_focus_in_event (GdkEventFocus *ev)
+{
+	Window::on_focus_in_event (ev);
+	//Keyboard::the_keyboard().magic_widget_grab_focus ();
+	return false;
+}
+
+bool
+PluginUIWindow::on_focus_out_event (GdkEventFocus *ev)
+{
+	Window::on_focus_out_event (ev);
+	//Keyboard::the_keyboard().magic_widget_drop_focus ();
+	return false;
+}
+
 void
 PluginUIWindow::on_show ()
 {
@@ -248,12 +272,32 @@ PluginUIWindow::app_activated (bool yn)
 }
 
 bool
-PluginUIWindow::on_key_press_event (GdkEventKey* event)
+PluginUIWindow::create_lv2_editor(boost::shared_ptr<PluginInsert> insert)
 {
-	if (non_gtk_gui) {
-		return false;
+#ifndef HAVE_LV2
+	return false;
+#else
+
+	boost::shared_ptr<LV2Plugin> vp;
+	
+	if ((vp = boost::dynamic_pointer_cast<LV2Plugin> (insert->plugin())) == 0) {
+		error << _("create_lv2_editor called on non-LV2 plugin") << endmsg;
+		throw failed_constructor ();
+	} else {
+		LV2PluginUI* lpu = new LV2PluginUI (insert, vp);
+		_pluginui = lpu;
+		add (*lpu);
+		lpu->package (*this);
 	}
 
+	non_gtk_gui = false;
+	return true;
+#endif
+}
+
+bool
+PluginUIWindow::on_key_press_event (GdkEventKey* event)
+{
 	if (!key_press_focus_accelerator_handler (*this, event)) {
 		return PublicEditor::instance().on_key_press_event(event);
 	} else {
@@ -298,13 +342,26 @@ PlugUIBase::PlugUIBase (boost::shared_ptr<PluginInsert> pi)
 
 	bypass_button.set_name ("PluginBypassButton");
 	bypass_button.signal_toggled().connect (mem_fun(*this, &PlugUIBase::bypass_toggled));
+	focus_button.add_events (Gdk::ENTER_NOTIFY_MASK|Gdk::LEAVE_NOTIFY_MASK);
+
+	focus_button.signal_button_release_event().connect (mem_fun(*this, &PlugUIBase::focus_toggled));
+	focus_button.add_events (Gdk::ENTER_NOTIFY_MASK|Gdk::LEAVE_NOTIFY_MASK);
+
+	/* these images are not managed, so that we can remove them at will */
+
+	focus_out_image = new Image (get_icon (X_("computer_keyboard")));
+	focus_in_image = new Image (get_icon (X_("computer_keyboard_active")));
+	
+	focus_button.add (*focus_out_image);
+
+	ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to focus all keyboard events on this plugin window"), "");
+	ARDOUR_UI::instance()->set_tip (&bypass_button, _("Click to enable/disable this plugin"), "");
 }
 
 void
 PlugUIBase::redirect_active_changed (Redirect* r, void* src)
 {
 	ENSURE_GUI_THREAD(bind (mem_fun(*this, &PlugUIBase::redirect_active_changed), r, src));
-	bypass_button.set_active (!r->active());
 }
 
 void
@@ -324,6 +381,7 @@ PlugUIBase::save_plugin_setting ()
 	prompter.set_prompt(_("Name of New Preset:"));
 	prompter.add_button (Gtk::Stock::ADD, Gtk::RESPONSE_ACCEPT);
 	prompter.set_response_sensitive (Gtk::RESPONSE_ACCEPT, false);
+	prompter.set_type_hint (Gdk::WINDOW_TYPE_HINT_UTILITY);
 
 	prompter.show_all();
 
@@ -351,14 +409,29 @@ PlugUIBase::bypass_toggled ()
 
 	if ((x = bypass_button.get_active()) == insert->active()) {
 		insert->set_active (!x, this);
-		if (insert->active()) {
-			bypass_button.set_label (_("Bypass"));
-		} else {
-			bypass_button.set_label (_("Active"));
-		}
 	}
 }
 
+bool
+PlugUIBase::focus_toggled (GdkEventButton* ev)
+{
+	if (Keyboard::the_keyboard().some_magic_widget_has_focus()) {
+		Keyboard::the_keyboard().magic_widget_drop_focus();
+		focus_button.remove ();
+		focus_button.add (*focus_out_image);
+		focus_out_image->show ();
+		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to focus all keyboard events on this plugin window"), "");
+	} else {
+		Keyboard::the_keyboard().magic_widget_grab_focus();
+		focus_button.remove ();
+		focus_button.add (*focus_in_image);
+		focus_in_image->show ();
+		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to remove keyboard focus from this plugin window"), "");
+	}
+
+	return true;
+}
+
 void
 PlugUIBase::update_presets ()
 {
