@@ -34,6 +34,7 @@
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/label.h>
 #include <gtkmm/menu.h>
+#include <gtkmm/image.h>
 #include <gtkmm/adjustment.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/socket.h>
@@ -85,9 +86,14 @@ class PlugUIBase : public virtual sigc::trackable
 	Gtk::ComboBoxText preset_combo;
 	Gtk::Button save_button;
 	Gtk::ToggleButton bypass_button;
+	Gtk::EventBox focus_button;
+
+	Gtk::Image* focus_out_image;
+	Gtk::Image* focus_in_image;
 
 	void setting_selected();
 	void save_plugin_setting (void);
+	bool focus_toggled(GdkEventButton*);
 	void bypass_toggled();
 	void redirect_active_changed (ARDOUR::Redirect* r, void* src);
 };
@@ -188,8 +194,6 @@ class GenericPluginUI : public PlugUIBase, public Gtk::VBox
 	void control_port_toggled (ControlUI* cui);
 	void control_combo_changed (ControlUI* cui);
 
-	void redirect_active_changed (ARDOUR::Redirect*, void*);
-
 	void astate_clicked (ControlUI*, uint32_t parameter);
 	void automation_state_changed (ControlUI*);
 	void set_automation_state (ARDOUR::AutoState state, ControlUI* cui);
@@ -212,6 +216,8 @@ class PluginUIWindow : public Gtk::Window
 
 	bool on_enter_notify_event (GdkEventCrossing*);
 	bool on_leave_notify_event (GdkEventCrossing*);
+	bool on_focus_in_event (GdkEventFocus*);
+	bool on_focus_out_event (GdkEventFocus*);
 	bool on_key_press_event (GdkEventKey*);
 	bool on_key_release_event (GdkEventKey*);
 	void on_show ();
@@ -231,6 +237,7 @@ class PluginUIWindow : public Gtk::Window
 
 	bool create_vst_editor (boost::shared_ptr<ARDOUR::PluginInsert>);
 	bool create_audiounit_editor (boost::shared_ptr<ARDOUR::PluginInsert>);
+	bool create_lv2_editor (boost::shared_ptr<ARDOUR::PluginInsert>);
 };
 
 #ifdef VST_SUPPORT
