@@ -147,6 +147,7 @@ class PublicEditor : public Gtk::Window, public PBD::StatefulThingWithGoingAway
 	virtual void toggle_follow_playhead () = 0;
 	virtual bool follow_playhead() const = 0;
 	virtual bool dragging_playhead() const = 0;
+	virtual double get_physical_screen_width() const = 0;
 	virtual void ensure_float (Gtk::Window&) = 0;
 	virtual void show_window () = 0;
 	virtual TrackViewList* get_valid_views (TimeAxisView*, ARDOUR::RouteGroup* grp = 0) = 0;
@@ -223,7 +224,12 @@ class PublicEditor : public Gtk::Window, public PBD::StatefulThingWithGoingAway
 	static const int container_border_width;
 	static const int vertical_spacing;
 	static const int horizontal_spacing;
-	
+
+	virtual gdouble get_trackview_group_vertical_offset () const = 0;
+	virtual gdouble get_canvas_timebars_vsize () const = 0;
+	virtual ArdourCanvas::Group* get_background_group () const = 0;
+	virtual ArdourCanvas::Group* get_trackview_group () const = 0;
+
 	static PublicEditor* _instance;
 
 	friend class PluginUIWindow;
