@@ -83,10 +83,9 @@ bool RedirectBox::get_colors = true;
 Gdk::Color* RedirectBox::active_redirect_color;
 Gdk::Color* RedirectBox::inactive_redirect_color;
 
-RedirectBox::RedirectBox (Placement pcmnt, Session& sess, boost::shared_ptr<Route> rt, PluginSelector &plugsel, 
-			  RouteRedirectSelection & rsel, bool owner_is_mixer)
-	: _route(rt), 
-	  _session(sess), 
+RedirectBox::RedirectBox (Placement pcmnt, Session& sess, PluginSelector &plugsel, 
+			  RouteRedirectSelection& rsel, bool owner_is_mixer)
+	: _session(sess), 
 	  _owner_is_mixer (owner_is_mixer), 
 	  _placement(pcmnt), 
 	  _plugin_selector(plugsel),
@@ -122,7 +121,7 @@ RedirectBox::RedirectBox (Placement pcmnt, Session& sess, boost::shared_ptr<Rout
 	redirect_display.get_column(0)->set_sizing(TREE_VIEW_COLUMN_FIXED);
 	redirect_display.get_column(0)->set_fixed_width(48);
 	redirect_display.add_object_drag (columns.redirect.index(), "redirects");
-	redirect_display.signal_object_drop.connect (mem_fun (*this, &RedirectBox::object_drop));
+	redirect_display.signal_drop.connect (mem_fun (*this, &RedirectBox::object_drop));
 
 	TreeViewColumn* name_col = redirect_display.get_column(0);
 	CellRendererText* renderer = dynamic_cast<CellRendererText*>(redirect_display.get_column_cell_renderer (0));
@@ -139,27 +138,29 @@ RedirectBox::RedirectBox (Placement pcmnt, Session& sess, boost::shared_ptr<Rout
 
 	pack_start (redirect_eventbox, true, true);
 
-	_route->redirects_changed.connect (mem_fun(*this, &RedirectBox::redisplay_redirects));
-	_route->GoingAway.connect (mem_fun (*this, &RedirectBox::route_going_away));
-
 	redirect_eventbox.signal_enter_notify_event().connect (bind (sigc::ptr_fun (RedirectBox::enter_box), this));
 
 	redirect_display.signal_button_press_event().connect (mem_fun(*this, &RedirectBox::redirect_button_press_event), false);
 	redirect_display.signal_button_release_event().connect (mem_fun(*this, &RedirectBox::redirect_button_release_event));
-
-	/* start off as a passthru strip. we'll correct this, if necessary,
-	   in update_diskstream_display().
-	*/
-
-	/* now force an update of all the various elements */
-
-	redisplay_redirects (0);
 }
 
 RedirectBox::~RedirectBox ()
 {
 }
 
+void
+RedirectBox::set_route (boost::shared_ptr<Route> r)
+{
+	connections.clear ();
+
+	_route = r;
+
+	connections.push_back (_route->redirects_changed.connect (mem_fun(*this, &RedirectBox::redisplay_redirects)));
+	connections.push_back (_route->GoingAway.connect (mem_fun (*this, &RedirectBox::route_going_away)));
+
+	redisplay_redirects (0);
+}
+
 void
 RedirectBox::route_going_away ()
 {
@@ -168,20 +169,8 @@ RedirectBox::route_going_away ()
 }
 
 void
-RedirectBox::object_drop (string type, uint32_t cnt, const boost::shared_ptr<Redirect>* ptr)
+RedirectBox::object_drop (const list<boost::shared_ptr<Redirect> >& redirects)
 {
-	if (type != "redirects" || cnt == 0 || !ptr) {
-		return;
-	}
-
-	/* do something with the dropped redirects */
-
-	list<boost::shared_ptr<Redirect> > redirects;
-	
-	for (uint32_t n = 0; n < cnt; ++n) {
-		redirects.push_back (ptr[n]);
-	}
-	
 	paste_redirect_list (redirects);
 }
 
@@ -191,7 +180,6 @@ RedirectBox::update()
 	redisplay_redirects (0);
 }
 
-
 void
 RedirectBox::set_width (Width w)
 {
@@ -199,7 +187,9 @@ RedirectBox::set_width (Width w)
 		return;
 	}
 	_width = w;
-
+	if (w == -1) {
+		abort ();
+	}
 	redisplay_redirects (0);
 }
 
@@ -313,6 +303,12 @@ RedirectBox::redirect_button_press_event (GdkEventButton *ev)
 
 		// this is purely informational but necessary
 		RedirectSelected (redirect); // emit
+
+	} else if (!redirect && ev->button == 1 && ev->type == GDK_2BUTTON_PRESS) {
+
+		choose_plugin ();
+		_plugin_selector.show_manager ();
+
 	}
 	
 	return ret;
@@ -346,7 +342,7 @@ RedirectBox::redirect_button_release_event (GdkEventButton *ev)
 		show_redirect_menu(ev->time);
 		ret = true;
 
-	} else if (redirect && (ev->button == 2) && (Keyboard::no_modifier_keys_pressed (ev) && ((ev->state & Gdk::BUTTON2_MASK) == Gdk::BUTTON2_MASK))) {
+	} else if (redirect && Keyboard::is_button2_event (ev) && (Keyboard::no_modifier_keys_pressed (ev) && ((ev->state & Gdk::BUTTON2_MASK) == Gdk::BUTTON2_MASK))) {
 		
 		/* button2-click with no modifiers */
 
@@ -402,6 +398,10 @@ RedirectBox::use_plugins (const SelectedPlugins& plugins)
 		boost::shared_ptr<Redirect> redirect (new PluginInsert (_session, *p, _placement));
 
 		uint32_t err_streams;
+
+		if (Config->get_new_plugins_active()) {
+			redirect->set_active (true, this);
+		}
 		
 		if (_route->add_redirect (redirect, this, &err_streams)) {
 			weird_plugin_dialog (**p, err_streams, _route);
@@ -528,6 +528,9 @@ RedirectBox::send_io_finished (IOSelector::Result r, boost::weak_ptr<Redirect> w
 
 	case IOSelector::Accepted:
 		_route->add_redirect (redirect, this);
+		if (Profile->get_sae()) {
+			redirect->set_active (true, 0);
+		}
 		break;
 	}
 
@@ -571,6 +574,7 @@ RedirectBox::add_redirect_to_display (boost::shared_ptr<Redirect> redirect)
 	}
 	
 	Gtk::TreeModel::Row row = *(model->append());
+
 	row[columns.text] = redirect_name (redirect);
 	row[columns.redirect] = redirect;
 
@@ -681,6 +685,7 @@ RedirectBox::show_redirect_active (boost::weak_ptr<Redirect> weak_redirect)
 		boost::shared_ptr<Redirect> r = (*iter)[columns.redirect];
 
 		if (r == redirect) {
+			
 			(*iter)[columns.text] = redirect_name (r);
 			
 			if (redirect->active()) {
@@ -811,8 +816,9 @@ RedirectBox::copy_redirects ()
 	}
 
 	for (vector<boost::shared_ptr<Redirect> >::iterator i = to_be_copied.begin(); i != to_be_copied.end(); ++i) {
-		// Do not copy inserts or sends
-		if (boost::dynamic_pointer_cast<PluginInsert>((*i)) != 0) {
+		// Do not copy inserts 
+		if ((boost::dynamic_pointer_cast<PluginInsert>((*i)) != 0) ||
+		    (boost::dynamic_pointer_cast<Send>((*i)) != 0)) {
 			copies.push_back (Redirect::clone (*i));
 		}
   	}
@@ -939,11 +945,11 @@ RedirectBox::paste_redirects ()
 }
 
 void
-RedirectBox::paste_redirect_list (list<boost::shared_ptr<Redirect> >& redirects)
+RedirectBox::paste_redirect_list (const list<boost::shared_ptr<Redirect> >& redirects)
 {
 	list<boost::shared_ptr<Redirect> > copies;
 
-	for (list<boost::shared_ptr<Redirect> >::iterator i = redirects.begin(); i != redirects.end(); ++i) {
+	for (list<boost::shared_ptr<Redirect> >::const_iterator i = redirects.begin(); i != redirects.end(); ++i) {
 
 		boost::shared_ptr<Redirect> copy = Redirect::clone (*i);
 
