@@ -105,8 +105,9 @@ RouteTimeAxisView::RouteTimeAxisView (PublicEditor& ed, Session& sess, boost::sh
 	  size_button (_("h")), // height
 	  automation_button (_("a")),
 	  visual_button (_("v")),
-	  gm (rt, sess, slider, true)
+	  gm (sess, slider, true)
 {
+	gm.set_io (rt);
 	gm.get_level_meter().set_no_show_all();
 	gm.get_level_meter().setup_meters(50);
 
@@ -129,6 +130,13 @@ RouteTimeAxisView::RouteTimeAxisView (PublicEditor& ed, Session& sess, boost::sh
 	visual_button.set_name ("TrackVisualButton");
 	hide_button.set_name ("TrackRemoveButton");
 
+	edit_group_button.unset_flags (Gtk::CAN_FOCUS);
+	playlist_button.unset_flags (Gtk::CAN_FOCUS);
+	automation_button.unset_flags (Gtk::CAN_FOCUS);
+	size_button.unset_flags (Gtk::CAN_FOCUS);
+	visual_button.unset_flags (Gtk::CAN_FOCUS);
+	hide_button.unset_flags (Gtk::CAN_FOCUS);
+
 	hide_button.add (*(manage (new Image (::get_icon("hide")))));
 	hide_button.show_all ();
 
@@ -140,9 +148,9 @@ RouteTimeAxisView::RouteTimeAxisView (PublicEditor& ed, Session& sess, boost::sh
 	hide_button.signal_clicked().connect (mem_fun(*this, &RouteTimeAxisView::hide_click));
 
 	solo_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::solo_press), false);
-	solo_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::solo_release));
+	solo_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::solo_release), false);
 	mute_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::mute_press), false);
-	mute_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::mute_release));
+	mute_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::mute_release), false);
 
 	if (is_track()) {
 
@@ -442,11 +450,10 @@ RouteTimeAxisView::build_display_menu ()
 
 	items.push_back (SeparatorElem());
 
-	build_remote_control_menu ();
-	build_automation_action_menu ();
-
 	if (!Profile->get_sae()) {
+		build_remote_control_menu ();
 		items.push_back (MenuElem (_("Remote Control ID"), *remote_control_menu));
+		build_automation_action_menu ();
 		items.push_back (MenuElem (_("Automation"), *automation_action_menu));
 		items.push_back (SeparatorElem());
 	}
@@ -506,7 +513,12 @@ RouteTimeAxisView::build_display_menu ()
 
 	items.push_back (SeparatorElem());
 	items.push_back (MenuElem (_("Hide"), mem_fun(*this, &RouteTimeAxisView::hide_click)));
-	items.push_back (MenuElem (_("Remove"), mem_fun(*this, &RouteUI::remove_this_route)));
+	if (!Profile->get_sae()) {
+		items.push_back (MenuElem (_("Remove"), mem_fun(*this, &RouteUI::remove_this_route)));
+	} else {
+		items.push_front (SeparatorElem());
+		items.push_front (MenuElem (_("Delete"), mem_fun(*this, &RouteUI::remove_this_route)));
+	}
 }
 
 static bool __reset_item (RadioMenuItem* item)
@@ -745,6 +757,18 @@ RouteTimeAxisView::set_height (uint32_t h)
 	} else {
 
 		hide_meter ();
+
+		/* don't allow name_entry to be hidden while
+		   it has focus, otherwise the GUI becomes unusable.
+		*/
+
+		if (name_entry.has_focus()) {
+			if (name_entry.get_text() != _route->name()) {
+				name_entry_changed ();
+			}
+			controls_ebox.grab_focus ();
+		}
+
 		hide_name_entry ();
 		show_name_label ();
 		
@@ -874,8 +898,43 @@ RouteTimeAxisView::rename_current_playlist ()
 	}
 }
 
+std::string 
+RouteTimeAxisView::resolve_new_group_playlist_name(std::string &basename, vector<boost::shared_ptr<Playlist> > const & playlists)
+{
+	std::string ret(basename);
+
+	std::string group_string = "."+edit_group()->name()+".";
+
+	// iterate through all playlists
+	int maxnumber = 0;
+	for (vector<boost::shared_ptr<Playlist> >::const_iterator i = playlists.begin(); i != playlists.end(); ++i) {
+		std::string tmp = (*i)->name();
+
+		std::string::size_type idx = tmp.find(group_string);			
+		// find those which belong to this group
+		if (idx != string::npos) {
+			tmp = tmp.substr(idx + group_string.length());
+
+			// and find the largest current number
+			int x = atoi(tmp.c_str());
+			if (x > maxnumber) {
+				maxnumber = x;
+			}
+		}
+	}
+
+	maxnumber++;
+
+	char buf[32];
+	snprintf (buf, sizeof(buf), "%d", maxnumber);
+               
+	ret = this->name()+"."+edit_group()->name()+"."+buf;
+
+	return ret;
+}
+
 void
-RouteTimeAxisView::use_copy_playlist (bool prompt)
+RouteTimeAxisView::use_copy_playlist (bool prompt, vector<boost::shared_ptr<Playlist> > const & playlists_before_op)
 {
 	string name;
 	
@@ -888,10 +947,14 @@ RouteTimeAxisView::use_copy_playlist (bool prompt)
 		return;
 
 	name = pl->name();
+	
+	if (edit_group() && edit_group()->is_active()) {
+		name = resolve_new_group_playlist_name(name, playlists_before_op);
+	}
 
-	do {
+	while (_session.playlist_by_name(name)) {
 		name = Playlist::bump_name (name, _session);
-	} while (_session.playlist_by_name(name));
+	}
 
 	// TODO: The prompter "new" button should be de-activated if the user
 	// specifies a playlist name which already exists in the session.
@@ -923,7 +986,7 @@ RouteTimeAxisView::use_copy_playlist (bool prompt)
 }
 
 void
-RouteTimeAxisView::use_new_playlist (bool prompt)
+RouteTimeAxisView::use_new_playlist (bool prompt, vector<boost::shared_ptr<Playlist> > const & playlists_before_op)
 {
 	string name;
 	
@@ -936,10 +999,14 @@ RouteTimeAxisView::use_new_playlist (bool prompt)
 		return;
 
 	name = pl->name();
+	
+	if (edit_group() && edit_group()->is_active()) {
+		name = resolve_new_group_playlist_name(name,playlists_before_op);
+	}
 
-	do {
+	while (_session.playlist_by_name(name)) {
 		name = Playlist::bump_name (name, _session);
-	} while (_session.playlist_by_name(name));
+	}
 
 
 	if (prompt) {
@@ -1337,8 +1404,17 @@ RouteTimeAxisView::build_playlist_menu (Gtk::Menu * menu)
 	playlist_items.push_back (MenuElem (_("Rename"), mem_fun(*this, &RouteTimeAxisView::rename_current_playlist)));
 	playlist_items.push_back (SeparatorElem());
 
-	playlist_items.push_back (MenuElem (_("New"), bind(mem_fun(editor, &PublicEditor::new_playlists), this)));
-	playlist_items.push_back (MenuElem (_("New Copy"), bind(mem_fun(editor, &PublicEditor::copy_playlists), this)));
+	if (!edit_group() || !edit_group()->is_active()) {
+		playlist_items.push_back (MenuElem (_("New"), bind(mem_fun(editor, &PublicEditor::new_playlists), this)));
+		playlist_items.push_back (MenuElem (_("New Copy"), bind(mem_fun(editor, &PublicEditor::copy_playlists), this)));
+
+	} else {
+		// Use a label which tells the user what is happening
+		playlist_items.push_back (MenuElem (_("New Take"), bind(mem_fun(editor, &PublicEditor::new_playlists), this)));
+		playlist_items.push_back (MenuElem (_("Copy Take"), bind(mem_fun(editor, &PublicEditor::copy_playlists), this)));
+		
+	}
+
 	playlist_items.push_back (SeparatorElem());
 	playlist_items.push_back (MenuElem (_("Clear Current"), bind(mem_fun(editor, &PublicEditor::clear_playlists), this)));
 	playlist_items.push_back (SeparatorElem());
@@ -1360,7 +1436,51 @@ RouteTimeAxisView::use_playlist (boost::weak_ptr<Playlist> wpl)
 	boost::shared_ptr<AudioPlaylist> apl = boost::dynamic_pointer_cast<AudioPlaylist> (pl);
 	
 	if (apl) {
+		if (get_diskstream()->playlist() == apl) {
+			// radio button cotnrols mean this function is called for both the 
+			// old and new playlist
+			return;
+		}
 		get_diskstream()->use_playlist (apl);
+
+
+		if (edit_group() && edit_group()->is_active()) {
+			//PBD::stacktrace(cerr, 20);
+			std::string group_string = "."+edit_group()->name()+".";
+
+			std::string take_name = apl->name();
+			std::string::size_type idx = take_name.find(group_string);
+
+			if (idx == std::string::npos)
+				return;
+
+			take_name = take_name.substr(idx + group_string.length()); // find the bit containing the take number / name
+			
+			for (list<Route*>::const_iterator i = edit_group()->route_list().begin(); i != edit_group()->route_list().end(); ++i) {
+				if ( (*i) == this->route().get()) {
+					continue;
+				}
+				
+				std::string playlist_name = (*i)->name()+group_string+take_name;
+
+				Track *track = dynamic_cast<Track *>(*i);
+				if (!track) {
+					std::cerr << "route " << (*i)->name() << " is not a Track" << std::endl;
+					continue;
+				}
+
+				boost::shared_ptr<Playlist> ipl = session().playlist_by_name(playlist_name);
+				if (!ipl) {
+					// No playlist for this track for this take yet, make it
+					track->diskstream()->use_new_playlist();
+					track->diskstream()->playlist()->set_name(playlist_name);
+				} else {
+					track->diskstream()->use_playlist(ipl);
+				}
+				
+				//(*i)->get_dis
+			}
+		}
 	}
 }
 
@@ -1726,6 +1846,7 @@ RouteTimeAxisView::redirect_menu_item_toggled (RouteTimeAxisView::RedirectAutoma
 		if (showit) {
 			ran->view->set_marked_for_display (true);
 			ran->view->canvas_display->show();
+			ran->view->canvas_background->show();
 		} else {
 			rai->redirect->mark_automation_visible (ran->what, true);
 			ran->view->set_marked_for_display (false);
