@@ -22,6 +22,7 @@
 #include <gtkmm2ext/choice.h>
 #include <gtkmm2ext/doi.h>
 #include <gtkmm2ext/bindable_button.h>
+#include <gtkmm2ext/gtk_ui.h>
 
 #include <ardour/route_group.h>
 #include <pbd/memento_command.h>
@@ -39,6 +40,7 @@
 #include <ardour/audioengine.h>
 #include <ardour/audio_track.h>
 #include <ardour/audio_diskstream.h>
+#include <ardour/profile.h>
 
 #include "i18n.h"
 using namespace sigc;
@@ -47,13 +49,24 @@ using namespace Gtkmm2ext;
 using namespace ARDOUR;
 using namespace PBD;
 
-RouteUI::RouteUI (boost::shared_ptr<ARDOUR::Route> rt, ARDOUR::Session& sess, const char* m_name,
-		  const char* s_name, const char* r_name)
-	: AxisView(sess),
-	  _route(rt),
-	  mute_button(0),
-	  solo_button(0),
-	  rec_enable_button(0)
+RouteUI::RouteUI (ARDOUR::Session& sess, const char* mute_name, const char* solo_name, const char* rec_name)
+	: AxisView(sess)
+{
+	init ();
+	set_button_names (mute_name, solo_name, rec_name);
+}
+
+RouteUI::RouteUI (boost::shared_ptr<ARDOUR::Route> rt, 
+		  ARDOUR::Session& sess, const char* mute_name, const char* solo_name, const char* rec_name)
+	: AxisView(sess)
+{
+	init ();
+	set_button_names (mute_name, solo_name, rec_name);
+	set_route (rt);
+}
+
+void
+RouteUI::init ()
 {
 	xml_node = 0;
 	mute_menu = 0;
@@ -65,50 +78,107 @@ RouteUI::RouteUI (boost::shared_ptr<ARDOUR::Route> rt, ARDOUR::Session& sess, co
 	was_solo_safe = false;
 	polarity_menu_item = 0;
 	denormal_menu_item = 0;
+	multiple_mute_change = false;
+	multiple_solo_change = false;
+
+	mute_button = manage (new BindableToggleButton (0, ""));
+	mute_button->set_self_managed (true);
+	mute_button->set_name ("MuteButton");
+	UI::instance()->set_tip (mute_button, _("Mute this track"), "");
+
+	solo_button = manage (new BindableToggleButton (0, ""));
+	solo_button->set_self_managed (true);
+	solo_button->set_name ("SoloButton");
+	UI::instance()->set_tip (solo_button, _("Mute other (non-soloed) tracks"), "");
+
+	rec_enable_button = manage (new BindableToggleButton (0, ""));
+	rec_enable_button->set_name ("RecordEnableButton");
+	rec_enable_button->set_self_managed (true);
+	UI::instance()->set_tip (rec_enable_button, _("Enable recording on this track"), "");
+
+	_session.SoloChanged.connect (mem_fun(*this, &RouteUI::solo_changed_so_update_mute));
+}
+
+void
+RouteUI::reset ()
+{
+	connections.clear ();
+
+	if (solo_menu) {
+		delete solo_menu;
+		solo_menu = 0;
+	}
+
+	if (mute_menu) {
+		delete mute_menu;
+		mute_menu = 0;
+	}
+	
+	if (xml_node) {
+		/* do not delete the node - its owned by the route */
+		xml_node = 0;
+	}
+
+	route_active_menu_item = 0;
+	polarity_menu_item = 0;
+	denormal_menu_item = 0;
+}
+
+void
+RouteUI::set_button_names (const char* mute, const char* solo, const char* rec)
+{
+	m_name = mute;
+	s_name = solo;
+	r_name = rec;
+}
+
+void
+RouteUI::set_route (boost::shared_ptr<Route> rp)
+{
+	reset ();
+
+	_route = rp;
 
 	if (set_color_from_route()) {
 		set_color (unique_random_color());
 	}
 
+	/* no, there is no memory leak here. This object cleans itself (and other stuff)
+	   up when the route is destroyed.
+	*/
+
 	new PairedShiva<Route,RouteUI> (*_route, *this);
 
-	_route->active_changed.connect (mem_fun (*this, &RouteUI::route_active_changed));
+	mute_button->set_controllable (&_route->mute_control());
+	mute_button->set_label (m_name);
+	
+	solo_button->set_controllable (&_route->solo_control());
+	solo_button->set_label (s_name);
 
-        mute_button = manage (new BindableToggleButton (_route->mute_control(), m_name ));
-	mute_button->set_self_managed (true);
-
-        solo_button = manage (new BindableToggleButton (_route->solo_control(), s_name ));
-	solo_button->set_self_managed (true);
-
-	mute_button->set_name ("MuteButton");
-	solo_button->set_name ("SoloButton");
-
-	_route->mute_changed.connect (mem_fun(*this, &RouteUI::mute_changed));
-	_route->solo_changed.connect (mem_fun(*this, &RouteUI::solo_changed));
-	_route->solo_safe_changed.connect (mem_fun(*this, &RouteUI::solo_changed));
+	connections.push_back (_route->active_changed.connect (mem_fun (*this, &RouteUI::route_active_changed)));
+	connections.push_back (_route->mute_changed.connect (mem_fun(*this, &RouteUI::mute_changed)));
+	connections.push_back (_route->solo_changed.connect (mem_fun(*this, &RouteUI::solo_changed)));
+	connections.push_back (_route->solo_safe_changed.connect (mem_fun(*this, &RouteUI::solo_changed)));
 
 	/* when solo changes, update mute state too, in case the user wants us to display it */
 
-	_session.SoloChanged.connect (mem_fun(*this, &RouteUI::solo_changed_so_update_mute));
-	
 	update_solo_display ();
 	update_mute_display ();
 
 	if (is_track()) {
 		boost::shared_ptr<Track> t = boost::dynamic_pointer_cast<Track>(_route);
 
-		t->diskstream()->RecordEnableChanged.connect (mem_fun (*this, &RouteUI::route_rec_enable_changed));
+		connections.push_back (t->diskstream()->RecordEnableChanged.connect (mem_fun (*this, &RouteUI::route_rec_enable_changed)));
 
-		_session.RecordStateChanged.connect (mem_fun (*this, &RouteUI::session_rec_enable_changed));
+		connections.push_back (_session.RecordStateChanged.connect (mem_fun (*this, &RouteUI::session_rec_enable_changed)));
 
-		rec_enable_button = manage (new BindableToggleButton (t->rec_enable_control(), r_name ));
-		rec_enable_button->set_name ("RecordEnableButton");
-		rec_enable_button->set_self_managed (true);
+		rec_enable_button->set_controllable (&t->rec_enable_control());
+		rec_enable_button->set_label (r_name);
 
 		update_rec_display ();
 	} 
 	
-	_route->RemoteControlIDChanged.connect (mem_fun(*this, &RouteUI::refresh_remote_control_menu));
+	connections.push_back (_route->RemoteControlIDChanged.connect (mem_fun(*this, &RouteUI::refresh_remote_control_menu)));
 
 	/* map the current state */
 
@@ -118,16 +188,30 @@ RouteUI::RouteUI (boost::shared_ptr<ARDOUR::Route> rt, ARDOUR::Session& sess, co
 RouteUI::~RouteUI()
 {
 	GoingAway (); /* EMIT SIGNAL */
-	delete mute_menu;
+
+	if (solo_menu) {
+		delete solo_menu;
+	}
+
+	if (mute_menu) {
+		delete mute_menu;
+	}
+	
+	/* Note: the remote control menu is constructed
+	   by derived classes (e.g. MixerStrip or RouteTimeAxis) and
+	   is always attached to a context menu. It then becomes
+	   owned by that menu, and will deleted along with it. We
+	   do not need to take care of it here.
+	*/
 }
 
 bool
 RouteUI::mute_press(GdkEventButton* ev)
 {
-	if (ev->type == GDK_2BUTTON_PRESS) {
+	if (ev->type == GDK_2BUTTON_PRESS || ev->type == GDK_3BUTTON_PRESS ) {
 		return true;
 	}
-
+	multiple_mute_change = false;
 	if (!ignore_toggle) {
 
 		if (Keyboard::is_context_menu_event (ev)) {
@@ -140,7 +224,7 @@ RouteUI::mute_press(GdkEventButton* ev)
 
 		} else {
 
-			if (ev->button == 2) {
+			if (Keyboard::is_button2_event (ev)) {
 				// Primary-button2 click is the midi binding click
 				// button2-click is "momentary"
 				
@@ -151,7 +235,7 @@ RouteUI::mute_press(GdkEventButton* ev)
 				}
 			}
 
-			if (ev->button == 1 || ev->button == 2) {
+			if (ev->button == 1 || Keyboard::is_button2_event (ev)) {
 
 				if (Keyboard::modifier_state_equals (ev->state, Keyboard::ModifierMask (Keyboard::PrimaryModifier|Keyboard::TertiaryModifier))) {
 
@@ -163,6 +247,7 @@ RouteUI::mute_press(GdkEventButton* ev)
                                         cmd->mark();
 					_session.add_command(cmd);
 					_session.commit_reversible_command ();
+					multiple_mute_change = true;
 
 				} else if (Keyboard::modifier_state_equals (ev->state, Keyboard::PrimaryModifier)) {
 
@@ -177,8 +262,11 @@ RouteUI::mute_press(GdkEventButton* ev)
 				} else {
 
 					/* plain click applies change to this route */
-
-					reversibly_apply_route_boolean ("mute change", &Route::set_mute, !_route->muted(), this);
+					if (wait_for_release) {
+						_route->set_mute (!_route->muted(), this);
+					} else {
+						reversibly_apply_route_boolean ("mute change", &Route::set_mute, !_route->muted(), this);
+					}
 				}
 			}
 		}
@@ -194,9 +282,14 @@ RouteUI::mute_release(GdkEventButton* ev)
 	if (!ignore_toggle) {
 		if (wait_for_release){
 			wait_for_release = false;
-			// undo the last op
-			// because the press was the last undoable thing we did
-			_session.undo (1U);
+			if (multiple_mute_change) {
+				multiple_mute_change = false;
+				// undo the last op
+				// because the press was the last undoable thing we did
+				_session.undo (1U);
+			} else {
+				_route->set_mute (!_route->muted(), this);
+			}
 		}
 	}
 	return true;
@@ -205,16 +298,16 @@ RouteUI::mute_release(GdkEventButton* ev)
 bool
 RouteUI::solo_press(GdkEventButton* ev)
 {
-	/* ignore double clicks */
+	/* ignore double/triple clicks */
 
-	if (ev->type == GDK_2BUTTON_PRESS) {
+	if (ev->type == GDK_2BUTTON_PRESS || ev->type == GDK_3BUTTON_PRESS ) {
 		return true;
 	}
-
+	multiple_solo_change = false;
 	if (!ignore_toggle) {
 
 		if (Keyboard::is_context_menu_event (ev)) {
-			
+
 			if (solo_menu == 0) {
 				build_solo_menu ();
 			}
@@ -223,7 +316,7 @@ RouteUI::solo_press(GdkEventButton* ev)
 
 		} else {
 
-			if (ev->button == 2) {
+			if (Keyboard::is_button2_event (ev)) {
 
 				// Primary-button2 click is the midi binding click
 				// button2-click is "momentary"
@@ -235,18 +328,31 @@ RouteUI::solo_press(GdkEventButton* ev)
 				}
 			}
 
-			if (ev->button == 1 || ev->button == 2) {
+			if (ev->button == 1 || Keyboard::is_button2_event (ev)) {
 
 				if (Keyboard::modifier_state_equals (ev->state, Keyboard::ModifierMask (Keyboard::PrimaryModifier|Keyboard::TertiaryModifier))) {
 
 					/* Primary-Tertiary-click applies change to all routes */
-
+					bool was_not_latched = false;
+					if (!Config->get_solo_latched ()) {
+						was_not_latched = true;
+						/*
+						  XXX it makes no sense to solo all tracks if we're 
+						  not in latched mode, but doing nothing feels like a bug, 
+						  so do it anyway 
+						*/
+						Config->set_solo_latched (true);
+					}
 					_session.begin_reversible_command (_("solo change"));
                                         Session::GlobalSoloStateCommand *cmd = new Session::GlobalSoloStateCommand(_session, this);
 					_session.set_all_solo (!_route->soloed());
                                         cmd->mark();
 					_session.add_command (cmd);
 					_session.commit_reversible_command ();
+					multiple_solo_change = true;
+					if (was_not_latched) {
+						Config->set_solo_latched (false);
+					}
 					
 				} else if (Keyboard::modifier_state_contains (ev->state, Keyboard::ModifierMask (Keyboard::PrimaryModifier|Keyboard::SecondaryModifier))) {
 
@@ -264,8 +370,17 @@ RouteUI::solo_press(GdkEventButton* ev)
 
 					// shift-click: set this route to solo safe
 
-					_route->set_solo_safe (!_route->solo_safe(), this);
-					wait_for_release = false;
+					if (Profile->get_sae() && ev->button == 1) {
+						// button 1 and shift-click: disables solo_latched for this click
+						if (!Config->get_solo_latched ()) {
+							Config->set_solo_latched (true);
+							reversibly_apply_route_boolean ("solo change", &Route::set_solo, !_route->soloed(), this);
+							Config->set_solo_latched (false);
+						}
+					} else {
+						_route->set_solo_safe (!_route->solo_safe(), this);
+						wait_for_release = false;
+					}
 
 				} else if (Keyboard::modifier_state_equals (ev->state, Keyboard::PrimaryModifier)) {
 
@@ -280,7 +395,11 @@ RouteUI::solo_press(GdkEventButton* ev)
 				} else {
 
 					/* click: solo this route */
-					reversibly_apply_route_boolean ("solo change", &Route::set_solo, !_route->soloed(), this);
+					if (wait_for_release) {
+						_route->set_solo (!_route->soloed(), this);
+					} else {
+						reversibly_apply_route_boolean ("solo change", &Route::set_solo, !_route->soloed(), this);
+					}
 				}
 			}
 		}
@@ -295,10 +414,16 @@ RouteUI::solo_release(GdkEventButton* ev)
 	if (!ignore_toggle) {
 		if (wait_for_release) {
 			wait_for_release = false;
-			// undo the last op
-			// because the press was the last undoable thing we did
-
-			_session.undo (1U);
+			if (multiple_solo_change) {
+				multiple_solo_change = false;
+				// undo the last op
+				// because the press was the last undoable thing we did
+				_session.undo (1U);
+			} else {
+				// we don't use "undo the last op"
+				// here because its expensive for the GUI
+				_route->set_solo (!_route->soloed(), this);
+			}
 		}
 	}
 
@@ -308,7 +433,7 @@ RouteUI::solo_release(GdkEventButton* ev)
 bool
 RouteUI::rec_enable_press(GdkEventButton* ev)
 {
-	if (ev->type == GDK_2BUTTON_PRESS) {
+	if (ev->type == GDK_2BUTTON_PRESS || ev->type == GDK_3BUTTON_PRESS ) {
 		return true;
 	}
 
@@ -320,7 +445,7 @@ RouteUI::rec_enable_press(GdkEventButton* ev)
 
 	if (!ignore_toggle && is_track() && rec_enable_button) {
 
-		if (ev->button == 2 && Keyboard::modifier_state_equals (ev->state, Keyboard::PrimaryModifier)) {
+		if (Keyboard::is_button2_event (ev) && Keyboard::modifier_state_equals (ev->state, Keyboard::PrimaryModifier)) {
 
 			// do nothing on midi bind event
 			return false;
@@ -366,6 +491,7 @@ RouteUI::rec_enable_release (GdkEventButton* ev)
 void
 RouteUI::solo_changed(void* src)
 {
+
 	Gtkmm2ext::UI::instance()->call_slot (mem_fun (*this, &RouteUI::update_solo_display));
 }
 
@@ -492,7 +618,7 @@ RouteUI::update_rec_display ()
 void
 RouteUI::build_remote_control_menu ()
 {
-	remote_control_menu = manage (new Menu);
+	remote_control_menu = new Menu;
 	refresh_remote_control_menu ();
 }
 
@@ -814,7 +940,7 @@ gint
 RouteUI::idle_remove_this_route (RouteUI *rui)
 {
 	rui->_session.remove_route (rui->_route);
-	return FALSE;
+	return false;
 }
 
 void
