@@ -44,9 +44,14 @@ class BindableToggleButton;
 class RouteUI : public virtual AxisView
 {
   public:
+	RouteUI(ARDOUR::Session&, const char*, const char*, const char*);
 	RouteUI(boost::shared_ptr<ARDOUR::Route>, ARDOUR::Session&, const char*, const char*, const char*);
+
 	virtual ~RouteUI();
 
+	virtual void set_route (boost::shared_ptr<ARDOUR::Route>);
+	void set_button_names (const char*, const char*, const char*);
+
 	bool is_track() const;
 	bool is_audio_track() const;
 
@@ -66,6 +71,8 @@ class RouteUI : public virtual AxisView
 
 	bool ignore_toggle;
 	bool wait_for_release;
+	bool multiple_mute_change;
+	bool multiple_solo_change;
 
 	BindableToggleButton* mute_button;
 	BindableToggleButton* solo_button;
@@ -154,6 +161,15 @@ class RouteUI : public virtual AxisView
 
 	void reversibly_apply_route_boolean (string name, void (ARDOUR::Route::*func)(bool, void*), bool, void *);
 	void reversibly_apply_audio_track_boolean (string name, void (ARDOUR::AudioTrack::*func)(bool, void*), bool, void *);
+
+  protected:
+	std::vector<sigc::connection> connections;
+	std::string s_name;
+	std::string m_name;
+	std::string r_name;
+
+	void init ();
+	void reset ();
 };
 
 #endif /* __ardour_route_ui__ */
