@@ -262,8 +262,10 @@ SoundFileBox::setup_labels (const ustring& filename)
 		samplerate.set_name ("NewSessionSR2Label");
 	}
 
-	length_clock.set (sf_info.length, true);
-	timecode_clock.set (sf_info.timecode, true);
+	double src_coef = (double) _session->nominal_frame_rate() / sf_info.samplerate;
+
+	length_clock.set (sf_info.length * src_coef + 0.5, true);
+	timecode_clock.set (sf_info.timecode * src_coef + 0.5, true);
 
 	// this is a hack that is fixed in trunk, i think (august 26th, 2007)
 
@@ -582,7 +584,8 @@ SoundFileBrowser::add_gain_meter ()
 		delete gm;
 	}
 
-	gm = new GainMeter (session->the_auditioner(), *session);
+	gm = new GainMeter (*session);
+	gm->set_io (session->the_auditioner());
 
 	meter_packer.set_border_width (12);
 	meter_packer.pack_start (*gm, false, true);
@@ -711,7 +714,7 @@ SoundFileBrowser::found_search_clicked ()
 void*
 freesound_search_thread_entry (void* arg)
 {
-	PBD::ThreadCreated (pthread_self(), X_("Freesound Search"));
+	PBD::notify_gui_about_thread_creation (pthread_self(), X_("Freesound Search"));
 
 	static_cast<SoundFileBrowser*>(arg)->freesound_search_thread ();
 	
