@@ -78,9 +78,9 @@ TimeAxisView::TimeAxisView (ARDOUR::Session& sess, PublicEditor& ed, TimeAxisVie
 		compute_controls_size_info ();
 		need_size_info = false;
 	}
+	canvas_background = new Group (*ed.get_background_group (), 0.0, 0.0);
+	canvas_display = new Group (*ed.get_trackview_group (), 0.0, 0.0);
 
-	canvas_display = new Group (*canvas.root(), 0.0, 0.0);
-	
 	selection_group = new Group (*canvas_display);
 	selection_group->hide();
 	
@@ -197,6 +197,11 @@ TimeAxisView::~TimeAxisView()
 		selection_group = 0;
 	}
 
+	if (canvas_background) {
+		delete canvas_background;
+		canvas_background = 0;
+	}
+
 	if (canvas_display) {
 		delete canvas_display;
 		canvas_display = 0;
@@ -211,50 +216,42 @@ TimeAxisView::~TimeAxisView()
 guint32
 TimeAxisView::show_at (double y, int& nth, VBox *parent)
 {
-	gdouble ix1, ix2, iy1, iy2;
-	effective_height = 0;
-	
 	if (control_parent) {
 		control_parent->reorder_child (controls_frame, nth);
-	} else {
+	} else {	
 		control_parent = parent;
 		parent->pack_start (controls_frame, false, false);
 		parent->reorder_child (controls_frame, nth);
 	}
-	controls_frame.show ();
-	controls_ebox.show ();
-	
-	/* the coordinates used here are in the system of the
-	   item's parent ...
-	*/
 
-	canvas_display->get_bounds (ix1, iy1, ix2, iy2);
-	Group* pg = canvas_display->property_parent();
-	pg->i2w (ix1, iy1);
+	order = nth;
 
-	if (iy1 < 0) {
-		iy1 = 0;
+	if (y_position != y) {
+		canvas_display->property_y () = y;
+		canvas_background->property_y () = y;
+		/* silly canvas */
+		canvas_display->move (0.0, 0.0);
+		canvas_background->move (0.0, 0.0);
+		y_position = y;
+	}
+
+	canvas_background->raise_to_top ();
+	canvas_display->raise_to_top ();
+
+	if (_marked_for_display) {
+		controls_frame.show ();
+		controls_ebox.show ();
+		canvas_background->show ();
 	}
 
-	canvas_display->move (0.0, y - iy1);
-	canvas_display->show();/* XXX not necessary */
-	y_position = y;
-	order = nth;
 	_hidden = false;
 	
-	/* height in pixels depends on _order, so update it now we've changed _order */
-	set_height (height);
-	
 	effective_height = current_height();
 
 	/* now show children */
 	
 	for (vector<TimeAxisView*>::iterator i = children.begin(); i != children.end(); ++i) {
 		
-		if ((*i)->marked_for_display()) {
-			(*i)->canvas_display->show();
-		}
-		
 		if (canvas_item_visible ((*i)->canvas_display)) {
 			++nth;
 			effective_height += (*i)->show_at (y + effective_height, nth, parent);
@@ -264,6 +261,21 @@ TimeAxisView::show_at (double y, int& nth, VBox *parent)
 	return effective_height;
 }
 
+void
+TimeAxisView::clip_to_viewport ()
+{
+	if (_marked_for_display) {
+		if (y_position  +  effective_height < editor.get_trackview_group_vertical_offset () || y_position > editor.get_trackview_group_vertical_offset () + canvas_display->get_canvas()->get_height()) {
+			canvas_background->hide ();
+			canvas_display->hide ();
+			return;
+		}
+		canvas_background->show();
+		canvas_display->show ();
+	}
+	return;
+}
+
 bool
 TimeAxisView::controls_ebox_scroll (GdkEventScroll* ev)
 {
@@ -327,6 +339,7 @@ TimeAxisView::hide ()
 	}
 
 	canvas_display->hide();
+	canvas_background->hide();
 	controls_frame.hide ();
 
 	if (control_parent) {
@@ -342,6 +355,10 @@ TimeAxisView::hide ()
 	for (vector<TimeAxisView*>::iterator i = children.begin(); i != children.end(); ++i) {
 		(*i)->hide ();
 	}
+
+	/* if its hidden, it cannot be selected */
+
+	editor.get_selection().remove (this);
 	
 	Hiding ();
 }
@@ -375,9 +392,11 @@ TimeAxisView::set_heights (uint32_t h)
 void
 TimeAxisView::set_height(uint32_t h)
 {
+	if (h == height) {
+		return;
+	}
 	height = h;
-
-	controls_frame.set_size_request (-1, current_height() + ((order == 0) ? 1 : 0));
+	controls_frame.property_height_request () = h;
 
  	if (canvas_item_visible (selection_group)) {
 		/* resize the selection rect */
