@@ -103,6 +103,7 @@ class TimeAxisView : public virtual AxisView, public Stateful
 	
 	uint32_t current_height() const { return height; }
 
+	ArdourCanvas::Group   *canvas_background;
 	ArdourCanvas::Group   *canvas_display;
  	Gtk::VBox       *control_parent;
 
@@ -143,6 +144,8 @@ class TimeAxisView : public virtual AxisView, public Stateful
 	 */
 	virtual guint32 show_at (double y, int& nth, Gtk::VBox *parent);
 
+	void clip_to_viewport ();
+
 	bool touched (double top, double bot);
 
 	/**
