@@ -149,7 +149,7 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 	vestigial_frame = new ArdourCanvas::SimpleRect (*group);
 	vestigial_frame->property_x1() = (double) 0.0;
 	vestigial_frame->property_y1() = (double) 1.0;
-	vestigial_frame->property_x2() = 2.0;
+	vestigial_frame->property_x2() = (double) 2.0;
 	vestigial_frame->property_y2() = (double) trackview.current_height();
 	vestigial_frame->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_VestigialFrame.get();
 	vestigial_frame->property_fill_color_rgba() = ARDOUR_UI::config()->canvasvar_VestigialFrame.get();
@@ -162,7 +162,6 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 		frame->property_x2() = (double) trackview.editor.frame_to_pixel(duration);
 		frame->property_y2() = (double) trackview.current_height();
 		frame->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_TimeAxisFrame.get();
-		frame->property_fill_color_rgba() = ARDOUR_UI::config()->canvasvar_TimeAxisFrame.get();
 
 		/* by default draw all 4 edges */
 
@@ -197,8 +196,6 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 		}
 		name_highlight->property_y1() = (double) (trackview.current_height() - TimeAxisViewItem::NAME_HIGHLIGHT_SIZE);
 		name_highlight->property_y2() = (double) (trackview.current_height() - 1);
-		name_highlight->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_NameHighlightFill.get();
-		name_highlight->property_fill_color_rgba() = ARDOUR_UI::config()->canvasvar_NameHighlightOutline.get();
 
 		name_highlight->set_data ("timeaxisviewitem", this);
 
@@ -206,6 +203,28 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 		name_highlight = 0;
 	}
 
+	/* create our grab handles used for trimming/duration etc */
+
+	if (visibility & ShowHandles) {
+		frame_handle_start = new ArdourCanvas::SimpleRect (*group);
+		frame_handle_start->property_x1() = (double) 0.0;
+		frame_handle_start->property_x2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH;
+		frame_handle_start->property_y1() = (double) 1.0;
+		frame_handle_start->property_y2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH+1;
+		frame_handle_start->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
+
+		frame_handle_end = new ArdourCanvas::SimpleRect (*group);
+		frame_handle_end->property_x1() = (double) (trackview.editor.frame_to_pixel(get_duration())) - (TimeAxisViewItem::GRAB_HANDLE_LENGTH);
+		frame_handle_end->property_x2() = (double) trackview.editor.frame_to_pixel(get_duration());
+		frame_handle_end->property_y1() = (double) 1;
+		frame_handle_end->property_y2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH + 1;
+		frame_handle_end->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
+
+	} else {
+		frame_handle_start = 0;
+		frame_handle_end = 0;
+	}
+
 	if (visibility & ShowNameText) {
 		name_text = new ArdourCanvas::Text (*group);
 		name_text->property_x() = (double) TimeAxisViewItem::NAME_X_OFFSET;
@@ -222,32 +241,8 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 		name_text = 0;
 	}
 
-	/* create our grab handles used for trimming/duration etc */
-
-	if (visibility & ShowHandles) {
-		frame_handle_start = new ArdourCanvas::SimpleRect (*group);
-		frame_handle_start->property_x1() = (double) 0.0;
-		frame_handle_start->property_x2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH;
-		frame_handle_start->property_y1() = (double) 1.0;
-		frame_handle_start->property_y2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH+1;
-		frame_handle_start->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
-		frame_handle_start->property_fill_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
-		
-		frame_handle_end = new ArdourCanvas::SimpleRect (*group);
-		frame_handle_end->property_x1() = (double) (trackview.editor.frame_to_pixel(get_duration())) - (TimeAxisViewItem::GRAB_HANDLE_LENGTH);
-		frame_handle_end->property_x2() = (double) trackview.editor.frame_to_pixel(get_duration());
-		frame_handle_end->property_y1() = (double) 1;
-		frame_handle_end->property_y2() = (double) TimeAxisViewItem::GRAB_HANDLE_LENGTH + 1;
-		frame_handle_end->property_outline_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
-		frame_handle_end->property_fill_color_rgba() = ARDOUR_UI::config()->canvasvar_FrameHandle.get();
-
-	} else {
-		frame_handle_start = 0;
-		frame_handle_end = 0;
-	}
-
 	set_color (base_color) ;
-
+	
 	set_duration (item_duration, this) ;
 	set_position (start, this) ;
 }
@@ -591,11 +586,10 @@ TimeAxisViewItem::set_height (double height)
 		if (height > NAME_HIGHLIGHT_SIZE) {
 			name_highlight->property_y1() = (double) height+1 - NAME_HIGHLIGHT_SIZE;
 			name_highlight->property_y2() = (double) height;
-		}
-		else {
+		} else {
 			/* it gets hidden now anyway */
-			name_highlight->property_y1() = (double) 1.0;
-			name_highlight->property_y2() = (double) height;
+			//name_highlight->property_y1() = (double) 1.0;
+			//name_highlight->property_y2() = (double) height;
 		}
 	}
 
@@ -603,8 +597,7 @@ TimeAxisViewItem::set_height (double height)
 		name_text->property_y() = height+1 - NAME_Y_OFFSET;
 		if (height < NAME_HIGHLIGHT_THRESH) {
 			name_text->property_fill_color_rgba() =  fill_color;
-		}
-		else {
+		} else {
 			name_text->property_fill_color_rgba() = label_color;
 		}
 	}
@@ -638,7 +631,7 @@ TimeAxisViewItem::get_canvas_frame()
 /**
  * 
  */
-ArdourCanvas::Item*
+ArdourCanvas::Group*
 TimeAxisViewItem::get_canvas_group()
 {
 	return (group) ;
@@ -844,14 +837,7 @@ TimeAxisViewItem::set_samples_per_unit (double spu)
 void
 TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 {
-	if (pixel_width < GRAB_HANDLE_LENGTH * 2) {
-
-		if (frame_handle_start) {
-			frame_handle_start->hide();
-			frame_handle_end->hide();
-		}
-
-	} if (pixel_width < 2.0) {
+	if (pixel_width < 2.0) {
 
 		if (show_vestigial) {
 			vestigial_frame->show();
@@ -910,11 +896,12 @@ TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 			if (pixel_width < (2*TimeAxisViewItem::GRAB_HANDLE_LENGTH)) {
 				frame_handle_start->hide();
 				frame_handle_end->hide();
+			} else {
+				frame_handle_start->show();
+				frame_handle_end->property_x1() = pixel_width - (TimeAxisViewItem::GRAB_HANDLE_LENGTH);
+				frame_handle_end->property_x2() = pixel_width;
+				frame_handle_end->show();
 			}
-			frame_handle_start->show();
-			frame_handle_end->property_x1() = pixel_width - (TimeAxisViewItem::GRAB_HANDLE_LENGTH);
-			frame_handle_end->show();
-			frame_handle_end->property_x2() = pixel_width;
 		}
 	}
 }
