@@ -110,8 +110,9 @@ class Region : public PBD::StatefulDestructible, public Readable, public boost::
 
 	nframes_t sync_offset(int& dir) const;
 	nframes_t sync_position() const;
+	nframes_t sync_point () const;
 
-	nframes_t adjust_to_sync (nframes_t);
+	nframes_t adjust_to_sync (nframes_t) const;
 	
 	/* first_frame() is an alias; last_frame() just hides some math */
 
@@ -212,10 +213,13 @@ class Region : public PBD::StatefulDestructible, public Readable, public boost::
 	Region (nframes_t start, nframes_t length, 
 		const string& name, layer_t = 0, Flag flags = DefaultFlags);
 	Region (boost::shared_ptr<const Region>, nframes_t start, nframes_t length, const string& name, layer_t = 0, Flag flags = DefaultFlags);
+	Region (boost::shared_ptr<const Region>, nframes_t length, const string& name, layer_t = 0, Flag flags = DefaultFlags);
 	Region (boost::shared_ptr<const Region>);
 	Region (const XMLNode&);
 
   protected:
+	void copy_stuff (boost::shared_ptr<const Region>, nframes_t start, nframes_t length, const string& name, layer_t, Flag flags);
+
 	XMLNode& get_short_state (); /* used only by Session */
 
 	void send_change (Change);
