@@ -306,6 +306,8 @@ class Session : public PBD::StatefulDestructible
 	    bool operator() (boost::shared_ptr<Route>, boost::shared_ptr<Route> b);
 	};
 	
+	void sync_order_keys (const char* base);
+
 	template<class T> void foreach_route (T *obj, void (T::*func)(Route&));
 	template<class T> void foreach_route (T *obj, void (T::*func)(boost::shared_ptr<Route>));
 	template<class T, class A> void foreach_route (T *obj, void (T::*func)(Route&, A), A arg);
@@ -396,6 +398,10 @@ class Session : public PBD::StatefulDestructible
 	double frames_per_smpte_frame() const { return _frames_per_smpte_frame; }
 	nframes_t smpte_frames_per_hour() const { return _smpte_frames_per_hour; }
 
+	MIDI::byte get_mtc_smpte_bits() const { 
+		return mtc_smpte_bits;   /* encoding of SMTPE type for MTC */
+	}
+
 	float smpte_frames_per_second() const;
 	bool smpte_drop_frames() const;
 
@@ -583,6 +589,7 @@ class Session : public PBD::StatefulDestructible
 	    string doing_what;
 	    
 	    /* control info */
+	    uint32_t total;
 	    SrcQuality quality;
 	    volatile bool freeze;
 	    std::vector<Glib::ustring> paths;
@@ -590,7 +597,6 @@ class Session : public PBD::StatefulDestructible
 	    
 	    /* result */
 	    SourceList sources;
-	    
 	};
 
 	void import_audiofiles (import_status&);
@@ -1418,8 +1424,6 @@ class Session : public PBD::StatefulDestructible
 	void          change_midi_ports ();
 	int           use_config_midi_ports ();
 
-	bool waiting_to_start;
-
 	void set_play_loop (bool yn);
 	void overwrite_some_buffers (Diskstream*);
 	void flush_all_redirects ();
@@ -1431,7 +1435,6 @@ class Session : public PBD::StatefulDestructible
 	void set_transport_speed (float speed, bool abort = false);
 	void stop_transport (bool abort = false);
 	void start_transport ();
-	void actually_start_transport ();
 	void realtime_stop (bool abort);
 	void non_realtime_start_scrub ();
 	void non_realtime_set_speed ();
@@ -1480,6 +1483,7 @@ class Session : public PBD::StatefulDestructible
 	void route_mute_changed (void *src);
 	void route_solo_changed (void *src, boost::weak_ptr<Route>);
 	void catch_up_on_solo ();
+	void catch_up_on_solo_mute_override ();
 	void update_route_solo_state ();
 	void modify_solo_mute (bool, bool);
 	void strip_portname_for_solo (string& portname);
@@ -1751,9 +1755,12 @@ class Session : public PBD::StatefulDestructible
 	XMLNode& get_control_protocol_state ();
 	
 	void set_history_depth (uint32_t depth);
-	void sync_order_keys ();
 
 	static bool _disable_all_loaded_plugins;
+
+	/* used in ::audible_frame() */
+
+	mutable bool have_looped;
 };
 
 } // namespace ARDOUR
