@@ -247,7 +247,8 @@ namespace ARDOUR {
 
 	enum EditMode {
 		Slide,
-		Splice
+		Splice,
+		Lock
 	};
 
 	enum RegionPoint { 
@@ -340,6 +341,7 @@ namespace ARDOUR {
 	enum PluginType {
 		AudioUnit,
 		LADSPA,
+		LV2,
 		VST
 	};
 
@@ -369,6 +371,18 @@ namespace ARDOUR {
 		SrcFastest
 	};
 
+	struct TimeFXRequest : public InterThreadInfo {
+	    float time_fraction;
+	    float pitch_fraction;
+	    /* SoundTouch */
+	    bool  quick_seek; 
+	    bool  antialias;  
+	    /* RubberBand */
+	    int   opts; // really RubberBandStretcher::Options
+	};
+
+	typedef std::list<nframes64_t> AnalysisFeatureList;
+
 } // namespace ARDOUR
 
 std::istream& operator>>(std::istream& o, ARDOUR::SampleFormat& sf);
