@@ -606,18 +606,70 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 		/* copy the diskstream data to all output buffers */
 		
 		vector<Sample*>& bufs = _session.get_passthru_buffers ();
+		vector<Sample*>::size_type blimit = bufs.size();
 		uint32_t limit = n_process_buffers ();
 		
 		uint32_t n;
 		uint32_t i;
 
+		if (limit > blimit) {
 
-		for (i = 0, n = 1; i < limit; ++i, ++n) {
-			memcpy (bufs[i], b, sizeof (Sample) * nframes); 
-			if (n < diskstream->n_channels()) {
-				tmpb = diskstream->playback_buffer(n);
-				if (tmpb!=0) {
-					b = tmpb;
+			/* example case: auditioner configured for stereo output,
+			   but loaded with an 8 channel file. there are only
+			   2 passthrough buffers, but n_process_buffers() will
+			   return 8.
+			   
+			   arbitrary decision: map all channels in the diskstream
+			   to the outputs available.
+			*/
+
+			float scaling = limit/blimit;
+			
+			for (i = 0, n = 1; i < blimit; ++i, ++n) {
+
+				/* first time through just copy a channel into 
+				   the output buffer.
+				*/
+				
+				for (nframes_t xx = 0; xx < nframes; ++xx) {
+					bufs[i][xx] = b[xx] * scaling;
+				}
+
+				if (n < diskstream->n_channels()) {
+					tmpb = diskstream->playback_buffer(n);
+					if (tmpb!=0) {
+						b = tmpb;
+					}
+				}
+			}
+
+			for (;i < limit; ++i, ++n) {
+				
+				/* for all remaining channels, sum with existing
+				   data in the output buffers 
+				*/
+				
+				Session::mix_buffers_with_gain (bufs[i%blimit], b, nframes, scaling);
+
+				if (n < diskstream->n_channels()) {
+					tmpb = diskstream->playback_buffer(n);
+					if (tmpb!=0) {
+						b = tmpb;
+					}
+				}
+				
+			}
+
+			limit = blimit;
+
+		} else {
+			for (i = 0, n = 1; i < limit; ++i, ++n) {
+				memcpy (bufs[i], b, sizeof (Sample) * nframes); 
+				if (n < diskstream->n_channels()) {
+					tmpb = diskstream->playback_buffer(n);
+					if (tmpb!=0) {
+						b = tmpb;
+					}
 				}
 			}
 		}
@@ -848,6 +900,10 @@ AudioTrack::freeze (InterThreadInfo& itt)
 		}
 	}
 
+	_freeze_record.gain = _gain;
+	_freeze_record.gain_automation_state = _gain_automation_curve.automation_state();
+	_freeze_record.pan_automation_state = _panner->automation_state();
+
 	new_playlist = PlaylistFactory::create (_session, new_playlist_name, false);
 	region_name = new_playlist_name;
 
@@ -866,6 +922,12 @@ AudioTrack::freeze (InterThreadInfo& itt)
 	diskstream->use_playlist (boost::dynamic_pointer_cast<AudioPlaylist>(new_playlist));
 	diskstream->set_record_enabled (false);
 
+	/* reset stuff that has already been accounted for in the freeze process */
+	
+	set_gain (1.0, this);
+	_gain_automation_curve.set_automation_state (Off);
+	_panner->set_automation_state (Off);
+
 	_freeze_record.state = Frozen;
 	FreezeChange(); /* EMIT SIGNAL */
 }
@@ -896,6 +958,9 @@ AudioTrack::unfreeze ()
 		}
 		
 		_freeze_record.playlist.reset ();
+		set_gain (_freeze_record.gain, this);
+		_gain_automation_curve.set_automation_state (_freeze_record.gain_automation_state);
+		_panner->set_automation_state (_freeze_record.pan_automation_state);
 	}
 
 	_freeze_record.state = UnFrozen;
