@@ -103,7 +103,15 @@ AUPlugin::~AUPlugin ()
 void
 AUPlugin::init ()
 {
-	OSErr err = CAAudioUnit::Open (*(comp.get()), *unit);
+	OSErr err;
+
+	try {
+		err = CAAudioUnit::Open (*(comp.get()), *unit);
+	} catch (...) {
+		error << _("Exception thrown during AudioUnit plugin loading - plugin ignored") << endmsg;
+		cerr << _("Exception thrown during AudioUnit plugin loading - plugin ignored") << endl;
+		throw failed_constructor();
+	}
 
 	if (err != noErr) {
 		error << _("AudioUnit: Could not convert CAComponent to CAAudioUnit") << endmsg;
@@ -1060,10 +1068,20 @@ AUPluginInfo::cached_io_configuration (const std::string& unique_id,
 	
 	ARDOUR::BootMessage (string_compose (_("Checking AudioUnit: %1"), name));
 	
-	if (CAAudioUnit::Open (comp, unit) != noErr) {
-		return false;
-	}
+	try {
 
+		if (CAAudioUnit::Open (comp, unit) != noErr) {
+			return false;
+		}
+
+	} catch (...) {
+
+		warning << string_compose (_("Could not load AU plugin %1 - ignored"), name) << endmsg;
+		cerr << string_compose (_("Could not load AU plugin %1 - ignored"), name) << endl;
+		return false;
+
+	}
+		
 	if ((ret = unit.GetChannelInfo (&channel_info, cnt)) < 0) {
 		return false;
 	}
