@@ -185,7 +185,10 @@ AutomationList::operator= (const AutomationList& other)
 		max_yval = other.max_yval;
 		max_xval = other.max_xval;
 		default_value = other.default_value;
-		
+
+		rt_insertion_point = events.end();
+		lookup_cache.range.first = events.end();
+	
 		mark_dirty ();
 		maybe_signal_changed ();
 	}
@@ -1423,3 +1426,20 @@ AutomationList::set_state (const XMLNode& node)
 	return 0;
 }
 
+void
+AutomationList::shift (nframes64_t pos, nframes64_t frames)
+{
+	{
+		Glib::Mutex::Lock lm (lock);
+
+		for (iterator i = begin (); i != end (); ++i) {
+			if ((*i)->when >= pos) {
+				(*i)->when += frames;
+			}
+		}
+
+		mark_dirty ();
+	}
+
+	maybe_signal_changed ();
+}
