@@ -50,8 +50,10 @@
 #include <ardour/analyser.h>
 
 #ifdef HAVE_COREAUDIO
+#ifdef USE_COREAUDIO_FOR_FILE_IO
 #include <ardour/caimportable.h>
 #endif
+#endif
 
 #include "i18n.h"
 
@@ -63,11 +65,13 @@ static boost::shared_ptr<ImportableSource>
 open_importable_source (const string& path, nframes_t samplerate, ARDOUR::SrcQuality quality)
 {
 #ifdef HAVE_COREAUDIO
+#ifdef USE_COREAUDIO_FOR_FILE_IO
 
 	/* see if we can use CoreAudio to handle the IO */
 	
 	try { 
-		boost::shared_ptr<CAImportableSource> source(new CAImportableSource(path));
+		CAImportableSource* src = new CAImportableSource(path);
+		boost::shared_ptr<CAImportableSource> source (src);
 		
 		if (source->samplerate() == samplerate) {
 			return source;
@@ -81,8 +85,8 @@ open_importable_source (const string& path, nframes_t samplerate, ARDOUR::SrcQua
 	catch (...) {
 
 		/* fall back to SndFile */
-
 #endif	
+#endif
 
 		try { 
 			boost::shared_ptr<SndFileImportableSource> source(new SndFileImportableSource(path));
@@ -90,7 +94,7 @@ open_importable_source (const string& path, nframes_t samplerate, ARDOUR::SrcQua
 			if (source->samplerate() == samplerate) {
 				return source;
 			}
-
+			
 			/* rewrap as a resampled source */
 			
 			return boost::shared_ptr<ImportableSource>(new ResampledImportableSource(source, samplerate, quality));
@@ -101,8 +105,10 @@ open_importable_source (const string& path, nframes_t samplerate, ARDOUR::SrcQua
 		}
 		
 #ifdef HAVE_COREAUDIO		
+#ifdef USE_COREAUDIO_FOR_FILE_IO
 	}
 #endif
+#endif
 }
 
 static std::string
@@ -344,7 +350,7 @@ Session::import_audiofiles (import_status& status)
 		}
 
 		status.doing_what = compose_status_message (*p, source->samplerate(),
-				frame_rate(), cnt, status.paths.size());
+				frame_rate(), cnt, status.total);
 
 		write_audio_data_to_new_files (source.get(), status, newfiles);
 	}
@@ -374,8 +380,7 @@ Session::import_audiofiles (import_status& status)
 
 		save_state (_name);
 
-		std::copy (all_new_sources.begin(), all_new_sources.end(),
-				std::back_inserter(status.sources));
+		std::copy (all_new_sources.begin(), all_new_sources.end(), std::back_inserter(status.sources));
 	} else {
 		// this can throw...but it seems very unlikely
 		std::for_each (all_new_sources.begin(), all_new_sources.end(), remove_file_source);
