@@ -428,16 +428,23 @@ PluginInsert::automation_run (vector<Sample *>& bufs, uint32_t nbufs, nframes_t
  		connect_and_run (bufs, nbufs, nframes, offset, true, now);
  		return;
  	}
+
+	nframes_t buffer_correct = 0;
 	
  	while (nframes) {
-
 		nframes_t cnt = min (((nframes_t) ceil (next_event.when) - now), nframes);
-  
+
+		// This is called first, but nframes = 256
  		connect_and_run (bufs, nbufs, cnt, offset, true, now);
  		
  		nframes -= cnt;
  		offset += cnt;
 		now += cnt;
+		buffer_correct += cnt;
+
+		for (uint32_t i = 0; i < nbufs; i++) {
+			bufs[i] += cnt;
+		}
 
 		if (!find_next_event (now, end, next_event)) {
 			break;
@@ -449,6 +456,10 @@ PluginInsert::automation_run (vector<Sample *>& bufs, uint32_t nbufs, nframes_t
  	if (nframes) {
  		connect_and_run (bufs, nbufs, nframes, offset, true, now);
   	}
+
+	for (uint32_t i = 0; i < nbufs; i++) {
+		bufs[i] -= buffer_correct;
+	}
 }	
 
 float
@@ -616,6 +627,13 @@ PluginInsert::state (bool full)
 		snprintf(buf, sizeof(buf), "%" PRIu32, *x);
 		child->add_property("number", string(buf));
 
+#ifdef HAVE_SLV2
+		LV2Plugin* lv2p = dynamic_cast<LV2Plugin*>(_plugins[0].get());
+		if (lv2p) {
+			child->add_property("symbol", string(lv2p->port_symbol(*x)));
+		}
+#endif
+
 		child->add_child_nocopy (automation_list (*x).state (full));
 		autonode->add_child_nocopy (*child);
 	}
@@ -844,6 +862,9 @@ PluginInsert::type ()
 #ifdef HAVE_AUDIOUNITS
 	boost::shared_ptr<AUPlugin> ap;
 #endif
+#ifdef HAVE_LV2
+	boost::shared_ptr<LV2Plugin> lv2p;
+#endif
 	
 	PluginPtr other = plugin ();
 
@@ -856,8 +877,13 @@ PluginInsert::type ()
 #ifdef HAVE_AUDIOUNITS
 	} else if ((ap = boost::dynamic_pointer_cast<AUPlugin> (other)) != 0) {
 		return ARDOUR::AudioUnit;
+#endif
+#ifdef HAVE_LV2
+	} else if ((lv2p = boost::dynamic_pointer_cast<LV2Plugin> (other)) != 0) {
+		return ARDOUR::LV2;
 #endif
 	} else {
+		error << "Unknown plugin type" << endmsg;
 		/* NOT REACHED */
 		return (ARDOUR::PluginType) 0;
 	}
