@@ -2604,7 +2604,10 @@ void
 IO::set_gain (gain_t val, void *src)
 {
 	// max gain at about +6dB (10.0 ^ ( 6 dB * 0.05))
-	if (val>1.99526231f) val=1.99526231f;
+
+	if (val > 1.99526231f) {
+		val = 1.99526231f;
+	}
 
 	{
 		Glib::Mutex::Lock dm (declick_lock);
@@ -2613,7 +2616,7 @@ IO::set_gain (gain_t val, void *src)
 
 	if (_session.transport_stopped()) {
 		_effective_gain = val;
-		_gain = val;
+		// _gain = val;
 	}
 
 	gain_changed (src);
@@ -2803,3 +2806,4 @@ IO::set_active (bool yn)
 	 active_changed(); /* EMIT SIGNAL */
 }
 
+
