@@ -27,7 +27,7 @@
 #ifdef VST_SUPPORT
 #include <fst.h>
 #include <pbd/basename.h>
-#include <string.h>
+#include <cstring>
 #endif // VST_SUPPORT
 
 #include <glibmm/miscutils.h>
@@ -126,6 +126,8 @@ PluginManager::PluginManager ()
 	_lv2_world = new LV2World();
 #endif
 
+	BootMessage (_("Discovering Plugins"));
+
 	refresh ();
 }
 
@@ -150,9 +152,42 @@ void
 PluginManager::ladspa_refresh ()
 {
 	_ladspa_plugin_info.clear ();
+	
+	static const char *standard_paths[] = {
+		"/usr/local/lib64/ladspa",
+		"/usr/local/lib/ladspa",
+		"/usr/lib64/ladspa",
+		"/usr/lib/ladspa",
+		"/Library/Audio/Plug-Ins/LADSPA",
+		""
+	};
+	
+	/* allow LADSPA_PATH to augment, not override standard locations */
 
-	if (ladspa_path.length() == 0) {
-		ladspa_path = "/usr/local/lib64/ladspa:/usr/local/lib/ladspa:/usr/lib64/ladspa:/usr/lib/ladspa:/Library/Audio/Plug-Ins/LADSPA";
+	/* Only add standard locations to ladspa_path if it doesn't
+	 * already contain them. Check for trailing '/'s too.
+	 */
+	 
+	int i;
+	for (i = 0; standard_paths[i][0]; i++) {
+		size_t found = ladspa_path.find(standard_paths[i]);
+		if (found != ladspa_path.npos) {
+			switch (ladspa_path[found + strlen(standard_paths[i])]) {
+				case ':' :
+				case '\0':
+					continue;
+				case '/' :
+					if (ladspa_path[found + strlen(standard_paths[i]) + 1] == ':' ||
+					    ladspa_path[found + strlen(standard_paths[i]) + 1] == '\0') {
+						continue;
+					}
+			}
+		}
+		if (!ladspa_path.empty())
+			ladspa_path += ":";
+		
+		ladspa_path += standard_paths[i]; 
+		
 	}
 
 	ladspa_discover_from_path (ladspa_path);
@@ -594,7 +629,7 @@ PluginManager::add_favorite (PluginType t, string id)
 {
 	FavoritePlugin fp (t, id);
 	pair<FavoritePluginList::iterator,bool> res = favorites.insert (fp);
-	cerr << "Added " << t << " " << id << " success ? " << res.second << endl;
+	//cerr << "Added " << t << " " << id << " success ? " << res.second << endl;
 }
 
 void
