@@ -25,6 +25,7 @@
 #include <pbd/xml++.h>
 #include <pbd/enumwriter.h>
 #include <pbd/stacktrace.h>
+#include <pbd/memento_command.h>
 
 #include <ardour/timestamps.h>
 #include <ardour/buffer.h>
@@ -51,7 +52,7 @@ using namespace ARDOUR;
 using namespace PBD;
 
 uint32_t Route::order_key_cnt = 0;
-sigc::signal<void> Route::SyncOrderKeys;
+sigc::signal<void,const char*> Route::SyncOrderKeys;
 
 Route::Route (Session& sess, string name, int input_min, int input_max, int output_min, int output_max, Flag flg, DataType default_type)
 	: IO (sess, name, input_min, input_max, output_min, output_max, default_type),
@@ -169,20 +170,32 @@ Route::set_order_key (const char* name, long n)
 }
 
 void
-Route::sync_order_keys ()
+Route::sync_order_keys (const char* base)
 {
-	uint32_t key;
-	
 	if (order_keys.empty()) {
 		return;
 	}
-	
-	OrderKeys::iterator x = order_keys.begin();
-	key = x->second;
-	++x;
 
-	for (; x != order_keys.end(); ++x) {
-		x->second = key;
+	OrderKeys::iterator i;
+	uint32_t key;
+
+	if ((i = order_keys.find (base)) == order_keys.end()) {
+		/* key doesn't exist, use the first existing
+		   key (this is done during session initialization)
+		*/
+		i = order_keys.begin();
+		key = i->second;
+		++i;
+	} else {
+		/* key exists - use it and reset all others
+		   (actually, itself included)
+		*/
+		i = order_keys.begin();
+		key = i->second;
+	}
+
+	for (; i != order_keys.end(); ++i) {
+		i->second = key;
 	}
 }
 
@@ -804,6 +817,31 @@ Route::set_solo (bool yn, void *src)
 		_soloed = yn;
 		solo_changed (src); /* EMIT SIGNAL */
 		_solo_control.Changed (); /* EMIT SIGNAL */
+	}	
+	
+	catch_up_on_solo_mute_override ();
+}
+
+void
+Route::catch_up_on_solo_mute_override ()
+{
+	if (Config->get_solo_model() != InverseMute) {
+		return;
+	}
+	
+	{
+
+		Glib::Mutex::Lock lm (declick_lock);
+		
+		if (_muted) {
+			if (Config->get_solo_mute_override()) {
+				desired_mute_gain = (_soloed?1.0:0.0);
+			} else {
+				desired_mute_gain = 0.0;
+			}
+		} else {
+			desired_mute_gain = 1.0;
+		}
 	}
 }
 
@@ -843,7 +881,12 @@ Route::set_mute (bool yn, void *src)
 		_mute_control.Changed (); /* EMIT SIGNAL */
 		
 		Glib::Mutex::Lock lm (declick_lock);
-		desired_mute_gain = (yn?0.0f:1.0f);
+		
+		if (_soloed && Config->get_solo_mute_override()){
+			desired_mute_gain = 1.0f;
+		} else {
+			desired_mute_gain = (yn?0.0f:1.0f);
+		}
 	}
 }
 
@@ -909,7 +952,6 @@ Route::add_redirect (boost::shared_ptr<Redirect> redirect, void *src, uint32_t*
 			_max_peak_power.push_back(-INFINITY);
 		}
 
-		redirect->activate ();
 		redirect->active_changed.connect (mem_fun (*this, &Route::redirect_active_proxy));
 	}
 	
@@ -973,7 +1015,6 @@ Route::add_redirects (const RedirectList& others, void *src, uint32_t* err_strea
 				return -1;
 			}
 			
-			(*i)->activate ();
 			(*i)->active_changed.connect (mem_fun (*this, &Route::redirect_active_proxy));
 		}
 	}
@@ -2574,3 +2615,47 @@ Route::set_pending_declick (int declick)
 	}
 
 }
+
+/** Shift automation forwards from a particular place, thereby inserting time.
+ *  Adds undo commands for any shifts that are performed.
+ *
+ * @param pos Position to start shifting from.
+ * @param frames Amount to shift forwards by.
+ */
+
+void
+Route::shift (nframes64_t pos, nframes64_t frames)
+{
+	/* gain automation */
+	XMLNode &before = _gain_automation_curve.get_state ();
+	_gain_automation_curve.shift (pos, frames);
+	XMLNode &after = _gain_automation_curve.get_state ();
+	_session.add_command (new MementoCommand<AutomationList> (_gain_automation_curve, &before, &after));
+
+	/* pan automation */
+	for (std::vector<StreamPanner*>::iterator i = _panner->begin (); i != _panner->end (); ++i) {
+		Curve & c = (*i)->automation ();
+		XMLNode &before = c.get_state ();
+		c.shift (pos, frames);
+		XMLNode &after = c.get_state ();
+		_session.add_command (new MementoCommand<AutomationList> (c, &before, &after));
+	}
+
+	/* redirect automation */
+	{
+		Glib::RWLock::ReaderLock lm (redirect_lock);
+		for (RedirectList::iterator i = _redirects.begin (); i != _redirects.end (); ++i) {
+			
+			set<uint32_t> a;
+			(*i)->what_has_automation (a);
+			
+			for (set<uint32_t>::const_iterator j = a.begin (); j != a.end (); ++j) {
+				AutomationList & al = (*i)->automation_list (*j);
+				XMLNode &before = al.get_state ();
+				al.shift (pos, frames);
+				XMLNode &after = al.get_state ();
+				_session.add_command (new MementoCommand<AutomationList> (al, &before, &after));
+			}
+		}
+	}
+}
