@@ -276,16 +276,23 @@ Session::Session (AudioEngine &eng,
 		  string mix_template)
 
 	: _engine (eng),
+	  mmc (0),
 	  _mmc_port (default_mmc_port),
 	  _mtc_port (default_mtc_port),
 	  _midi_port (default_midi_port),
 	  pending_events (2048),
+	  state_tree (0),
+	  butler_mixdown_buffer (0),
+	  butler_gain_buffer (0),
+	  midi_thread (pthread_t (0)),
 	  midi_requests (128), // the size of this should match the midi request pool size
 	  diskstreams (new DiskstreamList),
 	  routes (new RouteList),
 	  auditioner ((Auditioner*) 0),
 	  _total_free_4k_blocks (0),
 	  _click_io ((IO*) 0),
+	  click_data (0),
+	  click_emphasis_data (0),
 	  main_outs (0)
 {
 	bool new_session;
@@ -340,14 +347,23 @@ Session::Session (AudioEngine &eng,
 		  nframes_t initial_length)
 
 	: _engine (eng),
+	  mmc (0),
 	  _mmc_port (default_mmc_port),
 	  _mtc_port (default_mtc_port),
 	  _midi_port (default_midi_port),
 	  pending_events (2048),
+	  state_tree (0),
+	  butler_mixdown_buffer (0),
+	  butler_gain_buffer (0),
+	  midi_thread (pthread_t (0)),
 	  midi_requests (16),
 	  diskstreams (new DiskstreamList),
 	  routes (new RouteList),
+	  auditioner ((Auditioner *) 0),
 	  _total_free_4k_blocks (0),
+	  _click_io ((IO *) 0),
+	  click_data (0),
+	  click_emphasis_data (0),
 	  main_outs (0)
 
 {
@@ -455,19 +471,16 @@ Session::destroy ()
 	_history.clear ();
 
 	/* clear state tree so that no references to objects are held any more */
-	
-	if (state_tree) {
-		delete state_tree;
-	}
+	delete state_tree;
 
 	terminate_butler_thread ();
 	terminate_midi_thread ();
 	
-	if (click_data && click_data != default_click) {
+	if (click_data != default_click) {
 		delete [] click_data;
 	}
 
-	if (click_emphasis_data && click_emphasis_data != default_click_emphasis) {
+	if (click_emphasis_data != default_click_emphasis) {
 		delete [] click_emphasis_data;
 	}
 
@@ -635,19 +648,12 @@ Session::destroy ()
 		i = tmp;
 	}
 
-	if (butler_mixdown_buffer) {
-		delete [] butler_mixdown_buffer;
-	}
-
-	if (butler_gain_buffer) {
-		delete [] butler_gain_buffer;
-	}
+	delete [] butler_mixdown_buffer;
+	delete [] butler_gain_buffer;
 
 	Crossfade::set_buffer_size (0);
 
-	if (mmc) {
-		delete mmc;
-	}
+	delete mmc;
 }
 
 void
@@ -1378,6 +1384,10 @@ Session::audible_frame () const
 	nframes_t offset;
 	nframes_t tf;
 
+	if (_transport_speed == 0.0f && non_realtime_work_pending()) {
+		return last_stop_frame;
+	}
+
 	/* the first of these two possible settings for "offset"
 	   mean that the audible frame is stationary until 
 	   audio emerges from the latency compensation
@@ -1406,24 +1416,43 @@ Session::audible_frame () const
 	} else {
 		tf = _transport_frame;
 	}
-
-	if (_transport_speed == 0) {
-		return tf;
-	}
-
-	if (tf < offset) {
-		return 0;
-	}
-
+	
 	ret = tf;
 
 	if (!non_realtime_work_pending()) {
 
 		/* MOVING */
 
-		/* take latency into account */
-		
-		ret -= offset;
+		/* check to see if we have passed the first guaranteed
+		   audible frame past our last stopping position. if not,
+		   the return that last stopping point because in terms
+		   of audible frames, we have not moved yet.
+		*/
+
+		if (_transport_speed > 0.0f) {
+
+			if (!play_loop || !have_looped) {
+				if (tf < last_stop_frame + offset) {
+					return last_stop_frame;
+					
+				}
+			} 
+			
+
+			/* forwards */
+			ret -= offset;
+
+		} else if (_transport_speed < 0.0f) {
+
+			/* XXX wot? no backward looping? */
+
+			if (tf > last_stop_frame - offset) {
+				return last_stop_frame;
+			} else {
+				/* backwards */
+				ret += offset;
+			}
+		}
 	}
 
 	return ret;
@@ -1943,20 +1972,20 @@ Session::new_audio_route (int input_channels, int output_channels, uint32_t how_
 				      << endmsg;
 				goto failure;
 			}
-			
+			/*
 			for (uint32_t x = 0; n_physical_audio_inputs && x < bus->n_inputs(); ++x) {
-				
+					
 				port = "";
-
+				
 				if (Config->get_input_auto_connect() & AutoConnectPhysical) {
-						port = physinputs[((n+x)%n_physical_audio_inputs)];
+					port = physinputs[((n+x)%n_physical_audio_inputs)];
 				} 
 				
 				if (port.length() && bus->connect_input (bus->input (x), port, this)) {
 					break;
 				}
 			}
-			
+			*/
 			for (uint32_t x = 0; n_physical_audio_outputs && x < bus->n_outputs(); ++x) {
 				
 				port = "";
@@ -2153,6 +2182,8 @@ Session::remove_route (shared_ptr<Route> route)
 
 	route->drop_references ();
 
+	sync_order_keys (N_("session"));
+
 	/* save the new state of the world */
 
 	if (save_state (_current_snapshot_name)) {
@@ -2277,8 +2308,6 @@ Session::update_route_solo_state ()
 	bool is_track = false;
 	bool signal = false;
 
-	/* caller must hold RouteLock */
-
 	/* this is where we actually implement solo by changing
 	   the solo mute setting of each track.
 	*/
@@ -2379,7 +2408,24 @@ Session::catch_up_on_solo ()
 	*/
 	update_route_solo_state();
 }	
-		
+
+void
+Session::catch_up_on_solo_mute_override ()
+{
+	if (Config->get_solo_model() != InverseMute) {
+		return;
+	}
+
+	/* this is called whenever the param solo-mute-override is
+	   changed.
+	*/
+	shared_ptr<RouteList> r = routes.reader ();
+
+	for (RouteList::iterator i = r->begin(); i != r->end(); ++i) {
+		(*i)->catch_up_on_solo_mute_override ();
+	}
+}	
+
 shared_ptr<Route>
 Session::route_by_name (string name)
 {
@@ -4197,7 +4243,7 @@ Session::compute_initial_length ()
 }
 
 void
-Session::sync_order_keys ()
+Session::sync_order_keys (const char* base)
 {
 	if (!Config->get_sync_all_route_ordering()) {
 		/* leave order keys as they are */
@@ -4207,8 +4253,8 @@ Session::sync_order_keys ()
 	boost::shared_ptr<RouteList> r = routes.reader ();
 
 	for (RouteList::iterator i = r->begin(); i != r->end(); ++i) {
-		(*i)->sync_order_keys ();
+		(*i)->sync_order_keys (base);
 	}
 
-	Route::SyncOrderKeys (); // EMIT SIGNAL
+	Route::SyncOrderKeys (base); // EMIT SIGNAL
 }
