@@ -453,10 +453,21 @@ Session::stop_audio_export (AudioExportSpecification& spec)
 {
 	/* don't stop freewheeling but do stop paying attention to it for now */
 
+
+	/* save the value of stop so that the UI
+	   can see if it requested a stop.
+	*/
+
+	bool old_stop = spec.stop;
+
 	spec.freewheel_connection.disconnect ();
 	spec.clear (); /* resets running/stop etc */
 
-	Exported (spec.path, name());
+	spec.stop = old_stop;
+
+	if (!spec.stop) {
+		Exported (spec.path, name());
+	}
 
 	return 0;
 }
@@ -549,10 +560,10 @@ Session::process_export (nframes_t nframes, AudioExportSpecification* spec)
 	int ret = -1;
 	nframes_t this_nframes;
 
-	cerr << "Export process at pos = " << spec->pos << " _exporting = "
+	/*cerr << "Export process at pos = " << spec->pos << " _exporting = "
 	     << _exporting << " running = " << spec->running << " stop = "
 	     << spec->stop << endl;
-
+	*/
 	/* This is not required to be RT-safe because we are running while freewheeling */
 
 	if (spec->do_freewheel == false) {
@@ -626,7 +637,7 @@ Session::process_export (nframes_t nframes, AudioExportSpecification* spec)
 		}
 	}
 
-	cerr << "\tprocess " << nframes << endl;
+	//cerr << "\tprocess " << nframes << endl;
 
 	if (spec->process (nframes)) {
 		goto out;
@@ -635,7 +646,7 @@ Session::process_export (nframes_t nframes, AudioExportSpecification* spec)
 	spec->pos += nframes;
 	spec->progress = 1.0 - (((float) spec->end_frame - spec->pos) / spec->total_frames);
 
-	cerr << "\t@ " << spec->pos << " prog = " << spec->progress << endl;
+	//cerr << "\t@ " << spec->pos << " prog = " << spec->progress << endl;
 
 	/* and we're good to go */
 
