@@ -148,13 +148,13 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 	g_atomic_int_set (&_record_status, Disabled);
 	loop_changing = false;
 	play_loop = false;
+	have_looped = false;
 	_last_roll_location = 0;
 	_last_record_location = 0;
 	pending_locate_frame = 0;
 	pending_locate_roll = false;
 	pending_locate_flush = false;
 	dstream_buffer_size = 0;
-	state_tree = 0;
 	state_was_pending = false;
 	set_next_event ();
 	outbound_mtc_smpte_frame = 0;
@@ -170,9 +170,6 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 
 	_slave = 0;
 	_silent = false;
-	butler_mixdown_buffer = 0;
-	butler_gain_buffer = 0;
-	mmc = 0;
 	session_send_mmc = false;
 	session_send_mtc = false;
 	post_transport_work = PostTransportWork (0);
@@ -183,7 +180,6 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 	g_atomic_int_set (&_playback_load_min, 100);
 	g_atomic_int_set (&_capture_load_min, 100);
 	_play_range = false;
-	waiting_to_start = false;
 	_exporting = false;
 	_gain_automation_buffer = 0;
 	_pan_automation_buffer = 0;
@@ -194,7 +190,6 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 	first_file_data_format_reset = true;
 	first_file_header_format_reset = true;
 	butler_thread = (pthread_t) 0;
-	midi_thread = (pthread_t) 0;
 
 	AudioDiskstream::allocate_working_buffers();
 	
@@ -211,8 +206,6 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 	   waveforms for clicks.
 	*/
 	
-	click_data = 0;
-	click_emphasis_data = 0;
 	click_length = 0;
 	click_emphasis_length = 0;
 	_clicking = false;
@@ -239,7 +232,7 @@ Session::first_stage_init (string fullpath, string snapshot_name)
 
 	/* slave stuff */
 
-	average_slave_delta = 1800;
+	average_slave_delta = 1800; // !!! why 1800 ????
 	have_first_delta_accumulator = false;
 	delta_accumulator_cnt = 0;
 	slave_state = Stopped;
@@ -342,6 +335,8 @@ Session::second_stage_init (bool new_session)
 	deliver_mmc (MIDI::MachineControl::cmdMmcReset, 0);
 	deliver_mmc (MIDI::MachineControl::cmdLocate, 0);
 
+	/* initial program change will be delivered later; see ::config_changed() */
+
 	BootMessage (_("Reset Control Protocols"));
 
 	ControlProtocolManager::instance().set_session (*this);
@@ -858,6 +853,12 @@ Session::load_options (const XMLNode& node)
 
 	Config->set_variables (node, ConfigVariableBase::Session);
 
+	/* now reset MIDI ports because the session can have its own 
+	   MIDI configuration.
+	*/
+
+	setup_midi ();
+
 	if ((child = find_named_node (node, "end-marker-is-free")) != 0) {
 		if ((prop = child->property ("val")) != 0) {
 			_end_location_is_free = (prop->value() == "yes");
@@ -1187,10 +1188,10 @@ Session::set_state (const XMLNode& node)
 
 	/* Object loading order:
 
-	MIDI
 	Path
 	extra
 	Options/Config
+	MIDI  <= relies on data from Options/Config
 	Locations
 	Sources
 	AudioRegions
@@ -1203,9 +1204,6 @@ Session::set_state (const XMLNode& node)
 	ControlProtocols
 	*/
 
-	if (use_config_midi_ports ()) {
-	}
-
 	if ((child = find_named_node (node, "extra")) != 0) {
 		_extra_xml = new XMLNode (*child);
 	}
@@ -1218,6 +1216,9 @@ Session::set_state (const XMLNode& node)
 		error << _("Session: XML state has no options section") << endmsg;
 	}
 
+	if (use_config_midi_ports ()) {
+	}
+
 	if ((child = find_named_node (node, "Locations")) == 0) {
 		error << _("Session: XML state has no locations section") << endmsg;
 		goto out;
@@ -3345,7 +3346,18 @@ Session::config_changed (const char* parameter_name)
 	} else if (PARAM_IS ("history-depth")) {
 		set_history_depth (Config->get_history_depth());
 	} else if (PARAM_IS ("sync-all-route-ordering")) {
-		sync_order_keys ();
+		sync_order_keys ("session"); 
+	} else if (PARAM_IS ("initial-program-change")) {
+
+		if (_mmc_port && Config->get_initial_program_change() >= 0) {
+			MIDI::byte* buf = new MIDI::byte[2];
+			
+			buf[0] = MIDI::program; // channel zero by default
+			buf[1] = (Config->get_initial_program_change() & 0x7f);
+			deliver_midi (_mmc_port, buf, 2);
+		}
+	} else if (PARAM_IS ("solo-mute-override")) {
+		catch_up_on_solo_mute_override ();
 	}
 
 	set_dirty ();
