@@ -207,8 +207,7 @@ Session::butler_transport_work ()
 	}
 
 	if (post_transport_work & PostTransportReverse) {
-
-
+		
 		clear_clicks();
 		cumulative_rf_motion = 0;
 		reset_rf_scale (0);
@@ -437,6 +436,8 @@ Session::non_realtime_stop (bool abort, int on_entry, bool& finished)
 		_requested_return_frame = -1;
 	}
 
+        have_looped = false; 
+
         send_full_time_code ();
 	deliver_mmc (MIDI::MachineControl::cmdStop, 0);
 	deliver_mmc (MIDI::MachineControl::cmdLocate, _transport_frame);
@@ -766,7 +767,7 @@ Session::locate (nframes_t target_frame, bool with_roll, bool with_flush, bool w
 					}
 				}
 			}
-
+			have_looped = true;
 			TransportLooped(); // EMIT SIGNAL
 		}
 	}
@@ -863,6 +864,7 @@ Session::set_transport_speed (float speed, bool abort)
 
 		if ((_transport_speed && speed * _transport_speed < 0.0f) || (_last_transport_speed * speed < 0.0f) || (_last_transport_speed == 0.0f && speed < 0.0f)) {
 			post_transport_work = PostTransportWork (post_transport_work | PostTransportReverse);
+			last_stop_frame = _transport_frame;
 		}
 		
 		_last_transport_speed = _transport_speed;
@@ -926,6 +928,7 @@ void
 Session::start_transport ()
 {
 	_last_roll_location = _transport_frame;
+	have_looped = false;
 
 	/* if record status is Enabled, move it to Recording. if its
 	   already Recording, move it to Disabled. 
@@ -948,18 +951,6 @@ Session::start_transport ()
 		break;
 	}
 
-	if (!synced_to_jack() || _exporting) {
-		actually_start_transport ();
-	} else {
-		waiting_to_start = true;
-	}
-}
-
-void
-Session::actually_start_transport ()
-{
-	waiting_to_start = false;
-
 	transport_sub_state |= PendingDeclickIn;
 	_transport_speed = 1.0;
 	
