@@ -14,7 +14,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: barcontroller.cc 3334 2008-05-11 21:42:10Z drobilla $
+    $Id: barcontroller.cc 3870 2008-10-05 19:06:20Z paul $
 */
 
 #include <string>
@@ -40,7 +40,7 @@ BarController::BarController (Gtk::Adjustment& adj,
 			      sigc::slot<void,char*,unsigned int> lc) 
 
 	: adjustment (adj),
-	  binding_proxy (mc),
+	  binding_proxy (&mc),
 	  label_callback (lc),
 	  spinner (adjustment)
 
