@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: gtk_ui.cc 3254 2008-04-16 00:38:09Z timbyr $
+    $Id: gtk_ui.cc 4142 2008-11-11 16:00:27Z nickm $
 */
 
 #include <cmath>
@@ -65,6 +65,9 @@ UI::UI (string namestr, int *argc, char ***argv)
 	: AbstractUI<UIRequest> (namestr, true)
 {
 	theMain = new Main (argc, argv);
+#ifndef GTK_NEW_TOOLTIP_API
+	tips = new Tooltips;
+#endif
 
 	_active = false;
 	_auto_display_errors = true;
@@ -96,6 +99,7 @@ UI::UI (string namestr, int *argc, char ***argv)
 
 	errors->dismiss_button().set_name ("ErrorLogCloseButton");
 	errors->signal_delete_event().connect (bind (sigc::ptr_fun (just_hide_it), (Window *) errors));
+	errors->set_type_hint (Gdk::WINDOW_TYPE_HINT_UTILITY);
 
 	register_thread (pthread_self(), X_("GUI"));
 
@@ -372,7 +376,16 @@ UI::do_request (UIRequest* req)
 
 	} else if (req->type == SetTip) {
 
-		/* XXX need to figure out how this works */
+#ifdef GTK_NEW_TOOLTIP_API
+		/* even if the installed GTK is up to date,
+		   at present (November 2008) our included
+		   version of gtkmm is not. so use the GTK
+		   API that we've verified has the right function.
+		*/
+		gtk_widget_set_tooltip_text (req->widget->gobj(), req->msg);
+#else
+		tips->set_tip (*req->widget, req->msg, "");
+#endif
 
 	} else {
 
