@@ -15,10 +15,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Last changed  : $Date: 2005-05-18 12:08:37 -0400 (Wed, 18 May 2005) $
-// File revision : $Revision: 13 $
+// Last changed  : $Date: 2008-07-10 20:37:26 +0200 (Thu, 10 Jul 2008) $
+// File revision : $Revision: 3584 $
 //
-// $Id: FIFOSampleBuffer.cpp 13 2005-05-18 16:08:37Z taybin $
+// $Id: FIFOSampleBuffer.cpp 3584 2008-07-10 18:37:26Z nostar $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -43,10 +43,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <memory.h>
-#include <string.h>
-#include <assert.h>
+#include <cstring>
+#include <cassert>
 #include <stdexcept>
 
 #include "FIFOSampleBuffer.h"
