@@ -11,10 +11,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Last changed  : $Date: 2005-05-18 12:08:37 -0400 (Wed, 18 May 2005) $
-// File revision : $Revision: 13 $
+// Last changed  : $Date: 2008-07-10 20:37:26 +0200 (Thu, 10 Jul 2008) $
+// File revision : $Revision: 3584 $
 //
-// $Id: FIRFilter.cpp 13 2005-05-18 16:08:37Z taybin $
+// $Id: FIRFilter.cpp 3584 2008-07-10 18:37:26Z nostar $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -40,9 +40,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <memory.h>
-#include <assert.h>
-#include <math.h>
-#include <stdlib.h>
+#include <cassert>
+#include <cmath>
+#include <cstdlib>
 #include <stdexcept>
 #include "FIRFilter.h"
 #include "cpu_detect.h"
