@@ -10,10 +10,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Last changed  : $Date: 2005/05/18 14:13:49 $
-// File revision : $Revision: 1.2 $
+// Last changed  : $Date: 2008-07-10 20:37:26 +0200 (Thu, 10 Jul 2008) $
+// File revision : $Revision: 3584 $
 //
-// $Id: RateTransposer.cpp,v 1.2 2005/05/18 14:13:49 taybin Exp $
+// $Id: RateTransposer.cpp 3584 2008-07-10 18:37:26Z nostar $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -39,10 +39,10 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <memory.h>
-#include <assert.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <limits.h>
+#include <cassert>
+#include <cstdlib>
+#include <cstdio>
+#include <climits>
 #include "RateTransposer.h"
 #include "AAFilter.h"
 
@@ -339,7 +339,7 @@ void RateTransposer::clear()
 
 
 // Returns nonzero if there aren't any samples available for outputting.
-uint RateTransposer::isEmpty()
+int RateTransposer::isEmpty() const
 {
     int res;
 
