@@ -13,10 +13,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Last changed  : $Date: 2007-03-16 17:44:10 -0400 (Fri, 16 Mar 2007) $
-// File revision : $Revision: 1605 $
+// Last changed  : $Date: 2008-07-10 20:37:26 +0200 (Thu, 10 Jul 2008) $
+// File revision : $Revision: 3584 $
 //
-// $Id: TDStretch.cpp 1605 2007-03-16 21:44:10Z paul $
+// $Id: TDStretch.cpp 3584 2008-07-10 18:37:26Z nostar $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -41,12 +41,12 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <string.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdlib>
 #include <memory.h>
-#include <limits.h>
-#include <math.h>
-#include <assert.h>
+#include <climits>
+#include <cmath>
+#include <cassert>
 
 #include "STTypes.h"
 #include "cpu_detect.h"
